@@ -29,7 +29,7 @@ import org.eclipse.swt.widgets.*;
 public class Sleak {
 	List list;
 	Canvas canvas;
-	Button snapshot, diff, stackTrace, saveAs, save;
+	Button enableTracking, snapshot, diff, stackTrace, saveAs, save;
 	Text text;
 	Label label;
 	
@@ -81,6 +81,11 @@ public void create (Composite parent) {
 	text = new Text (parent, SWT.BORDER | SWT.H_SCROLL | SWT.V_SCROLL);
 	canvas = new Canvas (parent, SWT.BORDER);
 	canvas.addListener (SWT.Paint, event -> paintCanvas (event));
+	enableTracking = new Button (parent, SWT.CHECK);
+	enableTracking.setText ("Enable");
+	enableTracking.setToolTipText("Enable Device resource tracking. Only resources allocated once enabled will be tracked. To track devices created before view is created, turn on tracing options, see https://www.eclipse.org/swt/tools.php");
+	enableTracking.addListener (SWT.Selection, e -> toggleEnableTracking ());
+	enableTracking.setSelection(enableTracking.getDisplay().isTracking());
 	stackTrace = new Button (parent, SWT.CHECK);
 	stackTrace.setText ("Stack");
 	stackTrace.addListener (SWT.Selection, e -> toggleStackTrace ());
@@ -106,11 +111,16 @@ public void create (Composite parent) {
 	layout();
 }
 
+private void toggleEnableTracking() {
+	Display display = enableTracking.getDisplay();
+	boolean tracking = display.isTracking();
+	display.setTracking(!tracking);
+}
+
 void refreshLabel () {
-	int colors = 0, cursors = 0, fonts = 0, gcs = 0, images = 0;
+	int cursors = 0, fonts = 0, gcs = 0, images = 0;
 	int paths = 0, patterns = 0, regions = 0, textLayouts = 0, transforms= 0;
 	for (Object object : objects) {
-		if (object instanceof Color) colors++;
 		if (object instanceof Cursor) cursors++;
 		if (object instanceof Font) fonts++;
 		if (object instanceof GC) gcs++;
@@ -122,7 +132,6 @@ void refreshLabel () {
 		if (object instanceof Transform) transforms++;
 	}
 	String string = "";
-	if (colors != 0) string += colors + " Color(s)\n";
 	if (cursors != 0) string += cursors + " Cursor(s)\n";
 	if (fonts != 0) string += fonts + " Font(s)\n";
 	if (gcs != 0) string += gcs + " GC(s)\n";
@@ -143,13 +152,31 @@ void refreshDifference () {
 	DeviceData info = display.getDeviceData ();
 	if (!info.tracking) {
 		Shell shell = canvas.getShell();
-		MessageBox dialog = new MessageBox (shell, SWT.ICON_WARNING | SWT.OK);
+		MessageBox dialog = new MessageBox (shell, SWT.ICON_WARNING | SWT.YES | SWT.NO);
 		dialog.setText (shell.getText ());
-		dialog.setMessage ("Warning: Device is not tracking resource allocation");
-		dialog.open ();
+		dialog.setMessage ("Warning: Device is not tracking resource allocation\nWould you like to enable tracking now for future created resources?");
+		if (SWT.YES == dialog.open ()) {
+			enableTracking.setSelection(true);
+			toggleEnableTracking();
+		}
+	}
+	int size = 0;
+	for (int i = 0; i < info.objects.length; i++) {
+		if (!(info.objects[i] instanceof Color)) {
+			size++;
+		}
+	}
+	Object [] newObjects = new Object[size];
+	Error [] newErrors = new Error[size];
+	for (int i = 0, out_i = 0; i < info.objects.length; i++) {
+		// Bug 563018: Colors don't require disposal, so exclude
+		// them from the list of allocated objects.
+		if (!(info.objects[i] instanceof Color)) {
+			newObjects[out_i] = info.objects[i];
+			newErrors[out_i] = info.errors[i];
+			out_i++;
+		}
 	}
-	Object [] newObjects = info.objects;
-	Error [] newErrors = info.errors;
 	Object [] diffObjects = new Object [newObjects.length];
 	Error [] diffErrors = new Error [newErrors.length];
 	int count = 0;
@@ -264,12 +291,6 @@ void paintCanvas (Event event) {
 }
 
 void draw(GC gc, Object object) {
-	if (object instanceof Color) {
-		if (((Color)object).isDisposed ()) return;
-		gc.setBackground ((Color) object);
-		gc.fillRectangle (canvas.getClientArea());
-		return;
-	}
 	if (object instanceof Cursor) {
 		if (((Cursor)object).isDisposed ()) return;
 		canvas.setCursor ((Cursor) object);
@@ -367,23 +388,26 @@ void layout () {
 		width = Math.max (width, gc.stringExtent (items [i]).x);
 	}
 	gc.dispose ();
+	Point enableTrackingSize = enableTracking.computeSize (SWT.DEFAULT, SWT.DEFAULT);
 	Point snapshotSize = snapshot.computeSize (SWT.DEFAULT, SWT.DEFAULT);
 	Point diffSize = diff.computeSize (SWT.DEFAULT, SWT.DEFAULT);
 	Point stackSize = stackTrace.computeSize (SWT.DEFAULT, SWT.DEFAULT);
 	Point labelSize = label.computeSize (SWT.DEFAULT, SWT.DEFAULT);
 	Point saveAsSize = saveAs.computeSize (SWT.DEFAULT, SWT.DEFAULT);
 	Point saveSize = save.computeSize (SWT.DEFAULT, SWT.DEFAULT);
+	width = Math.max (enableTrackingSize.x, width);
 	width = Math.max (snapshotSize.x, Math.max (diffSize.x, Math.max (stackSize.x, width)));
 	width = Math.max (saveAsSize.x, Math.max (saveSize.x, width));
 	width = Math.max (labelSize.x, list.computeSize (width, SWT.DEFAULT).x);
 	width = Math.max (64, width);
-	snapshot.setBounds (0, 0, width, snapshotSize.y);
-	diff.setBounds (0, snapshotSize.y, width, diffSize.y);
-	stackTrace.setBounds (0, snapshotSize.y + diffSize.y, width, stackSize.y);
+	enableTracking.setBounds (0, 0, width, enableTrackingSize.y);
+	snapshot.setBounds (0, enableTrackingSize.y, width, snapshotSize.y);
+	diff.setBounds (0, enableTrackingSize.y + snapshotSize.y, width, diffSize.y);
+	stackTrace.setBounds (0, enableTrackingSize.y + snapshotSize.y + diffSize.y, width, stackSize.y);
 	label.setBounds (0, rect.height - saveSize.y - saveAsSize.y - labelSize.y, width, labelSize.y);
 	saveAs.setBounds (0, rect.height - saveSize.y - saveAsSize.y, width, saveAsSize.y);
 	save.setBounds (0, rect.height - saveSize.y, width, saveSize.y);
-	int height = snapshotSize.y + diffSize.y + stackSize.y;
+	int height = enableTrackingSize.y + snapshotSize.y + diffSize.y + stackSize.y;
 	list.setBounds (0, height, width, rect.height - height - labelSize.y - saveAsSize.y -saveSize.y);
 	text.setBounds (width, 0, rect.width - width, rect.height);
 	canvas.setBounds (width, 0, rect.width - width, rect.height);
