@@ -155,8 +155,7 @@ void generateAll() {
 	shell.setCursor(cursor);
 	shell.setEnabled(false);
 	Control[] children = actionsPanel.getChildren();
-	for (int i = 0; i < children.length; i++) {
-		Control child = children[i];
+	for (Control child : children) {
 		if (child instanceof Button) child.setEnabled(false);				
 	}
 	boolean showProgress = true;
@@ -204,8 +203,7 @@ void generateAll() {
 	while (!done[0]) {
 		if (!display.readAndDispatch()) display.sleep();
 	}
-	for (int i = 0; i < children.length; i++) {
-		Control child = children[i];
+	for (Control child : children) {
 		if (child instanceof Button) child.setEnabled(true);				
 	}
 	if (showProgress) {
@@ -243,8 +241,7 @@ JNIMethod[] getSelectedMethods() {
 	TableItem[] selection = membersLt.getSelection();
 	JNIMethod[] methods = new JNIMethod[selection.length];
 	int count = 0;
-	for (int i = 0; i < selection.length; i++) {
-		TableItem item = selection [i];
+	for (TableItem item : selection) {
 		Object data = item.getData();
 		if (data instanceof JNIMethod) {
 			methods[count++] = (JNIMethod)data;
@@ -262,8 +259,7 @@ JNIField[] getSelectedFields() {
 	TableItem[] selection = membersLt.getSelection();
 	JNIField[] fields = new JNIField[selection.length];
 	int count = 0;
-	for (int i = 0; i < selection.length; i++) {
-		TableItem item = selection [i];
+	for (TableItem item : selection) {
 		Object data = item.getData();
 		if (data instanceof JNIField) {
 			fields[count++] = (JNIField)data;
@@ -918,8 +914,7 @@ String getClassString(JNIType type) {
 String getFlagsString(String[] flags) {
 	if (flags.length == 0) return "";
 	StringBuilder buffer = new StringBuilder();
-	for (int j = 0; j < flags.length; j++) {
-		String flag = flags[j];
+	for (String flag : flags) {
 		if (buffer.length() != 0) buffer.append(", ");
 		buffer.append(flag);
 	}
@@ -960,9 +955,7 @@ void updateClasses() {
 		item.setText(CLASS_FLAGS_COLUMN, getFlagsString(clazz.getFlags()));
 		item.setChecked(clazz.getGenerate());
 	}
-	TableColumn[] columns = classesLt.getColumns();
-	for (int i = 0; i < columns.length; i++) {
-		TableColumn column = columns[i];
+	for (TableColumn column : classesLt.getColumns()) {
 		column.pack();
 	}
 	classesLt.setSelection(mainIndex);
@@ -972,8 +965,7 @@ void updateMembers() {
 	membersLt.removeAll();
 	membersLt.setHeaderVisible(false);
 	TableColumn[] columns = membersLt.getColumns();
-	for (int i = 0; i < columns.length; i++) {
-		TableColumn column = columns[i];
+	for (TableColumn column : columns) {
 		column.dispose();
 	}
 	int[] indices = classesLt.getSelectionIndices();
@@ -982,8 +974,7 @@ void updateMembers() {
 	JNIClass clazz = (JNIClass)classItem.getData();
 	boolean hasNatives = false;
 	JNIMethod[] methods = clazz.getDeclaredMethods();
-	for (int i = 0; i < methods.length; i++) {
-		JNIMethod method = methods[i];
+	for (JNIMethod method : methods) {
 		int mods = method.getModifiers();
 		if (hasNatives =((mods & Modifier.NATIVE) != 0)) break;
 	}
@@ -1001,8 +992,7 @@ void updateMembers() {
 		column.setText("Exclude");
 		*/
 		JNIGenerator.sort(methods);
-		for (int i = 0; i < methods.length; i++) {
-			JNIMethod method = methods[i];
+		for (JNIMethod method : methods) {
 			if ((method.getModifiers() & Modifier.NATIVE) == 0) continue;
 			TableItem item = new TableItem(membersLt, SWT.NONE);
 			item.setData(method);
@@ -1028,9 +1018,7 @@ void updateMembers() {
 		column = new TableColumn(membersLt, SWT.NONE, FIELD_EXCLUDE_COLUMN);
 		column.setText("Exclude");
 		*/
-		JNIField[] fields = clazz.getDeclaredFields();	
-		for (int i = 0; i < fields.length; i++) {
-			JNIField field = fields[i];
+		for (JNIField field : clazz.getDeclaredFields()) {
 			int mods = field.getModifiers(); 
 			if (((mods & Modifier.PUBLIC) == 0) ||
 				((mods & Modifier.FINAL) != 0) ||
@@ -1047,9 +1035,7 @@ void updateMembers() {
 			*/
 		}
 	}
-	columns = membersLt.getColumns();
-	for (int i = 0; i < columns.length; i++) {
-		TableColumn column = columns[i];
+	for (TableColumn column : membersLt.getColumns()) {
 		column.pack();
 	}
 	membersLt.setHeaderVisible(true);
@@ -1078,9 +1064,7 @@ void updateParameters() {
 		item.setText(PARAM_CAST_COLUMN, param.getCast());
 		item.setText(PARAM_FLAGS_COLUMN, getFlagsString(param.getFlags()));
 	}
-	TableColumn[] columns = paramsLt.getColumns();
-	for (int i = 0; i < columns.length; i++) {
-		TableColumn column = columns[i];
+	for (TableColumn column : paramsLt.getColumns()) {
 		column.pack();
 	}
 	paramsLt.setRedraw(true);
