@@ -27,12 +27,8 @@ public JNIParameter[] getParameters();
 
 public JNIType getReturnType();
 
-public JNIType getReturnType64();
-
 public JNIType[] getParameterTypes();
 
-public JNIType[] getParameterTypes64();
-
 public JNIClass getDeclaringClass();
 
 public String getAccessor();
