@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -51,6 +51,7 @@ public class CTabFolderRenderer {
 	Color selectedOuterColor = null;
 	Color selectedInnerColor = null;
 	Color tabAreaColor = null;
+	Color minMaxBorderColor = null;
 	/*
 	 * Border color that was used in computing the cached anti-alias Colors.
 	 * We have to recompute the colors if the border color changes
@@ -251,6 +252,7 @@ public class CTabFolderRenderer {
 	 * </p><p>
 	 * The <code>part</code> value indicated what component the preferred size is
 	 * to be calculated for. Valid values are any of the part constants:
+	 * </p>
 	 * <ul>
 	 * <li>PART_BODY</li>
 	 * <li>PART_HEADER</li>
@@ -262,14 +264,13 @@ public class CTabFolderRenderer {
 	 * <li>PART_CLOSE_BUTTON</li>
 	 * <li>A positive integer which is the index of an item in the CTabFolder.</li>
 	 * </ul>
-	 * </p>
 	 * <p>
 	 * The <code>state</code> parameter may be one of the following:
+	 * </p>
 	 * <ul>
 	 * <li>SWT.NONE</li>
 	 * <li>SWT.SELECTED - whether the part is selected</li>
 	 * </ul>
-	 * </p>
 	 * @param part a part constant
 	 * @param state current state
 	 * @param gc the gc to use for measuring
@@ -458,45 +459,45 @@ public class CTabFolderRenderer {
 	}
 
 	void createAntialiasColors() {
-	    disposeAntialiasColors();
-	    lastBorderColor = parent.getDisplay().getSystemColor(BORDER1_COLOR);
-	    RGB lineRGB = lastBorderColor.getRGB();
-	    /* compute the selected color */
-	    RGB innerRGB = parent.selectionBackground.getRGB();
-	    if (parent.selectionBgImage != null ||
-		    (parent.selectionGradientColors != null && parent.selectionGradientColors.length > 1)) {
-		    innerRGB = null;
-	    }
-	    RGB outerRGB = parent.getBackground().getRGB();
-	    if (parent.gradientColors != null && parent.gradientColors.length > 1) {
-		    outerRGB = null;
-	    }
-	    if (outerRGB != null) {
+		disposeAntialiasColors();
+		lastBorderColor = parent.getDisplay().getSystemColor(BORDER1_COLOR);
+		RGB lineRGB = lastBorderColor.getRGB();
+		/* compute the selected color */
+		RGB innerRGB = parent.selectionBackground.getRGB();
+		if (parent.selectionBgImage != null ||
+			(parent.selectionGradientColors != null && parent.selectionGradientColors.length > 1)) {
+			innerRGB = null;
+		}
+		RGB outerRGB = parent.getBackground().getRGB();
+		if (parent.gradientColors != null && parent.gradientColors.length > 1) {
+			outerRGB = null;
+		}
+		if (outerRGB != null) {
 			RGB from = lineRGB;
 			RGB to = outerRGB;
 			int red = from.red + 2*(to.red - from.red)/3;
 			int green = from.green + 2*(to.green - from.green)/3;
 			int blue = from.blue + 2*(to.blue - from.blue)/3;
-			selectedOuterColor = new Color(parent.getDisplay(), red, green, blue);
-	    }
-	    if (innerRGB != null) {
+			selectedOuterColor = new Color(red, green, blue);
+		}
+		if (innerRGB != null) {
 			RGB from = lineRGB;
 			RGB to = innerRGB;
 			int red = from.red + 2*(to.red - from.red)/3;
 			int green = from.green + 2*(to.green - from.green)/3;
 			int blue = from.blue + 2*(to.blue - from.blue)/3;
-			selectedInnerColor = new Color(parent.getDisplay(), red, green, blue);
-	    }
-	    /* compute the tabArea color */
-	    outerRGB = parent.getParent().getBackground().getRGB();
-	    if (outerRGB != null) {
+			selectedInnerColor = new Color(red, green, blue);
+		}
+		/* compute the tabArea color */
+		outerRGB = parent.getParent().getBackground().getRGB();
+		if (outerRGB != null) {
 			RGB from = lineRGB;
 			RGB to = outerRGB;
 			int red = from.red + 2*(to.red - from.red)/3;
 			int green = from.green + 2*(to.green - from.green)/3;
 			int blue = from.blue + 2*(to.blue - from.blue)/3;
-			tabAreaColor = new Color(parent.getDisplay(), red, green, blue);
-	    }
+			tabAreaColor = new Color(red, green, blue);
+		}
 	}
 
 	/*
@@ -527,7 +528,7 @@ public class CTabFolderRenderer {
 			int red = (to.red * propTo + from.red * propFrom) / denom;
 			int green = (to.green * propTo  + from.green * propFrom) / denom;
 			int blue = (to.blue * propTo  + from.blue * propFrom) / denom;
-			selectionHighlightGradientColorsCache[i] = new Color(parent.getDisplay(), red, green, blue);
+			selectionHighlightGradientColorsCache[i] = new Color(red, green, blue);
 		}
 	}
 
@@ -542,20 +543,24 @@ public class CTabFolderRenderer {
 		disposeAntialiasColors();
 		disposeSelectionHighlightGradientColors();
 		if (fillColor != null) {
-		    fillColor.dispose();
-		    fillColor = null;
+			fillColor.dispose();
+			fillColor = null;
 		}
 		if (chevronFont != null) {
 			chevronFont.dispose();
 			chevronFont = null;
 		}
+		if (minMaxBorderColor != null) {
+			minMaxBorderColor.dispose();
+			minMaxBorderColor = null;
+		}
 	}
 
 	void disposeAntialiasColors() {
-	    if (tabAreaColor != null) tabAreaColor.dispose();
-	    if (selectedInnerColor != null) selectedInnerColor.dispose();
-	    if (selectedOuterColor != null) selectedOuterColor.dispose();
-	    tabAreaColor = selectedInnerColor = selectedOuterColor = null;
+		if (tabAreaColor != null) tabAreaColor.dispose();
+		if (selectedInnerColor != null) selectedInnerColor.dispose();
+		if (selectedOuterColor != null) selectedOuterColor.dispose();
+		tabAreaColor = selectedInnerColor = selectedOuterColor = null;
 	}
 
 	void disposeSelectionHighlightGradientColors() {
@@ -570,6 +575,7 @@ public class CTabFolderRenderer {
 	/**
 	 * Draw a specified <code>part</code> of the CTabFolder using the provided <code>bounds</code> and <code>GC</code>.
 	 * <p>The valid CTabFolder <code>part</code> constants are:
+	 * </p>
 	 * <ul>
 	 * <li>PART_BODY - the entire body of the CTabFolder</li>
 	 * <li>PART_HEADER - the upper tab area of the CTabFolder</li>
@@ -581,16 +587,15 @@ public class CTabFolderRenderer {
 	 * <li>PART_CLOSE_BUTTON</li>
 	 * <li>A positive integer which is the index of an item in the CTabFolder.</li>
 	 * </ul>
-	 * </p>
 	 * <p>
 	 * The <code>state</code> parameter may be a combination of:
+	 * </p>
 	 * <ul>
 	 * <li>SWT.BACKGROUND - whether the background should be drawn</li>
 	 * <li>SWT.FOREGROUND - whether the foreground should be drawn</li>
 	 * <li>SWT.SELECTED - whether the part is selected</li>
 	 * <li>SWT.HOT - whether the part is hot (i.e. mouse is over the part)</li>
 	 * </ul>
-	 * </p>
 	 *
 	 * @param part part to draw
 	 * @param state state of the part
@@ -600,6 +605,12 @@ public class CTabFolderRenderer {
 	 * @since 3.6
 	 */
 	protected void draw (int part, int state, Rectangle bounds, GC gc) {
+		if (minMaxBorderColor == null) {
+			// this color has to be identical to the colors used in the PNG files of
+			// the view drop down menu located in
+			// org.eclipse.e4.ui.workbench.renderers.swt/icons/full/elcl16/view_menu.png
+			minMaxBorderColor = new Color (105, 105, 105);
+		}
 		switch (part) {
 			case PART_BACKGROUND:
 				this.drawBackground(gc, bounds, state);
@@ -801,7 +812,7 @@ public class CTabFolderRenderer {
 					int x2 = size.x - borderRight;
 					int y2 = size.y - borderBottom - tabHeight - highlight_header;
 					shape = new int[] {x1,y1, x2,y1, x2,y2, x2-highlight_margin,y2,
-							           x2-highlight_margin, y1+highlight_margin, x1+highlight_margin,y1+highlight_margin,
+									   x2-highlight_margin, y1+highlight_margin, x1+highlight_margin,y1+highlight_margin,
 									   x1+highlight_margin,y2, x1,y2};
 				} else {
 					int x1 = borderLeft;
@@ -809,7 +820,7 @@ public class CTabFolderRenderer {
 					int x2 = size.x - borderRight;
 					int y2 = size.y - borderBottom;
 					shape = new int[] {x1,y1, x1+highlight_margin,y1, x1+highlight_margin,y2-highlight_margin,
-							           x2-highlight_margin,y2-highlight_margin, x2-highlight_margin,y1,
+									   x2-highlight_margin,y2-highlight_margin, x2-highlight_margin,y1,
 									   x2,y1, x2,y2, x1,y2};
 				}
 				// If horizontal gradient, show gradient across the whole area
@@ -818,7 +829,7 @@ public class CTabFolderRenderer {
 				} else if (selectedIndex == -1 && parent.gradientColors != null && parent.gradientColors.length > 1 && !parent.gradientVertical) {
 					drawBackground(gc, shape, false);
 				} else {
-					gc.setBackground(selectedIndex == -1 ? parent.getBackground() : parent.selectionBackground);
+					gc.setBackground(selectedIndex != -1 && parent.shouldHighlight() ? parent.selectionBackground : parent.getBackground());
 					gc.fillPolygon(shape);
 				}
 			}
@@ -875,9 +886,9 @@ public class CTabFolderRenderer {
 		switch (closeImageState & (SWT.HOT | SWT.SELECTED | SWT.BACKGROUND)) {
 			case SWT.NONE: {
 				int[] shape = new int[] {x,y, x+2,y, x+4,y+2, x+5,y+2, x+7,y, x+9,y,
-						                 x+9,y+2, x+7,y+4, x+7,y+5, x+9,y+7, x+9,y+9,
-				                         x+7,y+9, x+5,y+7, x+4,y+7, x+2,y+9, x,y+9,
-				                         x,y+7, x+2,y+5, x+2,y+4, x,y+2};
+										 x+9,y+2, x+7,y+4, x+7,y+5, x+9,y+7, x+9,y+9,
+										 x+7,y+9, x+5,y+7, x+4,y+7, x+2,y+9, x,y+9,
+										 x,y+7, x+2,y+5, x+2,y+4, x,y+2};
 				gc.setBackground(display.getSystemColor(BUTTON_FILL));
 				gc.fillPolygon(shape);
 				gc.setForeground(closeBorder);
@@ -886,9 +897,9 @@ public class CTabFolderRenderer {
 			}
 			case SWT.HOT: {
 				int[] shape = new int[] {x,y, x+2,y, x+4,y+2, x+5,y+2, x+7,y, x+9,y,
-						                 x+9,y+2, x+7,y+4, x+7,y+5, x+9,y+7, x+9,y+9,
-				                         x+7,y+9, x+5,y+7, x+4,y+7, x+2,y+9, x,y+9,
-				                         x,y+7, x+2,y+5, x+2,y+4, x,y+2};
+										 x+9,y+2, x+7,y+4, x+7,y+5, x+9,y+7, x+9,y+9,
+										 x+7,y+9, x+5,y+7, x+4,y+7, x+2,y+9, x,y+9,
+										 x,y+7, x+2,y+5, x+2,y+4, x,y+2};
 				gc.setBackground(getFillColor());
 				gc.fillPolygon(shape);
 				gc.setForeground(closeBorder);
@@ -897,9 +908,9 @@ public class CTabFolderRenderer {
 			}
 			case SWT.SELECTED: {
 				int[] shape = new int[] {x+1,y+1, x+3,y+1, x+5,y+3, x+6,y+3, x+8,y+1, x+10,y+1,
-						                 x+10,y+3, x+8,y+5, x+8,y+6, x+10,y+8, x+10,y+10,
-				                         x+8,y+10, x+6,y+8, x+5,y+8, x+3,y+10, x+1,y+10,
-				                         x+1,y+8, x+3,y+6, x+3,y+5, x+1,y+3};
+										 x+10,y+3, x+8,y+5, x+8,y+6, x+10,y+8, x+10,y+10,
+										 x+8,y+10, x+6,y+8, x+5,y+8, x+3,y+10, x+1,y+10,
+										 x+1,y+8, x+3,y+6, x+3,y+5, x+1,y+3};
 				gc.setBackground(getFillColor());
 				gc.fillPolygon(shape);
 				gc.setForeground(closeBorder);
@@ -916,7 +927,6 @@ public class CTabFolderRenderer {
 
 	void drawChevron(GC gc, Rectangle chevronRect, int chevronImageState) {
 		if (chevronRect.width == 0 || chevronRect.height == 0) return;
-		int selectedIndex = parent.selectedIndex;
 		// draw chevron (10x7)
 		Display display = parent.getDisplay();
 		Font font = getChevronFont(display);
@@ -924,17 +934,7 @@ public class CTabFolderRenderer {
 		int indent = Math.max(2, (chevronRect.height - fontHeight - 4) /2);
 		int x = chevronRect.x + 2;
 		int y = chevronRect.y + indent;
-		int count;
-		int itemCount = parent.getItemCount();
-		if (parent.single) {
-			count = selectedIndex == -1 ? itemCount : itemCount - 1;
-		} else {
-			int showCount = 0;
-			while (showCount < parent.priority.length && parent.items[parent.priority[showCount]].showing) {
-				showCount++;
-			}
-			count = itemCount - showCount;
-		}
+		int count = parent.getChevronCount();
 		String chevronString = count > 99 ? CHEVRON_ELLIPSIS : String.valueOf(count);
 		switch (chevronImageState & (SWT.HOT | SWT.SELECTED)) {
 			case SWT.NONE: {
@@ -1122,7 +1122,7 @@ public class CTabFolderRenderer {
 		int x = maxRect.x + (maxRect.width - 10)/2;
 		int y = maxRect.y + 3;
 
-		gc.setForeground(display.getSystemColor(BUTTON_BORDER));
+		gc.setForeground(minMaxBorderColor);
 		gc.setBackground(display.getSystemColor(BUTTON_FILL));
 
 		switch (maxImageState & (SWT.HOT | SWT.SELECTED)) {
@@ -1182,7 +1182,7 @@ public class CTabFolderRenderer {
 		int x = minRect.x + (minRect.width - 10)/2;
 		int y = minRect.y + 3;
 
-		gc.setForeground(display.getSystemColor(BUTTON_BORDER));
+		gc.setForeground(minMaxBorderColor);
 		gc.setBackground(display.getSystemColor(BUTTON_FILL));
 
 		switch (minImageState & (SWT.HOT | SWT.SELECTED)) {
@@ -1464,7 +1464,7 @@ public class CTabFolderRenderer {
 				int textY = y + (height - extent.y) / 2;
 				textY += parent.onBottom ? -1 : 1;
 
-				gc.setForeground(parent.selectionForeground);
+				gc.setForeground(item.selectionForeground == null ? parent.getSelectionForeground() : item.selectionForeground);
 				gc.drawText(item.shortenedText, xDraw, textY, FLAGS);
 				gc.setFont(gcFont);
 
@@ -1515,7 +1515,7 @@ public class CTabFolderRenderer {
 			} else if (selectedIndex == -1 && parent.gradientColors != null && parent.gradientColors.length > 1 && !parent.gradientVertical) {
 				drawBackground(gc, shape, false);
 			} else {
-				gc.setBackground(selectedIndex == -1 ? parent.getBackground() : parent.selectionBackground);
+				gc.setBackground(selectedIndex != -1 && parent.shouldHighlight() ? parent.selectionBackground : parent.getBackground());
 				gc.fillPolygon(shape);
 			}
 
@@ -1606,8 +1606,8 @@ public class CTabFolderRenderer {
 
 		// Draw border line
 		if (borderLeft > 0) {
-	    	if (! borderColor.equals(lastBorderColor)) createAntialiasColors();
-	    	antialias(shape, null, tabAreaColor, gc);
+			if (! borderColor.equals(lastBorderColor)) createAntialiasColors();
+			antialias(shape, null, tabAreaColor, gc);
 			gc.setForeground(borderColor);
 			gc.drawPolyline(shape);
 		}
@@ -1653,8 +1653,8 @@ public class CTabFolderRenderer {
 					imageY += parent.onBottom ? -1 : 1;
 					int imageWidth = imageBounds.width * imageHeight / imageBounds.height;
 					gc.drawImage(image,
-						         imageBounds.x, imageBounds.y, imageBounds.width, imageBounds.height,
-						         imageX, imageY, imageWidth, imageHeight);
+								 imageBounds.x, imageBounds.y, imageBounds.width, imageBounds.height,
+								 imageX, imageY, imageWidth, imageHeight);
 					xDraw += imageWidth + INTERNAL_SPACING;
 				}
 			}
@@ -1673,7 +1673,7 @@ public class CTabFolderRenderer {
 				Point extent = gc.textExtent(item.shortenedText, FLAGS);
 				int textY = y + (height - extent.y) / 2;
 				textY += parent.onBottom ? -1 : 1;
-				gc.setForeground(parent.getForeground());
+				gc.setForeground(item.foreground == null ? parent.getForeground() : item.foreground);
 				gc.drawText(item.shortenedText, xDraw, textY, FLAGS);
 				gc.setFont(gcFont);
 			}
@@ -1695,7 +1695,7 @@ public class CTabFolderRenderer {
 
 	Color getFillColor() {
 		if (fillColor == null) {
-			fillColor = new Color(parent.getDisplay(), CLOSE_FILL);
+			fillColor = new Color(CLOSE_FILL);
 		}
 		return fillColor;
 	}
@@ -1795,18 +1795,19 @@ public class CTabFolderRenderer {
 		if (this.getClass().getName().equals("org.eclipse.e4.ui.workbench.renderers.swt.CTabRendering")) return;
 		int tabHeight = parent.tabHeight;
 		if (tabHeight == lastTabHeight) return;
+		lastTabHeight = tabHeight;
 		if (parent.onBottom) {
 			int d = tabHeight - 12;
 			curve = new int[]{0,13+d, 0,12+d, 2,12+d, 3,11+d, 5,11+d, 6,10+d, 7,10+d, 9,8+d, 10,8+d,
-					          11,7+d, 11+d,7,
-							  12+d,6, 13+d,6, 15+d,4, 16+d,4, 17+d,3, 19+d,3, 20+d,2, 22+d,2, 23+d,1};
+								11,7+d, 11+d,7,
+								12+d,6, 13+d,6, 15+d,4, 16+d,4, 17+d,3, 19+d,3, 20+d,2, 22+d,2, 23+d,1};
 			curveWidth = 26+d;
 			curveIndent = curveWidth/3;
 		} else {
 			int d = tabHeight - 12;
 			curve = new int[]{0,0, 0,1, 2,1, 3,2, 5,2, 6,3, 7,3, 9,5, 10,5,
-					          11,6, 11+d,6+d,
-					          12+d,7+d, 13+d,7+d, 15+d,9+d, 16+d,9+d, 17+d,10+d, 19+d,10+d, 20+d,11+d, 22+d,11+d, 23+d,12+d};
+								11,6, 11+d,6+d,
+								12+d,7+d, 13+d,7+d, 15+d,9+d, 16+d,9+d, 17+d,10+d, 19+d,10+d, 20+d,11+d, 22+d,11+d, 23+d,12+d};
 			curveWidth = 26+d;
 			curveIndent = curveWidth/3;
 
