@@ -51,6 +51,8 @@ class StyledTextRenderer {
 	LineInfo[] lines;
 	int maxWidth;
 	int maxWidthLineIndex;
+	float averageLineHeight;
+	int linesInAverageLineHeight;
 	boolean idleRunning;
 
 	/* Bullet */
@@ -297,6 +299,7 @@ void calculate(int startLine, int lineCount) {
 			Rectangle rect = layout.getBounds();
 			line.width = rect.width + hTrim;
 			line.height = rect.height;
+			averageLineHeight += (line.height - Math.round(averageLineHeight)) / ++linesInAverageLineHeight;
 			disposeTextLayout(layout);
 		}
 		if (line.width > maxWidth) {
@@ -411,8 +414,8 @@ void dispose() {
 }
 void disposeTextLayout (TextLayout layout) {
 	if (layouts != null) {
-		for (int i = 0; i < layouts.length; i++) {
-			if (layouts[i] == layout) return;
+		for (TextLayout l : layouts) {
+			if (l == layout) return;
 		}
 	}
 	layout.dispose();
@@ -505,8 +508,8 @@ int drawLine(int lineIndex, int paintX, int paintY, GC gc, Color widgetBackgroun
 				bulletIndex = bulletsIndices[index];
 			}
 		} else {
-			for (int i = 0; i < bullets.length; i++) {
-				bullet = bullets[i];
+			for (Bullet b : bullets) {
+				bullet = b;
 				bulletIndex = bullet.indexOf(lineIndex);
 				if (bulletIndex != -1) break;
 			}
@@ -544,6 +547,9 @@ int drawLine(int lineIndex, int paintX, int paintY, GC gc, Color widgetBackgroun
 int getBaseline() {
 	return ascent;
 }
+int getCachedLineHeight(int lineIndex) {
+	return getLineHeight(lineIndex, false);
+}
 Font getFont(int style) {
 	switch (style) {
 		case SWT.BOLD:
@@ -561,8 +567,8 @@ Font getFont(int style) {
 }
 FontData[] getFontData(int style) {
 	FontData[] fontDatas = regularFont.getFontData();
-	for (int i = 0; i < fontDatas.length; i++) {
-		fontDatas[i].setStyle(style);
+	for (FontData fontData : fontDatas) {
+		fontData.setStyle(style);
 	}
 	return fontDatas;
 }
@@ -605,8 +611,7 @@ boolean hasLink(int offset) {
 					}
 				}
 			} else {
-				for (int i = 0; i < styles.length; i++) {
-					StyleRange style = styles[i];
+				for (StyleRange style : styles) {
 					if (style.start <= offset && offset < style.start + style.length && style.underline && style.underlineStyle == SWT.UNDERLINE_LINK) {
 						return true;
 					}
@@ -647,8 +652,7 @@ Color getLineBackground(int index, Color defaultBackground) {
 Bullet getLineBullet (int index, Bullet defaultBullet) {
 	if (bullets == null) return defaultBullet;
 	if (bulletsIndices != null) return defaultBullet;
-	for (int i = 0; i < bullets.length; i++) {
-		Bullet bullet = bullets[i];
+	for (Bullet bullet : bullets) {
 		if (bullet.indexOf(index) != -1) return bullet;
 	}
 	return defaultBullet;
@@ -657,12 +661,19 @@ int getLineHeight() {
 	return ascent + descent;
 }
 int getLineHeight(int lineIndex) {
+	return getLineHeight(lineIndex, true);
+}
+int getLineHeight(int lineIndex, boolean exact) {
 	LineSizeInfo line = getLineSize(lineIndex);
 	if (line.needsRecalculateHeight()) {
-		// here we are in "variable line height", the call of calculate which uses TextLayout can be very slow
-		// check if line can use the default line height.
+		// here we are in "variable line height", the call of calculate which uses TextLayout is very slow
+		// so use the average line height of all calculated lines when many heights are needed e.g. for scrolling.
 		if (isVariableHeight(lineIndex)) {
-			calculate(lineIndex, 1);
+			if (exact) {
+				calculate(lineIndex, 1);
+			} else {
+				return Math.round(averageLineHeight);
+			}
 		} else {
 			line.height = getLineHeight() + getLineSpacing(lineIndex);
 		}
@@ -912,7 +923,6 @@ TextLayout getTextLayout(int lineIndex) {
 			 */
 			lineSpacingComputing = true;
 			styledText.resetCache(lineIndex, 1);
-			styledText.setVariableLineHeight();
 			styledText.setCaretLocation();
 			styledText.redraw();
 		} finally {
@@ -1049,8 +1059,8 @@ TextLayout getTextLayout(int lineIndex, int orientation, int width, int lineSpac
 			if (styledText.isFixedLineHeight()) {
 				for (int i = 0; i < styleCount; i++) {
 					if (styles[i].isVariableHeight()) {
+						styledText.hasStyleWithVariableHeight = true;
 						styledText.verticalScrollOffset = -1;
-						styledText.setVariableLineHeight();
 						styledText.redraw();
 						break;
 					}
@@ -1085,9 +1095,9 @@ TextLayout getTextLayout(int lineIndex, int orientation, int width, int lineSpac
 			bulletsIndices = null;
 		}
 		if (bullets != null) {
-			for (int i = 0; i < bullets.length; i++) {
-				if (bullets[i].indexOf(lineIndex) != -1) {
-					bullet = bullets[i];
+			for (Bullet b : bullets) {
+				if (b.indexOf(lineIndex) != -1) {
+					bullet = b;
 					break;
 				}
 			}
@@ -1262,10 +1272,10 @@ TextLayout getTextLayout(int lineIndex, int orientation, int width, int lineSpac
 			ascent = metrics.getAscent() + metrics.getLeading();
 			descent = metrics.getDescent();
 			if (layouts != null) {
-				for (int i = 0; i < layouts.length; i++) {
-					if (layouts[i] != null && layouts[i] != layout) {
-						layouts[i].setAscent(ascent);
-						layouts[i].setDescent(descent);
+				for (TextLayout l : layouts) {
+					if (l != null && l != layout) {
+						l.setAscent(ascent);
+						l.setDescent(descent);
 					}
 				}
 			}
@@ -1295,8 +1305,7 @@ int getWidth() {
 }
 void reset() {
 	if (layouts != null) {
-		for (int i = 0; i < layouts.length; i++) {
-			TextLayout layout = layouts[i];
+		for (TextLayout layout : layouts) {
 			if (layout != null) layout.dispose();
 		}
 		layouts = null;
@@ -1331,6 +1340,12 @@ void reset(Set<Integer> lines) {
 			getLineSize(line.intValue()).resetSize();
 		}
 	}
+	if (linesInAverageLineHeight > resetLineCount) {
+		linesInAverageLineHeight -= resetLineCount;
+	} else {
+		linesInAverageLineHeight = 0;
+		averageLineHeight = 0.0f;
+	}
 	if (lines.contains(Integer.valueOf(maxWidthLineIndex))) {
 		maxWidth = 0;
 		maxWidthLineIndex = -1;
@@ -1638,8 +1653,8 @@ void setStyleRanges (int[] newRanges, StyleRange[] newStyles) {
 		}
 		modifyEnd = modifyStart;
 		StyleRange[] mergeStyles = new StyleRange[3];
-		for (int i = 0; i < newStyles.length; i++) {
-			StyleRange newStyle = newStyles[i], style;
+		for (StyleRange newStyle : newStyles) {
+			StyleRange style;
 			int newStart = newStyle.start;
 			int newEnd = newStart + newStyle.length;
 			if (newStart == newEnd) continue;
@@ -1794,8 +1809,7 @@ void textChanging(TextChangingEvent event) {
 void updateBullets(int startLine, int replaceLineCount, int newLineCount, boolean update) {
 	if (bullets == null) return;
 	if (bulletsIndices != null) return;
-	for (int i = 0; i < bullets.length; i++) {
-		Bullet bullet = bullets[i];
+	for (Bullet bullet : bullets) {
 		int[] lines = bullet.removeIndices(startLine, replaceLineCount, newLineCount, update);
 		if (lines != null) {
 			if (redrawLines == null) {
@@ -1809,8 +1823,8 @@ void updateBullets(int startLine, int replaceLineCount, int newLineCount, boolea
 		}
 	}
 	int removed = 0;
-	for (int i = 0; i < bullets.length; i++) {
-		if (bullets[i].size() == 0) removed++;
+	for (Bullet bullet : bullets) {
+		if (bullet.size() == 0) removed++;
 	}
 	if (removed > 0) {
 		if (removed == bullets.length) {
@@ -1929,5 +1943,11 @@ void updateRanges(int start, int replaceCharCount, int newCharCount) {
 	}
 }
 
+public boolean hasVerticalIndent() {
+	return Arrays.stream(lines).filter(Objects::nonNull) //
+			.mapToInt(line -> line.verticalIndent) //
+			.anyMatch(n -> n != 0);
+}
+
 
 }
