@@ -23,7 +23,7 @@ import org.eclipse.swt.internal.cocoa.*;
  *
  * <p>An example of a java <code>String</code> containing a URL is shown below:</p>
  *
- * <code><pre>
+ * <pre><code>
  *     String url = "http://www.eclipse.org";
  * </code></pre>
  *
@@ -91,20 +91,12 @@ public Object nativeToJava(TransferData transferData){
 
 @Override
 protected int[] getTypeIds(){
-	if (OS.VERSION >= 0x1060) {
-		return new int[] {URL_ID, URL_ID1};
-	} else {
-		return new int[] {URL_ID};
-	}
+	return new int[] {URL_ID, URL_ID1};
 }
 
 @Override
 protected String[] getTypeNames(){
-	if (OS.VERSION >= 0x1060) {
-		return new String[] {URL, URL1};
-	} else {
-		return new String[] {URL};
-	}
+	return new String[] {URL, URL1};
 }
 
 boolean checkURL(Object object) {
