@@ -366,10 +366,13 @@ private void drag(Event dragEvent) {
 		OS.GetWindowRect (hwndDrag, rect);
 		OS.ImageList_DragEnter(hwndDrag, pt.x - rect.left, pt.y - rect.top);
 	}
+	String externalLoopKey = "org.eclipse.swt.internal.win32.externalEventLoop";
 	int result = COM.DRAGDROP_S_CANCEL;
 	try {
+		display.setData(externalLoopKey, Boolean.TRUE);
 		result = COM.DoDragDrop(iDataObject.getAddress(), iDropSource.getAddress(), operations, pdwEffect);
 	} finally {
+		display.setData(externalLoopKey, Boolean.FALSE);
 		// ensure that we don't leave transparent window around
 		if (hwndDrag != 0) {
 			OS.ImageList_DragLeave(hwndDrag);
@@ -437,8 +440,7 @@ private int EnumFormatEtc(int dwDirection, long ppenumFormatetc) {
 
 	// what types have been registered?
 	TransferData[] allowedDataTypes = new TransferData[0];
-	for (int i = 0; i < transferAgents.length; i++){
-		Transfer transferAgent = transferAgents[i];
+	for (Transfer transferAgent : transferAgents) {
 		if (transferAgent != null) {
 			TransferData[] formats = transferAgent.getSupportedTypes();
 			TransferData[] newAllowedDataTypes = new TransferData[allowedDataTypes.length + formats.length];
@@ -497,8 +499,7 @@ private int GetData(long pFormatetc, long pmedium) {
 
 	// get matching transfer agent to perform conversion
 	Transfer transfer = null;
-	for (int i = 0; i < transferAgents.length; i++){
-		Transfer transferAgent = transferAgents[i];
+	for (Transfer transferAgent : transferAgents) {
 		if (transferAgent != null && transferAgent.isSupportedType(transferData)){
 			transfer = transferAgent;
 			break;
@@ -653,9 +654,8 @@ private int QueryGetData(long pFormatetc) {
 	transferData.type = transferData.formatetc.cfFormat;
 
 	// is this type supported by the transfer agent?
-	for (int i = 0; i < transferAgents.length; i++){
-		Transfer transfer = transferAgents[i];
-		if (transfer != null && transfer.isSupportedType(transferData))
+	for (Transfer transferAgent : transferAgents) {
+		if (transferAgent != null && transferAgent.isSupportedType(transferData))
 			return COM.S_OK;
 	}
 
