@@ -1,10 +1,13 @@
 #!/bin/sh
 #*******************************************************************************
 # Copyright (c) 2000, 2011 IBM Corporation and others.
-# All rights reserved. This program and the accompanying materials
-# are made available under the terms of the Eclipse Public License v1.0
+#
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License 2.0
 # which accompanies this distribution, and is available at
-# http://www.eclipse.org/legal/epl-v10.html
+# https://www.eclipse.org/legal/epl-2.0/
+#
+# SPDX-License-Identifier: EPL-2.0
 #
 # Contributors:
 #     IBM Corporation - initial API and implementation
@@ -23,14 +26,13 @@ if [ "x${MODEL}" = "xx86_64" ]; then
 	if [ "x${OUTPUT_DIR}" = "x" ]; then
 		export OUTPUT_DIR=../../../org.eclipse.swt.cocoa.macosx.x86_64
 	fi
-	if [ "x${XULRUNNER_SDK}" = "x" ]; then
-		export XULRUNNER_SDK="/Users/Shared/xulrunner/64-bit/mozilla/dist"
-	fi
-	if [ "x${XULRUNNER_LIBS}" = "x" ]; then
-		export XULRUNNER_LIBS="${XULRUNNER_SDK}/lib/libxpcomglue.a"
+	if [ -d "chromium_subp/cef_macosx" ]; then
+		export CHROMIUM_HEADERS=./chromium_subp/cef_macosx
+	else
+		export CHROMIUM_HEADERS=$CHROMIUM_OUTPUT_DIR/../../../../eclipse.platform.swt/bundles/org.eclipse.swt.browser.chromium/common/rust-library/chromium_subp/cef_macosx
 	fi
 fi
 
-export MACOSX_DEPLOYMENT_TARGET=10.7
+export MACOSX_DEPLOYMENT_TARGET=10.10
 
 make -f make_macosx.mak $1 $2 $3 $4 $5 $6 $7 $8 $9
