@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -40,10 +40,6 @@ public void getBytes(byte[] buffer) {
 	OS.objc_msgSend(this.id, OS.sel_getBytes_, buffer);
 }
 
-public void getBytes(long buffer, long length) {
-	OS.objc_msgSend(this.id, OS.sel_getBytes_length_, buffer, length);
-}
-
 public long length() {
 	return OS.objc_msgSend(this.id, OS.sel_length);
 }
