@@ -19,7 +19,7 @@ public NSTimer() {
 	super();
 }
 
-public NSTimer(long /*int*/ id) {
+public NSTimer(long id) {
 	super(id);
 }
 
@@ -31,8 +31,8 @@ public void invalidate() {
 	OS.objc_msgSend(this.id, OS.sel_invalidate);
 }
 
-public static NSTimer scheduledTimerWithTimeInterval(double ti, id aTarget, long /*int*/ aSelector, id userInfo, boolean yesOrNo) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSTimer, OS.sel_scheduledTimerWithTimeInterval_target_selector_userInfo_repeats_, ti, aTarget != null ? aTarget.id : 0, aSelector, userInfo != null ? userInfo.id : 0, yesOrNo);
+public static NSTimer scheduledTimerWithTimeInterval(double ti, id aTarget, long aSelector, id userInfo, boolean yesOrNo) {
+	long result = OS.objc_msgSend(OS.class_NSTimer, OS.sel_scheduledTimerWithTimeInterval_target_selector_userInfo_repeats_, ti, aTarget != null ? aTarget.id : 0, aSelector, userInfo != null ? userInfo.id : 0, yesOrNo);
 	return result != 0 ? new NSTimer(result) : null;
 }
 
@@ -41,7 +41,7 @@ public void setFireDate(NSDate fireDate) {
 }
 
 public id userInfo() {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_userInfo);
+	long result = OS.objc_msgSend(this.id, OS.sel_userInfo);
 	return result != 0 ? new id(result) : null;
 }
 
