@@ -23,7 +23,6 @@ public enum Selector {
 	, sel_sendVerticalSelection("sendVerticalSelection")
 	, sel_sendHorizontalSelection("sendHorizontalSelection")
 	, sel_timerProc_("timerProc:")
-	, sel_handleNotification_("handleNotification:")
 	, sel_callJava("callJava:index:token:arg:")
 	, sel_callRunBeforeUnloadConfirmPanelWithMessage("callRunBeforeUnloadConfirmPanelWithMessage:arg:")
 	, sel_createPanelDidEnd("createPanelDidEnd:returnCode:contextInfo:")
@@ -32,14 +31,10 @@ public enum Selector {
 	, sel_panelDidEnd_returnCode_contextInfo_("panelDidEnd:returnCode:contextInfo:")
 	, sel_updateOpenGLContext_("updateOpenGLContext:")
 	, sel_overwriteExistingFileCheck("_overwriteExistingFileCheck:")
-	, sel_setShowsHiddenFiles_("setShowsHiddenFiles:")
-	, sel_contextID("contextID")
 	, sel__drawThemeProgressArea_("_drawThemeProgressArea:")
 
 	, sel__setDashboardBehavior("_setDashboardBehavior:to:")
 
-	, sel__setNeedsToUseHeartBeatWindow_("_setNeedsToUseHeartBeatWindow:")
-
 	, sel_sharedHandler("sharedHandler")
 	, sel_startAuthentication("startAuthentication:window:")
 	, sel_setAllowsAnyHTTPSCertificate("setAllowsAnyHTTPSCertificate:forHost:")
@@ -77,13 +72,6 @@ public enum Selector {
 
 	, sel_cellBaselineOffset("cellBaselineOffset")
 
-	/** 10.7 selectors and constants */
-	, sel_isCompatibleWithOverlayScrollers("isCompatibleWithOverlayScrollers")
-	, sel_flashScrollers("flashScrollers")
-	, sel_frameSizeForContentSize_horizontalScrollerClass_verticalScrollerClass_borderType_controlSize_scrollerStyle_("frameSizeForContentSize:horizontalScrollerClass:verticalScrollerClass:borderType:controlSize:scrollerStyle:")
-	, sel_scrollerStyle("scrollerStyle")
-	, sel_toggleFullScreen_("toggleFullScreen:")
-
 	/** 10.12 selector */
 	, sel_setAllowsAutomaticWindowTabbing("setAllowsAutomaticWindowTabbing:")
 
@@ -100,7 +88,6 @@ public enum Selector {
 	, sel_URL("URL")
 	, sel_URLFromPasteboard_("URLFromPasteboard:")
 	, sel_URLWithString_("URLWithString:")
-	, sel_URLsForDirectory_inDomains_("URLsForDirectory:inDomains:")
 	, sel_UTF8String("UTF8String")
 	, sel_abortEditing("abortEditing")
 	, sel_absoluteString("absoluteString")
@@ -139,7 +126,6 @@ public enum Selector {
 	, sel_addSubview_("addSubview:")
 	, sel_addSubview_positioned_relativeTo_("addSubview:positioned:relativeTo:")
 	, sel_addTabStop_("addTabStop:")
-	, sel_addTabViewItem_("addTabViewItem:")
 	, sel_addTableColumn_("addTableColumn:")
 	, sel_addTemporaryAttribute_value_forCharacterRange_("addTemporaryAttribute:value:forCharacterRange:")
 	, sel_addTextContainer_("addTextContainer:")
@@ -150,18 +136,14 @@ public enum Selector {
 	, sel_allKeys("allKeys")
 	, sel_allObjects("allObjects")
 	, sel_alloc("alloc")
-	, sel_allowsColumnReordering("allowsColumnReordering")
-	, sel_allowsFloats("allowsFloats")
 	, sel_alphaComponent("alphaComponent")
 	, sel_alphaValue("alphaValue")
 	, sel_altKey("altKey")
 	, sel_alternateSelectedControlColor("alternateSelectedControlColor")
 	, sel_alternateSelectedControlTextColor("alternateSelectedControlTextColor")
-	, sel_alwaysShowsDecimalSeparator("alwaysShowsDecimalSeparator")
 	, sel_appearanceNamed_("appearanceNamed:")
 	, sel_appendAttributedString_("appendAttributedString:")
 	, sel_appendBezierPath_("appendBezierPath:")
-	, sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_("appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:")
 	, sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_clockwise_("appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:clockwise:")
 	, sel_appendBezierPathWithGlyphs_count_inFont_("appendBezierPathWithGlyphs:count:inFont:")
 	, sel_appendBezierPathWithOvalInRect_("appendBezierPathWithOvalInRect:")
@@ -171,14 +153,12 @@ public enum Selector {
 	, sel_application_openFile_("application:openFile:")
 	, sel_application_openFiles_("application:openFiles:")
 	, sel_applicationDidBecomeActive_("applicationDidBecomeActive:")
-	, sel_applicationDidFinishLaunching_("applicationDidFinishLaunching:")
 	, sel_applicationDidResignActive_("applicationDidResignActive:")
 	, sel_applicationDockMenu_("applicationDockMenu:")
 	, sel_applicationIconImage("applicationIconImage")
 	, sel_applicationShouldHandleReopen_hasVisibleWindows_("applicationShouldHandleReopen:hasVisibleWindows:")
 	, sel_applicationShouldTerminate_("applicationShouldTerminate:")
 	, sel_applicationWillFinishLaunching_("applicationWillFinishLaunching:")
-	, sel_applicationWillTerminate_("applicationWillTerminate:")
 	, sel_archivedDataWithRootObject_("archivedDataWithRootObject:")
 	, sel_areCursorRectsEnabled("areCursorRectsEnabled")
 	, sel_arrangeInFront_("arrangeInFront:")
@@ -191,16 +171,13 @@ public enum Selector {
 	, sel_attachment("attachment")
 	, sel_attribute_atIndex_effectiveRange_("attribute:atIndex:effectiveRange:")
 	, sel_attributedStringValue("attributedStringValue")
-	, sel_attributedStringWithAttachment_("attributedStringWithAttachment:")
 	, sel_attributedSubstringFromRange_("attributedSubstringFromRange:")
 	, sel_attributedTitle("attributedTitle")
 	, sel_attributesAtIndex_longestEffectiveRange_inRange_("attributesAtIndex:longestEffectiveRange:inRange:")
 	, sel_autorelease("autorelease")
 	, sel_availableFontFamilies("availableFontFamilies")
-	, sel_availableFonts("availableFonts")
 	, sel_availableMembersOfFontFamily_("availableMembersOfFontFamily:")
 	, sel_availableTypeFromArray_("availableTypeFromArray:")
-	, sel_backgroundColor("backgroundColor")
 	, sel_backingScaleFactor("backingScaleFactor")
 	, sel_badgeLabel("badgeLabel")
 	, sel_baselineOffsetInLayoutManager_glyphIndex_("baselineOffsetInLayoutManager:glyphIndex:")
@@ -208,12 +185,12 @@ public enum Selector {
 	, sel_becomeKeyWindow("becomeKeyWindow")
 	, sel_beginDocument("beginDocument")
 	, sel_beginEditing("beginEditing")
-	, sel_beginGestureWithEvent_("beginGestureWithEvent:")
 	, sel_beginPageInRect_atPlacement_("beginPageInRect:atPlacement:")
 	, sel_beginSheet_modalForWindow_modalDelegate_didEndSelector_contextInfo_("beginSheet:modalForWindow:modalDelegate:didEndSelector:contextInfo:")
 	, sel_beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_trust_message_("beginSheetForWindow:modalDelegate:didEndSelector:contextInfo:trust:message:")
 	, sel_beginSheetModalForWindow_modalDelegate_didEndSelector_contextInfo_("beginSheetModalForWindow:modalDelegate:didEndSelector:contextInfo:")
 	, sel_beginSheetWithPrintInfo_modalForWindow_delegate_didEndSelector_contextInfo_("beginSheetWithPrintInfo:modalForWindow:delegate:didEndSelector:contextInfo:")
+	, sel_beginUndoGrouping("beginUndoGrouping")
 	, sel_bestRepresentationForDevice_("bestRepresentationForDevice:")
 	, sel_bezelStyle("bezelStyle")
 	, sel_bezierPath("bezierPath")
@@ -240,7 +217,6 @@ public enum Selector {
 	, sel_button("button")
 	, sel_buttonNumber("buttonNumber")
 	, sel_bytes("bytes")
-	, sel_bytesPerPlane("bytesPerPlane")
 	, sel_bytesPerRow("bytesPerRow")
 	, sel_cacheDisplayInRect_toBitmapImageRep_("cacheDisplayInRect:toBitmapImageRep:")
 	, sel_calendarDate("calendarDate")
@@ -270,14 +246,12 @@ public enum Selector {
 	, sel_characterIndexForGlyphAtIndex_("characterIndexForGlyphAtIndex:")
 	, sel_characterIndexForInsertionAtPoint_("characterIndexForInsertionAtPoint:")
 	, sel_characterIndexForPoint_("characterIndexForPoint:")
-	, sel_characterIsMember_("characterIsMember:")
 	, sel_characters("characters")
 	, sel_charactersIgnoringModifiers("charactersIgnoringModifiers")
 	, sel_chooseFilename_("chooseFilename:")
 	, sel_className("className")
 	, sel_cleanUpOperation("cleanUpOperation")
 	, sel_clearColor("clearColor")
-	, sel_clearCurrentContext("clearCurrentContext")
 	, sel_clearDrawable("clearDrawable")
 	, sel_clickCount("clickCount")
 	, sel_clickedColumn("clickedColumn")
@@ -293,22 +267,17 @@ public enum Selector {
 	, sel_colorListNamed_("colorListNamed:")
 	, sel_colorSpace("colorSpace")
 	, sel_colorSpaceModel("colorSpaceModel")
-	, sel_colorSpaceName("colorSpaceName")
 	, sel_colorUsingColorSpaceName_("colorUsingColorSpaceName:")
-	, sel_colorWithCalibratedRed_green_blue_alpha_("colorWithCalibratedRed:green:blue:alpha:")
 	, sel_colorWithDeviceRed_green_blue_alpha_("colorWithDeviceRed:green:blue:alpha:")
 	, sel_colorWithKey_("colorWithKey:")
 	, sel_colorWithPatternImage_("colorWithPatternImage:")
 	, sel_columnAtPoint_("columnAtPoint:")
-	, sel_columnIndexesInRect_("columnIndexesInRect:")
-	, sel_columnWithIdentifier_("columnWithIdentifier:")
 	, sel_comboBoxSelectionDidChange_("comboBoxSelectionDidChange:")
 	, sel_comboBoxWillDismiss_("comboBoxWillDismiss:")
 	, sel_comboBoxWillPopUp_("comboBoxWillPopUp:")
 	, sel_compare_("compare:")
 	, sel_concat("concat")
 	, sel_conformsToProtocol_("conformsToProtocol:")
-	, sel_containerSize("containerSize")
 	, sel_containsIndex_("containsIndex:")
 	, sel_containsObject_("containsObject:")
 	, sel_containsPoint_("containsPoint:")
@@ -319,7 +288,6 @@ public enum Selector {
 	, sel_contentViewMargins("contentViewMargins")
 	, sel_context("context")
 	, sel_controlBackgroundColor("controlBackgroundColor")
-	, sel_controlContentFontOfSize_("controlContentFontOfSize:")
 	, sel_controlDarkShadowColor("controlDarkShadowColor")
 	, sel_controlHighlightColor("controlHighlightColor")
 	, sel_controlLightHighlightColor("controlLightHighlightColor")
@@ -331,17 +299,9 @@ public enum Selector {
 	, sel_convertFont_toHaveTrait_("convertFont:toHaveTrait:")
 	, sel_convertPoint_fromView_("convertPoint:fromView:")
 	, sel_convertPoint_toView_("convertPoint:toView:")
-	, sel_convertPointFromBase_("convertPointFromBase:")
-	, sel_convertPointToBase_("convertPointToBase:")
 	, sel_convertRect_fromView_("convertRect:fromView:")
 	, sel_convertRect_toView_("convertRect:toView:")
-	, sel_convertRectFromBase_("convertRectFromBase:")
-	, sel_convertRectToBase_("convertRectToBase:")
 	, sel_convertScreenToBase_("convertScreenToBase:")
-	, sel_convertSize_fromView_("convertSize:fromView:")
-	, sel_convertSize_toView_("convertSize:toView:")
-	, sel_convertSizeFromBase_("convertSizeFromBase:")
-	, sel_convertSizeToBase_("convertSizeToBase:")
 	, sel_cookies("cookies")
 	, sel_cookiesForURL_("cookiesForURL:")
 	, sel_cookiesWithResponseHeaderFields_forURL_("cookiesWithResponseHeaderFields:forURL:")
@@ -350,7 +310,6 @@ public enum Selector {
 	, sel_copy_("copy:")
 	, sel_count("count")
 	, sel_createContext("createContext")
-	, sel_createFileAtPath_contents_attributes_("createFileAtPath:contents:attributes:")
 	, sel_credentialWithUser_password_persistence_("credentialWithUser:password:persistence:")
 	, sel_crosshairCursor("crosshairCursor")
 	, sel_ctrlKey("ctrlKey")
@@ -377,7 +336,6 @@ public enum Selector {
 	, sel_dateWithYear_month_day_hour_minute_second_timeZone_("dateWithYear:month:day:hour:minute:second:timeZone:")
 	, sel_dayOfMonth("dayOfMonth")
 	, sel_dealloc("dealloc")
-	, sel_decimalDigitCharacterSet("decimalDigitCharacterSet")
 	, sel_decimalSeparator("decimalSeparator")
 	, sel_declareTypes_owner_("declareTypes:owner:")
 	, sel_defaultBaselineOffsetForFont_("defaultBaselineOffsetForFont:")
@@ -421,12 +379,10 @@ public enum Selector {
 	, sel_distantFuture("distantFuture")
 	, sel_doCommandBySelector_("doCommandBySelector:")
 	, sel_dockTile("dockTile")
-	, sel_documentCursor("documentCursor")
 	, sel_documentSource("documentSource")
 	, sel_documentView("documentView")
 	, sel_documentViewShouldHandlePrint("documentViewShouldHandlePrint")
 	, sel_documentVisibleRect("documentVisibleRect")
-	, sel_doubleClickAtIndex_("doubleClickAtIndex:")
 	, sel_doubleClickInterval("doubleClickInterval")
 	, sel_doubleValue("doubleValue")
 	, sel_download("download")
@@ -437,7 +393,6 @@ public enum Selector {
 	, sel_draggedImage_beganAt_("draggedImage:beganAt:")
 	, sel_draggedImage_endedAt_operation_("draggedImage:endedAt:operation:")
 	, sel_draggingDestinationWindow("draggingDestinationWindow")
-	, sel_draggingEnded_("draggingEnded:")
 	, sel_draggingEntered_("draggingEntered:")
 	, sel_draggingExited_("draggingExited:")
 	, sel_draggingLocation("draggingLocation")
@@ -445,8 +400,6 @@ public enum Selector {
 	, sel_draggingSourceOperationMask("draggingSourceOperationMask")
 	, sel_draggingSourceOperationMaskForLocal_("draggingSourceOperationMaskForLocal:")
 	, sel_draggingUpdated_("draggingUpdated:")
-	, sel_drawAtPoint_("drawAtPoint:")
-	, sel_drawAtPoint_fromRect_operation_fraction_("drawAtPoint:fromRect:operation:fraction:")
 	, sel_drawBackgroundForGlyphRange_atPoint_("drawBackgroundForGlyphRange:atPoint:")
 	, sel_drawBackgroundInClipRect_("drawBackgroundInClipRect:")
 	, sel_drawBezelWithFrame_inView_("drawBezelWithFrame:inView:")
@@ -473,9 +426,9 @@ public enum Selector {
 	, sel_endDocument("endDocument")
 	, sel_endEditing("endEditing")
 	, sel_endEditingFor_("endEditingFor:")
-	, sel_endGestureWithEvent_("endGestureWithEvent:")
 	, sel_endPage("endPage")
 	, sel_endSheet_returnCode_("endSheet:returnCode:")
+	, sel_endUndoGrouping("endUndoGrouping")
 	, sel_enterExitEventWithType_location_modifierFlags_timestamp_windowNumber_context_eventNumber_trackingNumber_userData_("enterExitEventWithType:location:modifierFlags:timestamp:windowNumber:context:eventNumber:trackingNumber:userData:")
 	, sel_enumeratorAtPath_("enumeratorAtPath:")
 	, sel_expandItem_("expandItem:")
@@ -485,17 +438,16 @@ public enum Selector {
 	, sel_fieldEditor_forObject_("fieldEditor:forObject:")
 	, sel_fileExistsAtPath_("fileExistsAtPath:")
 	, sel_fileExistsAtPath_isDirectory_("fileExistsAtPath:isDirectory:")
-	, sel_fileSystemRepresentation("fileSystemRepresentation")
 	, sel_fileURLWithPath_("fileURLWithPath:")
 	, sel_filename("filename")
 	, sel_filenames("filenames")
 	, sel_fill("fill")
 	, sel_fillRect_("fillRect:")
 	, sel_finishLaunching("finishLaunching")
-	, sel_firstIndex("firstIndex")
 	, sel_firstRectForCharacterRange_("firstRectForCharacterRange:")
 	, sel_firstResponder("firstResponder")
 	, sel_flagsChanged_("flagsChanged:")
+	, sel_flashScrollers("flashScrollers")
 	, sel_floatValue("floatValue")
 	, sel_flushBuffer("flushBuffer")
 	, sel_flushGraphics("flushGraphics")
@@ -503,26 +455,22 @@ public enum Selector {
 	, sel_focusRingMaskBoundsForFrame_inView_("focusRingMaskBoundsForFrame:inView:")
 	, sel_font("font")
 	, sel_fontName("fontName")
-	, sel_fontWithFamily_traits_weight_size_("fontWithFamily:traits:weight:size:")
 	, sel_fontWithName_size_("fontWithName:size:")
 	, sel_frame("frame")
 	, sel_frameOfCellAtColumn_row_("frameOfCellAtColumn:row:")
 	, sel_frameOfOutlineCellAtRow_("frameOfOutlineCellAtRow:")
 	, sel_frameRectForContentRect_("frameRectForContentRect:")
 	, sel_frameSizeForContentSize_hasHorizontalScroller_hasVerticalScroller_borderType_("frameSizeForContentSize:hasHorizontalScroller:hasVerticalScroller:borderType:")
+	, sel_frameSizeForContentSize_horizontalScrollerClass_verticalScrollerClass_borderType_controlSize_scrollerStyle_("frameSizeForContentSize:horizontalScrollerClass:verticalScrollerClass:borderType:controlSize:scrollerStyle:")
 	, sel_fullPathForApplication_("fullPathForApplication:")
 	, sel_generalPasteboard("generalPasteboard")
-	, sel_genericRGBColorSpace("genericRGBColorSpace")
-	, sel_getBitmapDataPlanes_("getBitmapDataPlanes:")
 	, sel_getBytes_("getBytes:")
-	, sel_getBytes_length_("getBytes:length:")
 	, sel_getCharacters_("getCharacters:")
 	, sel_getCharacters_range_("getCharacters:range:")
 	, sel_getComponents_("getComponents:")
 	, sel_getGlyphs_range_("getGlyphs:range:")
 	, sel_getGlyphsInRange_glyphs_characterIndexes_glyphInscriptions_elasticBits_bidiLevels_("getGlyphsInRange:glyphs:characterIndexes:glyphInscriptions:elasticBits:bidiLevels:")
 	, sel_getIndexes_maxCount_inIndexRange_("getIndexes:maxCount:inIndexRange:")
-	, sel_getInfoForFile_application_type_("getInfoForFile:application:type:")
 	, sel_getValues_forAttribute_forVirtualScreen_("getValues:forAttribute:forVirtualScreen:")
 	, sel_globalContext("globalContext")
 	, sel_glyphIndexForCharacterAtIndex_("glyphIndexForCharacterAtIndex:")
@@ -549,17 +497,13 @@ public enum Selector {
 	, sel_helpRequested_("helpRequested:")
 	, sel_hide_("hide:")
 	, sel_hideOtherApplications_("hideOtherApplications:")
-	, sel_highlightColorInView_("highlightColorInView:")
-	, sel_highlightColorWithFrame_inView_("highlightColorWithFrame:inView:")
 	, sel_highlightSelectionInClipRect_("highlightSelectionInClipRect:")
 	, sel_hitPart("hitPart")
 	, sel_hitTest_("hitTest:")
 	, sel_hitTestForEvent_inRect_ofView_("hitTestForEvent:inRect:ofView:")
 	, sel_host("host")
-	, sel_hotSpot("hotSpot")
 	, sel_hourOfDay("hourOfDay")
 	, sel_iconForFile_("iconForFile:")
-	, sel_iconForFileType_("iconForFileType:")
 	, sel_ignore("ignore")
 	, sel_ignoreModifierKeysWhileDragging("ignoreModifierKeysWhileDragging")
 	, sel_image("image")
@@ -567,21 +511,18 @@ public enum Selector {
 	, sel_imageNamed_("imageNamed:")
 	, sel_imageRectForBounds_("imageRectForBounds:")
 	, sel_imageRepWithContentsOfFile_("imageRepWithContentsOfFile:")
-	, sel_imageRepWithData_("imageRepWithData:")
 	, sel_imageablePageBounds("imageablePageBounds")
 	, sel_increment("increment")
 	, sel_indentationPerLevel("indentationPerLevel")
 	, sel_indexOfItemWithTarget_andAction_("indexOfItemWithTarget:andAction:")
 	, sel_indexOfObjectIdenticalTo_("indexOfObjectIdenticalTo:")
 	, sel_indexOfSelectedItem("indexOfSelectedItem")
-	, sel_indexSetWithIndex_("indexSetWithIndex:")
 	, sel_infoDictionary("infoDictionary")
 	, sel_init("init")
 	, sel_initByReferencingFile_("initByReferencingFile:")
 	, sel_initListDescriptor("initListDescriptor")
 	, sel_initWithAttributes_("initWithAttributes:")
 	, sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bitmapFormat_bytesPerRow_bitsPerPixel_("initWithBitmapDataPlanes:pixelsWide:pixelsHigh:bitsPerSample:samplesPerPixel:hasAlpha:isPlanar:colorSpaceName:bitmapFormat:bytesPerRow:bitsPerPixel:")
-	, sel_initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_("initWithBitmapDataPlanes:pixelsWide:pixelsHigh:bitsPerSample:samplesPerPixel:hasAlpha:isPlanar:colorSpaceName:bytesPerRow:bitsPerPixel:")
 	, sel_initWithCapacity_("initWithCapacity:")
 	, sel_initWithCharacters_length_("initWithCharacters:length:")
 	, sel_initWithColors_("initWithColors:")
@@ -590,9 +531,7 @@ public enum Selector {
 	, sel_initWithContentRect_styleMask_backing_defer_screen_("initWithContentRect:styleMask:backing:defer:screen:")
 	, sel_initWithContentsOfFile_("initWithContentsOfFile:")
 	, sel_initWithData_("initWithData:")
-	, sel_initWithDictionary_("initWithDictionary:")
 	, sel_initWithFileWrapper_("initWithFileWrapper:")
-	, sel_initWithFocusedViewRect_("initWithFocusedViewRect:")
 	, sel_initWithFormat_shareContext_("initWithFormat:shareContext:")
 	, sel_initWithFrame_("initWithFrame:")
 	, sel_initWithFrame_frameName_groupName_("initWithFrame:frameName:groupName:")
@@ -601,12 +540,10 @@ public enum Selector {
 	, sel_initWithIdentifier_("initWithIdentifier:")
 	, sel_initWithImage_hotSpot_("initWithImage:hotSpot:")
 	, sel_initWithIndex_("initWithIndex:")
-	, sel_initWithIndexSet_("initWithIndexSet:")
 	, sel_initWithIndexesInRange_("initWithIndexesInRange:")
 	, sel_initWithItemIdentifier_("initWithItemIdentifier:")
 	, sel_initWithLocaleIdentifier_("initWithLocaleIdentifier:")
 	, sel_initWithName_("initWithName:")
-	, sel_initWithRect_options_owner_userInfo_("initWithRect:options:owner:userInfo:")
 	, sel_initWithSize_("initWithSize:")
 	, sel_initWithStartingColor_endingColor_("initWithStartingColor:endingColor:")
 	, sel_initWithString_("initWithString:")
@@ -615,13 +552,13 @@ public enum Selector {
 	, sel_initWithTitle_action_keyEquivalent_("initWithTitle:action:keyEquivalent:")
 	, sel_initWithTransform_("initWithTransform:")
 	, sel_initWithType_location_("initWithType:location:")
-	, sel_initWithURL_("initWithURL:")
 	, sel_insertColor_key_atIndex_("insertColor:key:atIndex:")
 	, sel_insertItem_atIndex_("insertItem:atIndex:")
 	, sel_insertItemWithItemIdentifier_atIndex_("insertItemWithItemIdentifier:atIndex:")
 	, sel_insertItemWithObjectValue_atIndex_("insertItemWithObjectValue:atIndex:")
 	, sel_insertTabViewItem_atIndex_("insertTabViewItem:atIndex:")
 	, sel_insertText_("insertText:")
+	, sel_insertText_replacementRange_("insertText:replacementRange:")
 	, sel_intValue("intValue")
 	, sel_integerValue("integerValue")
 	, sel_intercellSpacing("intercellSpacing")
@@ -630,13 +567,13 @@ public enum Selector {
 	, sel_invalidateShadow("invalidateShadow")
 	, sel_invert("invert")
 	, sel_isActive("isActive")
+	, sel_isCompatibleWithOverlayScrollers("isCompatibleWithOverlayScrollers")
 	, sel_isDescendantOf_("isDescendantOf:")
 	, sel_isDocumentEdited("isDocumentEdited")
 	, sel_isDrawingToScreen("isDrawingToScreen")
 	, sel_isEmpty("isEmpty")
 	, sel_isEnabled("isEnabled")
 	, sel_isEqual_("isEqual:")
-	, sel_isEqualTo_("isEqualTo:")
 	, sel_isEqualToString_("isEqualToString:")
 	, sel_isExecutableFileAtPath_("isExecutableFileAtPath:")
 	, sel_isFieldEditor("isFieldEditor")
@@ -684,7 +621,6 @@ public enum Selector {
 	, sel_layoutManager("layoutManager")
 	, sel_leading("leading")
 	, sel_length("length")
-	, sel_level("level")
 	, sel_levelForItem_("levelForItem:")
 	, sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_("lineFragmentUsedRectForGlyphAtIndex:effectiveRange:")
 	, sel_lineFragmentUsedRectForGlyphAtIndex_effectiveRange_withoutAdditionalLayout_("lineFragmentUsedRectForGlyphAtIndex:effectiveRange:withoutAdditionalLayout:")
@@ -694,7 +630,6 @@ public enum Selector {
 	, sel_loadNibFile_externalNameTable_withZone_("loadNibFile:externalNameTable:withZone:")
 	, sel_loadRequest_("loadRequest:")
 	, sel_localizedDescription("localizedDescription")
-	, sel_location("location")
 	, sel_locationForGlyphAtIndex_("locationForGlyphAtIndex:")
 	, sel_locationInWindow("locationInWindow")
 	, sel_lockFocus("lockFocus")
@@ -705,23 +640,17 @@ public enum Selector {
 	, sel_mainBundle("mainBundle")
 	, sel_mainFrame("mainFrame")
 	, sel_mainMenu("mainMenu")
-	, sel_mainRunLoop("mainRunLoop")
 	, sel_mainScreen("mainScreen")
-	, sel_mainWindow("mainWindow")
 	, sel_makeCurrentContext("makeCurrentContext")
 	, sel_makeFirstResponder_("makeFirstResponder:")
 	, sel_makeKeyAndOrderFront_("makeKeyAndOrderFront:")
 	, sel_markedRange("markedRange")
 	, sel_markedTextAttributes("markedTextAttributes")
 	, sel_maxValue("maxValue")
-	, sel_maximum("maximum")
-	, sel_maximumFractionDigits("maximumFractionDigits")
-	, sel_maximumIntegerDigits("maximumIntegerDigits")
 	, sel_menu("menu")
 	, sel_menu_willHighlightItem_("menu:willHighlightItem:")
 	, sel_menuBarFontOfSize_("menuBarFontOfSize:")
 	, sel_menuDidClose_("menuDidClose:")
-	, sel_menuFontOfSize_("menuFontOfSize:")
 	, sel_menuForEvent_("menuForEvent:")
 	, sel_menuNeedsUpdate_("menuNeedsUpdate:")
 	, sel_menuWillOpen_("menuWillOpen:")
@@ -730,7 +659,6 @@ public enum Selector {
 	, sel_minSize("minSize")
 	, sel_minValue("minValue")
 	, sel_miniaturize_("miniaturize:")
-	, sel_minimum("minimum")
 	, sel_minimumSize("minimumSize")
 	, sel_minuteOfHour("minuteOfHour")
 	, sel_modifierFlags("modifierFlags")
@@ -746,12 +674,8 @@ public enum Selector {
 	, sel_mouseMoved_("mouseMoved:")
 	, sel_mouseUp_("mouseUp:")
 	, sel_moveColumn_toColumn_("moveColumn:toColumn:")
-	, sel_moveToBeginningOfParagraph_("moveToBeginningOfParagraph:")
-	, sel_moveToEndOfParagraph_("moveToEndOfParagraph:")
 	, sel_moveToPoint_("moveToPoint:")
-	, sel_moveUp_("moveUp:")
 	, sel_mutableCopy("mutableCopy")
-	, sel_mutableString("mutableString")
 	, sel_name("name")
 	, sel_nameFieldStringValue("nameFieldStringValue")
 	, sel_needsPanelToBecomeKey("needsPanelToBecomeKey")
@@ -766,7 +690,6 @@ public enum Selector {
 	, sel_numberOfComponents("numberOfComponents")
 	, sel_numberOfGlyphs("numberOfGlyphs")
 	, sel_numberOfItems("numberOfItems")
-	, sel_numberOfPlanes("numberOfPlanes")
 	, sel_numberOfRows("numberOfRows")
 	, sel_numberOfRowsInTableView_("numberOfRowsInTableView:")
 	, sel_numberOfSelectedRows("numberOfSelectedRows")
@@ -782,7 +705,6 @@ public enum Selector {
 	, sel_objectForInfoDictionaryKey_("objectForInfoDictionaryKey:")
 	, sel_objectForKey_("objectForKey:")
 	, sel_objectValues("objectValues")
-	, sel_openFile_withApplication_("openFile:withApplication:")
 	, sel_openPanel("openPanel")
 	, sel_openURL_("openURL:")
 	, sel_openURLs_withAppBundleIdentifier_options_additionalEventParamDescriptor_launchIdentifiers_("openURLs:withAppBundleIdentifier:options:additionalEventParamDescriptor:launchIdentifiers:")
@@ -795,12 +717,10 @@ public enum Selector {
 	, sel_orderFrontStandardAboutPanel_("orderFrontStandardAboutPanel:")
 	, sel_orderOut_("orderOut:")
 	, sel_orderWindow_relativeTo_("orderWindow:relativeTo:")
-	, sel_orderedWindows("orderedWindows")
 	, sel_otherEventWithType_location_modifierFlags_timestamp_windowNumber_context_subtype_data1_data2_("otherEventWithType:location:modifierFlags:timestamp:windowNumber:context:subtype:data1:data2:")
 	, sel_otherMouseDown_("otherMouseDown:")
 	, sel_otherMouseDragged_("otherMouseDragged:")
 	, sel_otherMouseUp_("otherMouseUp:")
-	, sel_outlineTableColumn("outlineTableColumn")
 	, sel_outlineView_acceptDrop_item_childIndex_("outlineView:acceptDrop:item:childIndex:")
 	, sel_outlineView_child_ofItem_("outlineView:child:ofItem:")
 	, sel_outlineView_didClickTableColumn_("outlineView:didClickTableColumn:")
@@ -808,18 +728,15 @@ public enum Selector {
 	, sel_outlineView_numberOfChildrenOfItem_("outlineView:numberOfChildrenOfItem:")
 	, sel_outlineView_objectValueForTableColumn_byItem_("outlineView:objectValueForTableColumn:byItem:")
 	, sel_outlineView_setObjectValue_forTableColumn_byItem_("outlineView:setObjectValue:forTableColumn:byItem:")
-	, sel_outlineView_shouldCollapseItem_("outlineView:shouldCollapseItem:")
 	, sel_outlineView_shouldEditTableColumn_item_("outlineView:shouldEditTableColumn:item:")
 	, sel_outlineView_shouldExpandItem_("outlineView:shouldExpandItem:")
 	, sel_outlineView_shouldReorderColumn_toColumn_("outlineView:shouldReorderColumn:toColumn:")
-	, sel_outlineView_shouldSelectItem_("outlineView:shouldSelectItem:")
 	, sel_outlineView_shouldTrackCell_forTableColumn_item_("outlineView:shouldTrackCell:forTableColumn:item:")
 	, sel_outlineView_validateDrop_proposedItem_proposedChildIndex_("outlineView:validateDrop:proposedItem:proposedChildIndex:")
 	, sel_outlineView_willDisplayCell_forTableColumn_item_("outlineView:willDisplayCell:forTableColumn:item:")
 	, sel_outlineView_writeItems_toPasteboard_("outlineView:writeItems:toPasteboard:")
 	, sel_outlineViewColumnDidMove_("outlineViewColumnDidMove:")
 	, sel_outlineViewColumnDidResize_("outlineViewColumnDidResize:")
-	, sel_outlineViewItemDidExpand_("outlineViewItemDidExpand:")
 	, sel_outlineViewSelectionDidChange_("outlineViewSelectionDidChange:")
 	, sel_outlineViewSelectionIsChanging_("outlineViewSelectionIsChanging:")
 	, sel_owner("owner")
@@ -864,7 +781,6 @@ public enum Selector {
 	, sel_printOperationWithPrintInfo_("printOperationWithPrintInfo:")
 	, sel_printOperationWithView_printInfo_("printOperationWithView:printInfo:")
 	, sel_printPanel("printPanel")
-	, sel_printSettings("printSettings")
 	, sel_printer("printer")
 	, sel_printerNames("printerNames")
 	, sel_printerWithName_("printerWithName:")
@@ -897,17 +813,14 @@ public enum Selector {
 	, sel_removeChildWindow_("removeChildWindow:")
 	, sel_removeColorWithKey_("removeColorWithKey:")
 	, sel_removeFromSuperview("removeFromSuperview")
-	, sel_removeIndex_("removeIndex:")
 	, sel_removeItem_("removeItem:")
 	, sel_removeItemAtIndex_("removeItemAtIndex:")
-	, sel_removeItemAtPath_error_("removeItemAtPath:error:")
 	, sel_removeLastObject("removeLastObject")
 	, sel_removeObject_("removeObject:")
 	, sel_removeObjectAtIndex_("removeObjectAtIndex:")
 	, sel_removeObjectForKey_("removeObjectForKey:")
 	, sel_removeObjectIdenticalTo_("removeObjectIdenticalTo:")
 	, sel_removeObserver_("removeObserver:")
-	, sel_removeObserver_name_object_("removeObserver:name:object:")
 	, sel_removeRepresentation_("removeRepresentation:")
 	, sel_removeStatusItem_("removeStatusItem:")
 	, sel_removeTabViewItem_("removeTabViewItem:")
@@ -930,7 +843,6 @@ public enum Selector {
 	, sel_resizeUpCursor("resizeUpCursor")
 	, sel_resizeUpDownCursor("resizeUpDownCursor")
 	, sel_resizingMask("resizingMask")
-	, sel_resourcePath("resourcePath")
 	, sel_respondsToSelector_("respondsToSelector:")
 	, sel_restoreGraphicsState("restoreGraphicsState")
 	, sel_retain("retain")
@@ -944,8 +856,6 @@ public enum Selector {
 	, sel_rowAtPoint_("rowAtPoint:")
 	, sel_rowForItem_("rowForItem:")
 	, sel_rowHeight("rowHeight")
-	, sel_rowsInRect_("rowsInRect:")
-	, sel_run("run")
 	, sel_runModal("runModal")
 	, sel_runModalForDirectory_file_("runModalForDirectory:file:")
 	, sel_runModalForWindow_("runModalForWindow:")
@@ -966,11 +876,9 @@ public enum Selector {
 	, sel_scrollPoint_("scrollPoint:")
 	, sel_scrollRangeToVisible_("scrollRangeToVisible:")
 	, sel_scrollRect_by_("scrollRect:by:")
-	, sel_scrollRectToVisible_("scrollRectToVisible:")
 	, sel_scrollRowToVisible_("scrollRowToVisible:")
-	, sel_scrollToPoint_("scrollToPoint:")
 	, sel_scrollWheel_("scrollWheel:")
-	, sel_scrollerWidth("scrollerWidth")
+	, sel_scrollerStyle("scrollerStyle")
 	, sel_scrollerWidthForControlSize_("scrollerWidthForControlSize:")
 	, sel_searchButtonCell("searchButtonCell")
 	, sel_searchButtonRectForBounds_("searchButtonRectForBounds:")
@@ -1034,7 +942,6 @@ public enum Selector {
 	, sel_setBackgroundStyle_("setBackgroundStyle:")
 	, sel_setBadgeLabel_("setBadgeLabel:")
 	, sel_setBaseWritingDirection_("setBaseWritingDirection:")
-	, sel_setBaseWritingDirection_range_("setBaseWritingDirection:range:")
 	, sel_setBecomesKeyOnlyIfNeeded_("setBecomesKeyOnlyIfNeeded:")
 	, sel_setBezelStyle_("setBezelStyle:")
 	, sel_setBezeled_("setBezeled:")
@@ -1042,6 +949,7 @@ public enum Selector {
 	, sel_setBorderWidth_("setBorderWidth:")
 	, sel_setBordered_("setBordered:")
 	, sel_setBoundsRotation_("setBoundsRotation:")
+	, sel_setBoundsSize_("setBoundsSize:")
 	, sel_setBoxType_("setBoxType:")
 	, sel_setButtonType_("setButtonType:")
 	, sel_setCacheMode_("setCacheMode:")
@@ -1094,7 +1002,6 @@ public enum Selector {
 	, sel_setDropRow_dropOperation_("setDropRow:dropOperation:")
 	, sel_setEditable_("setEditable:")
 	, sel_setEnabled_("setEnabled:")
-	, sel_setEnabled_forSegment_("setEnabled:forSegment:")
 	, sel_setFill("setFill")
 	, sel_setFillColor_("setFillColor:")
 	, sel_setFireDate_("setFireDate:")
@@ -1132,7 +1039,6 @@ public enum Selector {
 	, sel_setIcon_("setIcon:")
 	, sel_setIdentifier_("setIdentifier:")
 	, sel_setImage_("setImage:")
-	, sel_setImage_forSegment_("setImage:forSegment:")
 	, sel_setImageAlignment_("setImageAlignment:")
 	, sel_setImageInterpolation_("setImageInterpolation:")
 	, sel_setImagePosition_("setImagePosition:")
@@ -1150,15 +1056,12 @@ public enum Selector {
 	, sel_setKeyEquivalentModifierMask_("setKeyEquivalentModifierMask:")
 	, sel_setKnobProportion_("setKnobProportion:")
 	, sel_setLabel_("setLabel:")
-	, sel_setLabel_forSegment_("setLabel:forSegment:")
-	, sel_setLeaf_("setLeaf:")
 	, sel_setLength_("setLength:")
 	, sel_setLevel_("setLevel:")
 	, sel_setLineBreakMode_("setLineBreakMode:")
 	, sel_setLineCapStyle_("setLineCapStyle:")
 	, sel_setLineDash_count_phase_("setLineDash:count:phase:")
 	, sel_setLineFragmentPadding_("setLineFragmentPadding:")
-	, sel_setLineFragmentRect_forGlyphRange_usedRect_("setLineFragmentRect:forGlyphRange:usedRect:")
 	, sel_setLineJoinStyle_("setLineJoinStyle:")
 	, sel_setLineSpacing_("setLineSpacing:")
 	, sel_setLineWidth_("setLineWidth:")
@@ -1171,7 +1074,6 @@ public enum Selector {
 	, sel_setMaximumFractionDigits_("setMaximumFractionDigits:")
 	, sel_setMaximumIntegerDigits_("setMaximumIntegerDigits:")
 	, sel_setMenu_("setMenu:")
-	, sel_setMenu_forSegment_("setMenu:forSegment:")
 	, sel_setMenuFormRepresentation_("setMenuFormRepresentation:")
 	, sel_setMessage_("setMessage:")
 	, sel_setMessageText_("setMessageText:")
@@ -1214,13 +1116,9 @@ public enum Selector {
 	, sel_setScalesWhenResized_("setScalesWhenResized:")
 	, sel_setScrollable_("setScrollable:")
 	, sel_setSearchButtonCell_("setSearchButtonCell:")
-	, sel_setSegmentCount_("setSegmentCount:")
-	, sel_setSegmentStyle_("setSegmentStyle:")
 	, sel_setSelectable_("setSelectable:")
-	, sel_setSelected_forSegment_("setSelected:forSegment:")
 	, sel_setSelectedItemIdentifier_("setSelectedItemIdentifier:")
 	, sel_setSelectedRange_("setSelectedRange:")
-	, sel_setSelectedSegment_("setSelectedSegment:")
 	, sel_setSelectedTextAttributes_("setSelectedTextAttributes:")
 	, sel_setSelectionOnly_("setSelectionOnly:")
 	, sel_setServicesMenu_("setServicesMenu:")
@@ -1241,7 +1139,6 @@ public enum Selector {
 	, sel_setTabStops_("setTabStops:")
 	, sel_setTabViewType_("setTabViewType:")
 	, sel_setTag_("setTag:")
-	, sel_setTag_forSegment_("setTag:forSegment:")
 	, sel_setTarget_("setTarget:")
 	, sel_setTextColor_("setTextColor:")
 	, sel_setTextStorage_("setTextStorage:")
@@ -1249,9 +1146,7 @@ public enum Selector {
 	, sel_setTitleFont_("setTitleFont:")
 	, sel_setTitlePosition_("setTitlePosition:")
 	, sel_setToolTip_("setToolTip:")
-	, sel_setToolTip_forSegment_("setToolTip:forSegment:")
 	, sel_setToolbar_("setToolbar:")
-	, sel_setTrackingMode_("setTrackingMode:")
 	, sel_setTransformStruct_("setTransformStruct:")
 	, sel_setTreatsFilePackagesAsDirectories_("setTreatsFilePackagesAsDirectories:")
 	, sel_setUIDelegate_("setUIDelegate:")
@@ -1272,7 +1167,6 @@ public enum Selector {
 	, sel_setVisible_("setVisible:")
 	, sel_setWantsRestingTouches_("setWantsRestingTouches:")
 	, sel_setWidth_("setWidth:")
-	, sel_setWidth_forSegment_("setWidth:forSegment:")
 	, sel_setWidthTracksTextView_("setWidthTracksTextView:")
 	, sel_setWindingRule_("setWindingRule:")
 	, sel_setWorksWhenModal_("setWorksWhenModal:")
@@ -1299,12 +1193,10 @@ public enum Selector {
 	, sel_sortIndicatorRectForBounds_("sortIndicatorRectForBounds:")
 	, sel_standardPreferences("standardPreferences")
 	, sel_standardUserDefaults("standardUserDefaults")
-	, sel_standardWindowButton_("standardWindowButton:")
 	, sel_startAnimation_("startAnimation:")
 	, sel_state("state")
 	, sel_statusItemWithLength_("statusItemWithLength:")
 	, sel_stop_("stop:")
-	, sel_stopAnimation_("stopAnimation:")
 	, sel_stopLoading_("stopLoading:")
 	, sel_stopModal("stopModal")
 	, sel_string("string")
@@ -1335,10 +1227,7 @@ public enum Selector {
 	, sel_systemFontSizeForControlSize_("systemFontSizeForControlSize:")
 	, sel_systemStatusBar("systemStatusBar")
 	, sel_systemVersion("systemVersion")
-	, sel_tabStopType("tabStopType")
-	, sel_tabStops("tabStops")
 	, sel_tabView_didSelectTabViewItem_("tabView:didSelectTabViewItem:")
-	, sel_tabView_shouldSelectTabViewItem_("tabView:shouldSelectTabViewItem:")
 	, sel_tabView_willSelectTabViewItem_("tabView:willSelectTabViewItem:")
 	, sel_tabViewItemAtPoint_("tabViewItemAtPoint:")
 	, sel_tableColumns("tableColumns")
@@ -1348,7 +1237,6 @@ public enum Selector {
 	, sel_tableView_setObjectValue_forTableColumn_row_("tableView:setObjectValue:forTableColumn:row:")
 	, sel_tableView_shouldEditTableColumn_row_("tableView:shouldEditTableColumn:row:")
 	, sel_tableView_shouldReorderColumn_toColumn_("tableView:shouldReorderColumn:toColumn:")
-	, sel_tableView_shouldSelectRow_("tableView:shouldSelectRow:")
 	, sel_tableView_shouldTrackCell_forTableColumn_row_("tableView:shouldTrackCell:forTableColumn:row:")
 	, sel_tableView_validateDrop_proposedRow_proposedDropOperation_("tableView:validateDrop:proposedRow:proposedDropOperation:")
 	, sel_tableView_willDisplayCell_forTableColumn_row_("tableView:willDisplayCell:forTableColumn:row:")
@@ -1380,14 +1268,12 @@ public enum Selector {
 	, sel_titleFont("titleFont")
 	, sel_titleOfSelectedItem("titleOfSelectedItem")
 	, sel_titleRectForBounds_("titleRectForBounds:")
-	, sel_toggleToolbarShown_("toggleToolbarShown:")
+	, sel_toggleFullScreen_("toggleFullScreen:")
 	, sel_toolbar("toolbar")
 	, sel_toolbar_itemForItemIdentifier_willBeInsertedIntoToolbar_("toolbar:itemForItemIdentifier:willBeInsertedIntoToolbar:")
 	, sel_toolbarAllowedItemIdentifiers_("toolbarAllowedItemIdentifiers:")
 	, sel_toolbarDefaultItemIdentifiers_("toolbarDefaultItemIdentifiers:")
-	, sel_toolbarDidRemoveItem_("toolbarDidRemoveItem:")
 	, sel_toolbarSelectableItemIdentifiers_("toolbarSelectableItemIdentifiers:")
-	, sel_toolbarWillAddItem_("toolbarWillAddItem:")
 	, sel_touchesBeganWithEvent_("touchesBeganWithEvent:")
 	, sel_touchesCancelledWithEvent_("touchesCancelledWithEvent:")
 	, sel_touchesEndedWithEvent_("touchesEndedWithEvent:")
@@ -1479,7 +1365,6 @@ public enum Selector {
 	, sel_webViewFocus_("webViewFocus:")
 	, sel_webViewShow_("webViewShow:")
 	, sel_webViewUnfocus_("webViewUnfocus:")
-	, sel_weightOfFont_("weightOfFont:")
 	, sel_wheelDelta("wheelDelta")
 	, sel_wheelDeltaX("wheelDeltaX")
 	, sel_wheelDeltaY("wheelDeltaY")
@@ -1492,17 +1377,13 @@ public enum Selector {
 	, sel_windowDidMove_("windowDidMove:")
 	, sel_windowDidResignKey_("windowDidResignKey:")
 	, sel_windowDidResize_("windowDidResize:")
-	, sel_windowFrameColor("windowFrameColor")
 	, sel_windowFrameTextColor("windowFrameTextColor")
 	, sel_windowNumber("windowNumber")
 	, sel_windowNumberAtPoint_belowWindowWithWindowNumber_("windowNumberAtPoint:belowWindowWithWindowNumber:")
-	, sel_windowRef("windowRef")
 	, sel_windowShouldClose_("windowShouldClose:")
 	, sel_windowWillClose_("windowWillClose:")
 	, sel_windowWithWindowNumber_("windowWithWindowNumber:")
 	, sel_windows("windows")
-	, sel_worksWhenModal("worksWhenModal")
-	, sel_wraps("wraps")
 	, sel_writeObjects_("writeObjects:")
 	, sel_writeSelectionToPasteboard_types_("writeSelectionToPasteboard:types:")
 	, sel_yearOfCommonEra("yearOfCommonEra")
