@@ -199,7 +199,7 @@ public class GDK extends OS {
 	public static final int GDK_SELECTION_NOTIFY = 19;
 	public static final int GDK_SELECTION_REQUEST = 18;
 	public static final int GDK_SHIFT_MASK = 0x1;
-	public static final int GDK_SURFACE_STATE_ICONIFIED = 1 << 1;
+	public static final int GDK_SURFACE_STATE_MINIMIZED = 1 << 1;
 	public static final int GDK_SURFACE_STATE_MAXIMIZED = 1 << 2;
 	public static final int GDK_SURFACE_STATE_FULLSCREEN = 1 << 4;
 	public static final int GDK_Shift_L = 0xffe1;
@@ -349,10 +349,10 @@ public class GDK extends OS {
 	/* [GTK4 only, if-def'd in os.h] */
 	public static final native int gdk_surface_get_width(long surface);
 	/**
-	 * @param surface cast=(GdkSurface *)
+	 * @param toplevel cast=(GdkToplevel *)
 	 */
 	/* [GTK4 only, if-def'd in os.h] */
-	public static final native int gdk_surface_get_state(long surface);
+	public static final native int gdk_toplevel_get_state(long toplevel);
 	/**
 	 * @param window cast=(GdkWindow *)
 	 */
@@ -464,11 +464,9 @@ public class GDK extends OS {
 	public static final native long gdk_device_get_window_at_position(long device, int[] win_x, int[] win_y);
 	/**
 	 * @param device cast=(GdkDevice *)
-	 * @param win_x cast=(gint *)
-	 * @param win_y cast=(gint *)
 	 */
 	/* [GTK4 only] */
-	public static final native long gdk_device_get_surface_at_position(long device, int[] win_x, int[] win_y);
+	public static final native long gdk_device_get_surface_at_position(long device, double[] win_x, double[] win_y);
 	/**
 	 * @param display cast=(GdkDisplay *)
 	 */
@@ -501,12 +499,12 @@ public class GDK extends OS {
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_drag_status(long context, int action, int time);
+
+	/* GDK Events [GTK3 only, if-def'd in os.h] */
 	/** @param event cast=(GdkEvent *) */
 	public static final native long gdk_event_copy(long event);
 	/** @param event cast=(GdkEvent *) */
-	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_event_free(long event);
-	/* [GTK3 only, if-def'd in os.h] */
 	public static final native long gdk_event_get();
 	/**
 	 * @param event cast=(GdkEvent *)
@@ -514,23 +512,11 @@ public class GDK extends OS {
 	 * @param py cast=(gdouble *)
 	 */
 	public static final native boolean gdk_event_get_coords(long event, double[] px, double[] py);
-	/**
-	 * @param event cast=(GdkEvent *)
-	 * @param mode cast=(GdkCrossingMode *)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native boolean gdk_event_get_crossing_mode(long event, int [] mode);
 	/**
 	 * @param event cast=(GdkEvent *)
 	 * @param button cast=(guint *)
 	 */
 	public static final native boolean gdk_event_get_button(long event, int[] button);
-	/**
-	 * @param event cast=(GdkEvent *)
-	 * @param in cast=(gboolean *)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native boolean gdk_event_get_focus_in(long event, boolean [] in);
 	/**
 	 * @param event cast=(GdkEvent *)
 	 * @param keyval cast=(guint *)
@@ -541,12 +527,6 @@ public class GDK extends OS {
 	 * @param keycode cast=(guint16 *)
 	 */
 	public static final native boolean gdk_event_get_keycode(long event, short [] keycode);
-	/**
-	 * @param event cast=(GdkEvent *)
-	 * @param group cast=(guint *)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native boolean gdk_event_get_key_group(long event,int [] group);
 	/**
 	 * @param event cast=(GdkEvent *)
 	 * @param x cast=(gdouble *)
@@ -558,12 +538,6 @@ public class GDK extends OS {
 	 * @param pmod cast=(GdkModifierType *)
 	 */
 	public static final native boolean gdk_event_get_state(long event, int[] pmod);
-	/**
-	 * @param event cast=(GdkEvent *)
-	 * @param string cast=(const char **)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native boolean gdk_event_get_string(long event, long [] string);
 	/**
 	 * @param event cast=(const GdkEvent *)
 	 * @param delta_x cast=(gdouble *)
@@ -575,6 +549,38 @@ public class GDK extends OS {
 	 * @param direction cast=(GdkScrollDirection *)
 	 */
 	public static final native boolean gdk_event_get_scroll_direction(long event, int [] direction);
+
+
+	/* GDK Events (GTK4 only, if-def'd in os.h) */
+	/** @param event cast=(GdkEvent *) */
+	public static final native long gdk_event_ref(long event);
+	/** @param event cast=(GdkEvent *) */
+	public static final native void gdk_event_unref(long event);
+	/**
+	 * @param event cast=(GdkEvent *)
+	 * @param px cast=(gdouble *)
+	 * @param py cast=(gdouble *)
+	 */
+	public static final native boolean gdk_event_get_position(long event, double[] px, double[] py);
+	/** @param event cast=(GdkEvent *) */
+	public static final native int gdk_crossing_event_get_mode(long event);
+	/** @param event cast=(GdkEvent *) */
+	public static final native int gdk_button_event_get_button(long event);
+	/** @param event cast=(GdkEvent *) */
+	public static final native boolean gdk_focus_event_get_in(long event);
+	/** @param event cast=(GdkEvent *) */
+	public static final native int gdk_key_event_get_keycode(long event);
+	/** @param event cast=(GdkEvent *) */
+	public static final native int gdk_key_event_get_keyval(long event);
+	/** @param event cast=(GdkEvent *) */
+	public static final native int gdk_key_event_get_layout(long event);
+	/** @param event cast=(GdkEvent *) */
+	public static final native int gdk_event_get_modifier_state(long event);
+	/** @param event cast=(GdkEvent *) */
+	public static final native void gdk_scroll_event_get_deltas(long event, double[] delta_x, double[] delta_y);
+	/** @param event cast=(GdkEvent *) */
+	public static final native int gdk_scroll_event_get_direction(long event);
+
 	/**
 	 * @method flags=dynamic
 	 */
@@ -630,11 +636,16 @@ public class GDK extends OS {
 	/* [GTK3 only] */
 	public static final native long gdk_keymap_get_for_display(long display);
 	/**
+	 * @method flags=dynamic
 	 * @param display cast=(GdkDisplay *)
+	 * @param keyval cast=(guint)
+	 * @param keys cast=(GdkKeymapKey**)
+	 * @param n_keys cast=(gint*)
 	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native long gdk_display_get_keymap(long display);
+	/* [GTK4 only] */
+	public static final native boolean gdk_display_map_keyval(long display, int keyval, long[] keys, int[] n_keys);
 	/**
+	 * @method flags=dynamic
 	 * @param keymap cast=(GdkKeymap *)
 	 * @param hardware_keycode cast=(guint)
 	 * @param state cast=(GdkModifierType)
@@ -644,16 +655,21 @@ public class GDK extends OS {
 	 * @param level cast=(gint *)
 	 * @param consumed_modifiers cast=(GdkModifierType *)
 	 */
+	/* [GTK3 only] */
 	public static final native boolean gdk_keymap_translate_keyboard_state(long keymap, int hardware_keycode, int state, int group, int[] keyval, int[] effective_group, int[] level,  int[] consumed_modifiers);
 	/**
+	 * @method flags=dynamic
 	 * @param keymap cast=(GdkKeymap*)
 	 * @param keyval cast=(guint)
 	 * @param keys cast=(GdkKeymapKey**)
 	 * @param n_keys cast=(gint*)
 	 */
+	/* [GTK3 only] */
 	public static final native boolean gdk_keymap_get_entries_for_keyval(long keymap, int keyval, long [] keys, int[] n_keys);
 	public static final native long gdk_keyval_to_lower(long keyval);
 	public static final native long gdk_keyval_to_unicode(long keyval);
+	/** @param keyval cast=(guint) */
+	public static final native long gdk_keyval_name(int keyval);
 	/**
 	 * @method flags=dynamic
 	 */
@@ -876,7 +892,7 @@ public class GDK extends OS {
 	public static final native long gdk_display_peek_event(long display);
 	/**
 	 * @param display cast=(GdkDisplay *)
-	 * @param event cast=(const GdkEvent *)
+	 * @param event cast=(GdkEvent *)
 	 */
 	public static final native void gdk_display_put_event(long display, long event);
 	/**
@@ -1017,30 +1033,21 @@ public class GDK extends OS {
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native long gdk_window_get_children(long window);
-	/** @param surface cast=(GdkSurface *) */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native long gdk_surface_get_children(long surface);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native int gdk_window_get_events(long window);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_focus(long window, int timestamp);
-	/** @param surface cast=(GdkSurface *) */
+	/** @param surface cast=(GdkToplevel *) */
 	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_focus(long surface, int timestamp);
+	public static final native void gdk_toplevel_focus(long surface, int timestamp);
 	/**
 	 * @param window cast=(GdkWindow *)
 	 * @param rect cast=(GdkRectangle *),flags=no_in
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_get_frame_extents(long window, GdkRectangle rect);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param rect cast=(GdkRectangle *),flags=no_in
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_get_frame_extents(long surface, GdkRectangle rect);
 	/**
 	 * @param window cast=(GdkWindow *)
 	 * @param x cast=(gint *)
@@ -1067,12 +1074,12 @@ public class GDK extends OS {
 	/**
 	 * @param surface cast=(GdkSurface *)
 	 * @param device cast=(GdkDevice *)
-	 * @param x cast=(gint *)
-	 * @param y cast=(gint *)
+	 * @param x cast=(double *)
+	 * @param y cast=(double *)
 	 * @param mask cast=(GdkModifierType *)
 	 */
 	/* [GTK4 only, if-def'd in os.h] */
-	public static final native long gdk_surface_get_device_position(long surface, long device, int[] x, int[] y, int[] mask);
+	public static final native void gdk_surface_get_device_position(long surface, long device, double[] x, double[] y, int[] mask);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native long gdk_window_get_parent(long window);
@@ -1083,25 +1090,12 @@ public class GDK extends OS {
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_get_root_origin(long window, int[] x, int[] y);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param x cast=(gint *)
-	 * @param y cast=(gint *)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_get_root_origin(long surface, int[] x, int[] y);
 	/**
 	 * @param window cast=(GdkWindow *)
 	 * @param data cast=(gpointer *)
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_get_user_data(long window, long [] data);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param data cast=(gpointer *)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_get_user_data(long surface, long [] data);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_hide(long window);
@@ -1115,12 +1109,6 @@ public class GDK extends OS {
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_invalidate_rect(long window, GdkRectangle rectangle, boolean invalidate_children);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param rectangle cast=(GdkRectangle *),flags=no_out
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_invalidate_rect(long surface, GdkRectangle rectangle);
 	/**
 	 * @param window cast=(GdkWindow *)
 	 * @param region cast=(const cairo_region_t *)
@@ -1128,24 +1116,12 @@ public class GDK extends OS {
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_invalidate_region(long window, long region, boolean invalidate_children);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param region cast=(const cairo_region_t *)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_invalidate_region(long surface, long region);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_move(long window, int x, int y);
-	/** @param surface cast=(GdkSurface *) */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_move(long surface, int x, int y);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_move_resize(long window, int x, int y, int width, int height);
-	/** @param surface cast=(GdkSurface *) */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_move_resize(long surface, int x, int y, int width, int height);
 	/**
 	 * @param parent cast=(GdkWindow *)
 	 * @param attributes flags=no_out
@@ -1153,29 +1129,32 @@ public class GDK extends OS {
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native long gdk_window_new(long parent, GdkWindowAttr attributes, int attributes_mask);
 	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param rect flags=no_out
+	 * @param display cast=(GdkDisplay *)
 	 */
 	/* [GTK4 only, if-def'd in os.h] */
-	public static final native long gdk_surface_new_child(long surface, GdkRectangle rect);
+	public static final native long gdk_surface_new_toplevel(long display, int width, int height);
+	/** @param parent cast=(GdkSurface *) */
+	/* [GTK4 only, if-def'd in os.h] */
+	public static final native long gdk_surface_new_popup(long parent, boolean autohide);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_lower(long window);
-	/** @param surface cast=(GdkSurface *) */
+	/** @param toplevel cast=(GdkToplevel *) */
 	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_lower(long surface);
+	public static final native boolean gdk_toplevel_lower(long toplevel);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_raise(long window);
-	/** @param surface cast=(GdkSurface *) */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_raise(long surface);
+	/**
+	 * @method flags=dynamic
+	 * @param toplevel cast=(GdkToplevel *)
+	 * @param layout cast=(GdkToplevelLayout *)
+	 * */
+	/* [GTK4 only] */
+	public static final native boolean gdk_toplevel_present(long toplevel, int width, int height, long layout);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_resize(long window, int width, int height);
-	/** @param surface cast=(GdkSurface *) */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_resize(long surface, int width, int height);
 	/**
 	 * @param window cast=(GdkWindow *)
 	 * @param sibling cast=(GdkWindow *)
@@ -1183,13 +1162,6 @@ public class GDK extends OS {
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_restack(long window, long sibling, boolean above);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param sibling cast=(GdkSurface *)
-	 * @param above cast=(gboolean)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_restack(long surface, long sibling, boolean above);
 	/**
 	 * @param window cast=(GdkWindow *)
 	 * @param pattern cast=(cairo_pattern_t *)
@@ -1214,24 +1186,12 @@ public class GDK extends OS {
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_set_decorations(long window, int decorations);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param decorations cast=(GdkWMDecoration)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_set_decorations(long surface, int decorations);
 	/**
 	 * @param window cast=(GdkWindow *)
 	 * @param functions cast=(GdkWMFunction)
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_set_functions(long window, int functions);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param functions cast=(GdkWMFunction)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_set_functions(long surface, int functions);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_set_events(long window, int event_mask);
@@ -1247,29 +1207,37 @@ public class GDK extends OS {
 	 */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_set_user_data(long window, long user_data);
-	/**
-	 * @param surface cast=(GdkSurface *)
-	 * @param user_data cast=(gpointer)
-	 */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_set_user_data(long surface, long user_data);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_show(long window);
-	/** @param surface cast=(GdkSurface *) */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_show(long surface);
 	/** @param window cast=(GdkWindow *) */
 	/* [GTK3 only, if-def'd in os.h] */
 	public static final native void gdk_window_show_unraised(long window);
 
-	/** @param surface cast=(GdkSurface *) */
-	/* [GTK4 only, if-def'd in os.h] */
-	public static final native void gdk_surface_show_unraised(long surface);
+
+	/* GdkToplevelLayout [GTK4 only] */
+	/** @method flags=dynamic */
+	public static final native long gdk_toplevel_layout_new(int min_width, int min_height);
+
+	/* GdkPopup [GTK4 only] */
+	/** @param popup cast=(GdkPopup *) */
+	public static final native long gdk_popup_get_parent(long popup);
+	/**
+	 * @param popup cast=(GdkPopup *)
+	 * @param layout cast=(GdkPopupLayout *)
+	 */
+	public static final native boolean gdk_popup_present(long popup, int width, int height, long layout);
+
+	/* GdkPopupLayout [GTK4 only] */
+	/**
+	 * @param anchor_rect cast=(const GdkRectangle *)
+	 * @param rect_anchor cast=(GdkGravity)
+	 * @param surface_anchor cast=(GdkGravity)
+	 */
+	public static final native long gdk_popup_layout_new(GdkRectangle anchor_rect, int rect_anchor, int surface_anchor);
 
 	public static long gdk_get_pointer (long display) {
 		long default_seat = GDK.gdk_display_get_default_seat(display);
 		return GDK.gdk_seat_get_pointer(default_seat);
 	}
-
 }
