@@ -196,6 +196,7 @@ public class COM extends OS {
 	public static final int OLEEMBEDDED = 1;
 	public static final int OLELINKED = 0;
 	public static final int OLERENDER_DRAW = 1;
+	public static final int REGDB_E_CLASSNOTREG = 0x80040154;
 	public static final int S_FALSE = 1;
 	public static final int S_OK = 0;
 	public static final int STGC_DEFAULT = 0;
@@ -386,7 +387,6 @@ public static final native int OleSetClipboard(long pDataObject);
 /** @param pUnk cast=(LPUNKNOWN) */
 public static final native int OleSetContainedObject(long pUnk, boolean fContained);
 /**
- * @method flags=trycatch
  * @param holemenu cast=(HOLEMENU)
  * @param hwndFrame cast=(HWND)
  * @param hwndActiveObject cast=(HWND)
@@ -403,7 +403,7 @@ public static final native int OleTranslateColor(int clr, long hpal, int[] pcolo
 /**
  * Custom native function.
  * @param pszName cast=(PCWSTR)
- * @param ppidl cast=(PIDLIST_ABSOLUTE)
+ * @param ppidl cast=(PIDLIST_ABSOLUTE *)
  */
 public static final native int PathToPIDL (char [] pszName, long [] ppidl);
 /** @param lplpszProgID cast=(LPOLESTR *) */
@@ -456,7 +456,6 @@ public static final native void VariantInit(long pvarg);
 /** @param pStg cast=(IStorage *) */
 public static final native int WriteClassStg(long pStg, GUID rclsid);
 
-/** @method flags=trycatch */
 public static final native int VtblCall(int fnNumber, long ppVtbl);
 public static final native int VtblCall(int fnNumber, long ppVtbl, int arg0);
 public static final native int VtblCall(int fnNumber, long ppVtbl, long arg0);
@@ -658,14 +657,6 @@ public static final int IA2_SCROLL_TYPE_ANYWHERE = 6;
 /** Accessibility natives */
 
 /**
- * @method flags=dynamic
- * @param hwnd cast=(HWND)
- * @param dwObjectID cast=(DWORD)
- * @param ppvObject cast=(LPVOID *)
- */
-public static final native int AccessibleObjectFromWindow (long hwnd, int dwObjectID, GUID riid, long[] ppvObject);
-/**
- * @method flags=dynamic
  * @param hwnd cast=(HWND)
  * @param ppvObject cast=(LPVOID *)
  */
@@ -675,15 +666,6 @@ public static final native int CreateStdAccessibleObject (long hwnd, int idObjec
  * @param pAcc cast=(LPUNKNOWN)
  */
 public static final native long LresultFromObject (GUID riid, long wParam, long pAcc);
-/**
- * @method flags=dynamic
- * @param paccContainer cast=(IAccessible *)
- * @param iChildStart cast=(LONG)
- * @param cChildren cast=(LONG)
- * @param rgvarChildren cast=(VARIANT *)
- * @param pcObtained cast=(LONG *)
- */
-public static final native int AccessibleChildren(long paccContainer, int iChildStart, int cChildren, long rgvarChildren, int [] pcObtained);
 
 /* sizeof's */
 public static final native int CAUUID_sizeof();
