@@ -149,7 +149,13 @@ public static Program[] getPrograms() {
 public ImageData getImageData() {
 	if (iconPath == null) return null;
 	ImageData data = null;
-	long icon_theme =GTK.gtk_icon_theme_get_default();
+	long icon_theme;
+	if (GTK.GTK4) {
+		icon_theme = GTK.gtk_icon_theme_get_for_display(GDK.gdk_display_get_default());
+	} else {
+		icon_theme = GTK.gtk_icon_theme_get_default();
+	}
+
 	byte[] icon = Converter.wcsToMbcs (iconPath, true);
 	long gicon = OS.g_icon_new_for_string(icon, null);
 	if (gicon != 0) {
@@ -218,7 +224,7 @@ public ImageData getImageData() {
 						List<String> mimeTypes = new ArrayList<>();
 						String mimeType = line.substring(0, separatorIndex);
 						String extensionFormat = line.substring(separatorIndex + 1);
-						int extensionIndex = extensionFormat.indexOf(".");
+						int extensionIndex = extensionFormat.indexOf('.');
 						if (extensionIndex > 0) {
 							String extension = extensionFormat.substring(extensionIndex);
 							if (mimeTable.containsKey(extension)) {
