@@ -111,9 +111,7 @@ public Device(DeviceData data) {
 			tracking = data.tracking;
 		}
 		if (tracking) {
-			errors = new Error [128];
-			objects = new Object [128];
-			trackingLock = new Object ();
+			startTracking();
 		}
 		if (NSThread.isMainThread()) {
 			NSAutoreleasePool pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
@@ -134,6 +132,52 @@ public Device(DeviceData data) {
 	}
 }
 
+/**
+ *
+ * @exception SWTException <ul>
+ *    <li>ERROR_DEVICE_DISPOSED - if the receiver has been disposed</li>
+ * </ul>
+ * @since 3.115
+ */
+public boolean isTracking() {
+	checkDevice();
+	return tracking;
+}
+
+/**
+ * @exception SWTException <ul>
+ *    <li>ERROR_DEVICE_DISPOSED - if the receiver has been disposed</li>
+ * </ul>
+ * @since 3.115
+ */
+public void setTracking(boolean tracking) {
+	checkDevice();
+	if (tracking == this.tracking) {
+		return;
+	}
+	this.tracking = tracking;
+	if (tracking) {
+		startTracking();
+	} else {
+		stopTracking();
+	}
+}
+
+private void startTracking() {
+	errors = new Error [128];
+	objects = new Object [128];
+	trackingLock = new Object ();
+}
+
+private void stopTracking() {
+	synchronized (trackingLock) {
+		objects = null;
+		errors = null;
+		trackingLock = null;
+	}
+}
+
+
 /**
  * Throws an <code>SWTException</code> if the receiver can not
  * be accessed by the caller. This may include both checks on
@@ -738,22 +782,6 @@ protected void release () {
 	if (systemFont != null) systemFont.dispose();
 	systemFont = null;
 
-	if (COLOR_BLACK != null) COLOR_BLACK.dispose();
-	if (COLOR_DARK_RED != null) COLOR_DARK_RED.dispose();
-	if (COLOR_DARK_GREEN != null) COLOR_DARK_GREEN.dispose();
-	if (COLOR_DARK_YELLOW != null) COLOR_DARK_YELLOW.dispose();
-	if (COLOR_DARK_BLUE != null) COLOR_DARK_BLUE.dispose();
-	if (COLOR_DARK_MAGENTA != null) COLOR_DARK_MAGENTA.dispose();
-	if (COLOR_DARK_CYAN != null) COLOR_DARK_CYAN.dispose();
-	if (COLOR_GRAY != null) COLOR_GRAY.dispose();
-	if (COLOR_DARK_GRAY != null) COLOR_DARK_GRAY.dispose();
-	if (COLOR_RED != null) COLOR_RED.dispose();
-	if (COLOR_GREEN != null) COLOR_GREEN.dispose();
-	if (COLOR_YELLOW != null) COLOR_YELLOW.dispose();
-	if (COLOR_BLUE != null) COLOR_BLUE.dispose();
-	if (COLOR_MAGENTA != null) COLOR_MAGENTA.dispose();
-	if (COLOR_CYAN != null) COLOR_CYAN.dispose();
-	if (COLOR_WHITE != null) COLOR_WHITE.dispose();
 	COLOR_BLACK = COLOR_DARK_RED = COLOR_DARK_GREEN = COLOR_DARK_YELLOW = COLOR_DARK_BLUE =
 	COLOR_DARK_MAGENTA = COLOR_DARK_CYAN = COLOR_GRAY = COLOR_DARK_GRAY = COLOR_RED =
 	COLOR_GREEN = COLOR_YELLOW = COLOR_BLUE = COLOR_MAGENTA = COLOR_CYAN = COLOR_WHITE = null;
