@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -169,6 +169,13 @@ public final class Image extends Resource implements Drawable {
 		void init(NSImageRep nativeRep, NSBitmapImageRep rep) {
 			int width = (int)nativeRep.pixelsWide();
 			int height = (int)nativeRep.pixelsHigh();
+			/*
+			 * Intialize alphaInfo object. We may need to re intialize alpha info
+			 * when a new representation is created
+			 */
+			transparentPixel = -1;
+			alpha = -1;
+
 
 			boolean hasAlpha = rep.hasAlpha();
 			int bpr = width * 4;
@@ -1342,33 +1349,14 @@ public ImageData getImageData(int zoom) {
 	NSAutoreleasePool pool = null;
 	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
 	try {
-		boolean hasImageProvider = imageFileNameProvider != null || imageDataProvider != null;
 		if (zoom == 100) {
 			NSBitmapImageRep imageRep;
-			if (hasImageProvider) {
-				imageRep = getRepresentation_100();
-				return _getImageData(imageRep, alphaInfo_100);
-			} else {
-				imageRep = getRepresentation();
-				if (imageRep.pixelsHigh() == this.height) {
-					return _getImageData(imageRep, alphaInfo_100);
-				} else {
-					if (alphaInfo_200 == null) {
-						initAlpha_200(imageRep);
-					}
-
-					NSArray reps = handle.representations();
-					long count = reps.count();
-					for (int i = 0; i < count; i++) {
-						handle.removeRepresentation(new NSImageRep(handle.representations().objectAtIndex(0)));
-					}
-					handle.addRepresentation(imageRep);
-
-					NSSize targetSize = handle.size();
-					imageRep = createImageRep(targetSize);
-					return _getImageData(imageRep, alphaInfo_100);
-				}
+			NSSize size = handle.size();
+			imageRep = getRepresentation_100();
+			if (!((imageRep.pixelsHigh() == size.height) && (imageRep.pixelsWide() == size.width))) {
+				imageRep = createImageRep(size);
 			}
+			return _getImageData(imageRep, alphaInfo_100);
 		}
 		if (zoom == 200) {
 			NSBitmapImageRep imageRep200 = getRepresentation_200();
@@ -1509,6 +1497,27 @@ void initAlpha_200(NSBitmapImageRep nativeRep) {
 
 }
 
+void initAlpha_100(NSBitmapImageRep nativeRep) {
+	NSAutoreleasePool pool = null;
+	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
+	try {
+		int width = (int)nativeRep.pixelsWide();
+		int height = (int)nativeRep.pixelsHigh();
+
+		boolean hasAlpha = nativeRep.hasAlpha();
+		int bpr = width * 4;
+		NSBitmapImageRep rep = (NSBitmapImageRep)new NSBitmapImageRep().alloc();
+		rep = rep.initWithBitmapDataPlanes(0, width, height, 8, hasAlpha ? 4 : 3, hasAlpha, false, OS.NSDeviceRGBColorSpace, OS.NSAlphaFirstBitmapFormat | OS.NSAlphaNonpremultipliedBitmapFormat, bpr, 32);
+
+		if (alphaInfo_100 == null) alphaInfo_100 = new AlphaInfo();
+		alphaInfo_100.init(nativeRep, rep);
+		rep.release();
+	} finally {
+		if (pool != null) pool.release();
+	}
+
+}
+
 void initNative(String filename) {
 	NSAutoreleasePool pool = null;
 	NSImage nativeImage = null;
@@ -1591,10 +1600,11 @@ public long internal_new_GC (GCData data) {
 		int scaleFactor = DPIUtil.getDeviceZoom() / 100;
 		NSBitmapImageRep imageRep = getRepresentation();
 
-		// Can't perform transforms on image reps with alpha.
-		imageRep.setAlpha(false);
-
 		NSGraphicsContext context = NSGraphicsContext.graphicsContextWithBitmapImageRep(imageRep);
+		if (context == null) {
+			imageRep.setAlpha(false);
+			context = NSGraphicsContext.graphicsContextWithBitmapImageRep(imageRep);
+		}
 		NSGraphicsContext flippedContext = NSGraphicsContext.graphicsContextWithGraphicsPort(context.graphicsPort(), true);
 		context = flippedContext;
 		context.retain();
