@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -96,8 +96,10 @@ public Composite (Composite parent, int style) {
 }
 
 Control [] _getChildren () {
-	NSArray views = contentView().subviews();
-	int count = (int)/*64*/views.count();
+	NSView nsClipView = contentView();
+	if (nsClipView == null) return new Control [0];
+	NSArray views = nsClipView.subviews();
+	int count = (int)views.count();
 	Control [] children = new Control [count];
 	if (count == 0) return children;
 	int j = 0;
@@ -132,7 +134,7 @@ Control [] _getTabList () {
 }
 
 @Override
-boolean acceptsFirstMouse (long /*int*/ id, long /*int*/ sel, long /*int*/ theEvent) {
+boolean acceptsFirstMouse (long id, long sel, long theEvent) {
 	if ((state & CANVAS) != 0) {
 		return true;
 	}
@@ -140,7 +142,7 @@ boolean acceptsFirstMouse (long /*int*/ id, long /*int*/ sel, long /*int*/ theEv
 }
 
 @Override
-boolean acceptsFirstResponder (long /*int*/ id, long /*int*/ sel) {
+boolean acceptsFirstResponder (long id, long sel) {
 	if ((state & CANVAS) != 0) {
 		if ((style & SWT.NO_FOCUS) == 0 && hooksKeys ()) {
 			if (contentView().subviews().count() == 0) return true;
@@ -151,9 +153,9 @@ boolean acceptsFirstResponder (long /*int*/ id, long /*int*/ sel) {
 }
 
 @Override
-long /*int*/ accessibilityAttributeValue (long /*int*/ id, long /*int*/ sel, long /*int*/ arg0) {
+long accessibilityAttributeValue (long id, long sel, long arg0) {
 	NSString nsAttributeName = new NSString(arg0);
-	long /*int*/ superValue = super.accessibilityAttributeValue(id, sel, arg0);
+	long superValue = super.accessibilityAttributeValue(id, sel, arg0);
 
 	if ((state & CANVAS) != 0) {
 		// If this Composite has an Accessible that defined a role, return that, unless the
@@ -185,7 +187,7 @@ long /*int*/ accessibilityAttributeValue (long /*int*/ id, long /*int*/ sel, lon
 
 
 @Override
-boolean accessibilityIsIgnored(long /*int*/ id, long /*int*/ sel) {
+boolean accessibilityIsIgnored(long id, long sel) {
 	if (id == accessibleHandle()) {
 		// If a Composite or subclass has an Accessible it should not be ignored.
 		if (accessible != null) return accessible.internal_accessibilityIsIgnored(ACC.CHILDID_SELF);
@@ -347,7 +349,7 @@ public void drawBackground(GC gc, int x, int y, int width, int height, int offse
 }
 
 @Override
-void drawBackground (long /*int*/ id, NSGraphicsContext context, NSRect rect) {
+void drawBackground (long id, NSGraphicsContext context, NSRect rect) {
 	if (id != view.id) return;
 	if ((state & CANVAS) != 0) {
 		if ((style & SWT.NO_BACKGROUND) == 0) {
@@ -565,7 +567,7 @@ public boolean isLayoutDeferred () {
 }
 
 @Override
-boolean isOpaque (long /*int*/ id, long /*int*/ sel) {
+boolean isOpaque (long id, long sel) {
 	if ((state & CANVAS) != 0) {
 		if (id == view.id) {
 			return region == null && isOpaque();
@@ -594,7 +596,7 @@ boolean isTabGroup () {
 }
 
 @Override
-void keyDown (long /*int*/ id, long /*int*/ sel, long /*int*/ theEvent) {
+void keyDown (long id, long sel, long theEvent) {
 	if (hasFocus()) {
 		if ((state & CANVAS) != 0) {
 			Shell s = this.getShell();
@@ -710,7 +712,6 @@ public void layout (boolean changed) {
  * resize event will invoke the layout of the child.  Note that
  * a layout due to a resize will not flush any cached information
  * (same as <code>layout(false)</code>).
- * </p>
  * <p>
  * It is normally more efficient to invoke {@link Control#requestLayout()}
  * on every control which has changed in the layout than it is to invoke
@@ -789,6 +790,7 @@ public void layout (Control [] changed) {
  * receiver.
  * <p>
  * The parameter <code>flags</code> may be a combination of:
+ * </p>
  * <dl>
  * <dt><b>SWT.ALL</b></dt>
  * <dd>all children in the receiver's widget tree should be laid out</dd>
@@ -797,7 +799,6 @@ public void layout (Control [] changed) {
  * <dt><b>SWT.DEFER</b></dt>
  * <dd>layout will be deferred</dd>
  * </dl>
- * </p>
  * <p>
  * When the <code>changed</code> array is specified, the flags <code>SWT.ALL</code>
  * and <code>SWT.CHANGED</code> have no effect. In this case, the layouts in the
@@ -926,25 +927,25 @@ Point minimumSize (int wHint, int Hint, boolean changed) {
 }
 
 @Override
-boolean mouseEvent (long /*int*/ id, long /*int*/ sel, long /*int*/ theEvent, int type) {
+boolean mouseEvent (long id, long sel, long theEvent, int type) {
 	boolean result = super.mouseEvent (id, sel, theEvent, type);
 	return (state & CANVAS) == 0 ? result : new NSEvent (theEvent).type () != OS.NSLeftMouseDown;
 }
 
 @Override
-void pageDown(long /*int*/ id, long /*int*/ sel, long /*int*/ sender) {
+void pageDown(long id, long sel, long sender) {
 	if ((state & CANVAS) != 0) return;
 	super.pageDown(id, sel, sender);
 }
 
 @Override
-void pageUp(long /*int*/ id, long /*int*/ sel, long /*int*/ sender) {
+void pageUp(long id, long sel, long sender) {
 	if ((state & CANVAS) != 0) return;
 	super.pageUp(id, sel, sender);
 }
 
 @Override
-void reflectScrolledClipView (long /*int*/ id, long /*int*/ sel, long /*int*/ aClipView) {
+void reflectScrolledClipView (long id, long sel, long aClipView) {
 	if ((state & CANVAS) != 0) return;
 	super.reflectScrolledClipView (id, sel, aClipView);
 }
@@ -993,20 +994,18 @@ void resized () {
 }
 
 @Override
-void scrollWheel (long /*int*/ id, long /*int*/ sel, long /*int*/ theEvent) {
+void scrollWheel (long id, long sel, long theEvent) {
 	if ((state & CANVAS) != 0) {
 		NSView view = scrollView != null ? scrollView : this.view;
 		if (id == view.id) {
 			getShell().deferFlushing();
 			NSEvent nsEvent = new NSEvent(theEvent);
 			boolean handled = false;
-			double /*float*/ deltaY = nsEvent.deltaY();
-			double /*float*/ deltaX = nsEvent.deltaX ();
+			double deltaY = nsEvent.deltaY();
+			double deltaX = nsEvent.deltaX ();
 			if ((hooks(SWT.Gesture) || filters (SWT.Gesture))) {
-				if (deltaX != 0 || deltaY != 0) {
-					if (!gestureEvent(id, theEvent, SWT.GESTURE_PAN)) {
-						handled = true;
-					}
+				if (!gestureEvent(id, theEvent, SWT.GESTURE_PAN)) {
+					handled = true;
 				}
 			}
 			if (!handled) {
