@@ -29,7 +29,7 @@ import org.eclipse.swt.internal.cocoa.*;
  * Note that although this class is a subclass of <code>Composite</code>,
  * it does not make sense to add <code>Control</code> children to it,
  * or set a layout on it.
- * </p><p>
+ * </p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>FLAT, WRAP, RIGHT, HORIZONTAL, VERTICAL, SHADOW_OUT</dd>
@@ -111,7 +111,7 @@ ToolBar(Composite parent, int style, boolean internal) {
 }
 
 @Override
-long /*int*/ accessibilityAttributeValue (long /*int*/ id, long /*int*/ sel, long /*int*/ arg0) {
+long accessibilityAttributeValue (long id, long sel, long arg0) {
 	NSString nsAttributeName = new NSString(arg0);
 
 	if (id == accessibleHandle() && accessible != null) {
@@ -125,7 +125,7 @@ long /*int*/ accessibilityAttributeValue (long /*int*/ id, long /*int*/ sel, lon
 		if (nsAttributeName.isEqualToString (OS.NSAccessibilityRoleAttribute))
 			return role.id;
 		else {
-			long /*int*/ roleDescription = OS.NSAccessibilityRoleDescription(role.id, 0);
+			long roleDescription = OS.NSAccessibilityRoleDescription(role.id, 0);
 			return roleDescription;
 		}
 	} else if (nsAttributeName.isEqualToString(OS.NSAccessibilityChildrenAttribute)) {
@@ -146,7 +146,7 @@ long /*int*/ accessibilityAttributeValue (long /*int*/ id, long /*int*/ sel, lon
 }
 
 @Override
-boolean accessibilityIsIgnored(long /*int*/ id, long /*int*/ sel) {
+boolean accessibilityIsIgnored(long id, long sel) {
 	// Toolbars aren't ignored.
 	if (id == view.id) return false;
 	return super.accessibilityIsIgnored(id, sel);
@@ -243,15 +243,27 @@ void createHandle () {
 		NSWindow window = parent.view.window();
 		window.setToolbar(nsToolbar);
 		nsToolbar.setVisible(true);
+
 		NSArray views = window.contentView().superview().subviews();
-		for (int i = 0; i < views.count(); i++) {
+		int i = 0;
+		while (i < views.count()) {
 			id id = views.objectAtIndex(i);
-			if (new NSObject(id).className().getString().equals("NSToolbarView")) {
+			String className = new NSObject(id).className().getString();
+			if (className.equals("NSToolbarView")) {
 				view = new NSView(id);
 				OS.object_setClass(view.id, OS.objc_getClass("SWTToolbarView"));
 				view.retain();
 				break;
 			}
+			if (className.equals("NSTitlebarContainerView")) {
+				views = new NSView(id).subviews();
+				i = 0;
+			} else if (className.equals("NSTitlebarView")) {
+				views = new NSView(id).subviews();
+				i = 0;
+			} else {
+				i++;
+			}
 		}
 		style &= ~SWT.SMOOTH;
 	} else {
@@ -278,13 +290,13 @@ void createItem (ToolItem item, int index) {
 		System.arraycopy (items, 0, newItems, 0, items.length);
 		items = newItems;
 	}
-    item.createWidget();
+	item.createWidget();
 	System.arraycopy (items, index, items, index + 1, itemCount++ - index);
 	items [index] = item;
 	if (nsToolbar != null) {
-        nsToolbar.insertItemWithItemIdentifier(item.getItemID(), index);
+		nsToolbar.insertItemWithItemIdentifier(item.getItemID(), index);
 	} else {
-        view.addSubview(item.view);
+		view.addSubview(item.view);
 	}
 	relayout ();
 }
@@ -326,7 +338,7 @@ void destroyItem (ToolItem item) {
 }
 
 @Override
-void drawBackground (long /*int*/ id, NSGraphicsContext context, NSRect rect) {
+void drawBackground (long id, NSGraphicsContext context, NSRect rect) {
 	if (id != view.id) return;
 	if (background != null) {
 		fillBackground (view, context, rect, -1);
@@ -495,7 +507,7 @@ public int getRowCount () {
 }
 
 @Override
-boolean hasKeyboardFocus(long /*int*/ inId) {
+boolean hasKeyboardFocus(long inId) {
 	return hasFocus();
 }
 
@@ -671,11 +683,11 @@ void releaseChildren (boolean destroy) {
 
 @Override
 void releaseHandle () {
-    super.releaseHandle ();
+	super.releaseHandle ();
 
-    if (nsToolbar != null) {
-        nsToolbar.release();
-        nsToolbar = null;
+	if (nsToolbar != null) {
+		nsToolbar.release();
+		nsToolbar = null;
 	}
 
 	if (accessibilityAttributes != null) accessibilityAttributes.release();
@@ -768,12 +780,12 @@ public void setRedraw (boolean redraw) {
 
 @Override
 public void setVisible(boolean visible) {
-    if (nsToolbar != null) nsToolbar.setVisible(visible);
-    super.setVisible(visible);
+	if (nsToolbar != null) nsToolbar.setVisible(visible);
+	super.setVisible(visible);
 }
 
 @Override
-long /*int*/ toolbar_itemForItemIdentifier_willBeInsertedIntoToolbar(long /*int*/ id, long /*int*/ sel, long /*int*/ toolbar, long /*int*/ itemIdentifier, boolean flag) {
+long toolbar_itemForItemIdentifier_willBeInsertedIntoToolbar(long id, long sel, long toolbar, long itemIdentifier, boolean flag) {
 	NSString itemID = new NSString(itemIdentifier);
 	for (int j = 0; j < itemCount; j++) {
 		ToolItem item = items[j];
@@ -789,7 +801,7 @@ long /*int*/ toolbar_itemForItemIdentifier_willBeInsertedIntoToolbar(long /*int*
  * return all of the item IDs.
  */
 @Override
-long /*int*/ toolbarAllowedItemIdentifiers(long /*int*/ id, long /*int*/ sel, long /*int*/ toolbar) {
+long toolbarAllowedItemIdentifiers(long id, long sel, long toolbar) {
 	NSMutableArray array = NSMutableArray.arrayWithCapacity(itemCount);
 	for (int i = 0; i < itemCount; i++) {
 		array.addObject(items[i].nsItem.itemIdentifier());
@@ -801,7 +813,7 @@ long /*int*/ toolbarAllowedItemIdentifiers(long /*int*/ id, long /*int*/ sel, lo
  * This delegate method isn't really needed because ToolBars aren't customizable, but it's required according to the documentation.
  */
 @Override
-long /*int*/ toolbarDefaultItemIdentifiers(long /*int*/ id, long /*int*/ sel, long /*int*/ toolbar) {
+long toolbarDefaultItemIdentifiers(long id, long sel, long toolbar) {
 	return toolbarAllowedItemIdentifiers(id, sel, toolbar);
 }
 
@@ -810,7 +822,7 @@ long /*int*/ toolbarDefaultItemIdentifiers(long /*int*/ id, long /*int*/ sel, lo
  * by setSelectedItemIdentifier.
  */
 @Override
-long /*int*/ toolbarSelectableItemIdentifiers(long /*int*/ id, long /*int*/ sel, long /*int*/ toolbar) {
+long toolbarSelectableItemIdentifiers(long id, long sel, long toolbar) {
 	NSMutableArray array = NSMutableArray.arrayWithCapacity(itemCount);
 	for (int i = 0; i < itemCount; i++) {
 		if ((items[i].style & SWT.RADIO) != 0) array.addObject(items[i].nsItem.itemIdentifier());
