@@ -1738,7 +1738,7 @@ boolean setInputState (Event event, NSEvent nsEvent, int type) {
 	if ((modifierFlags & OS.NSControlKeyMask) != 0) event.stateMask |= SWT.CONTROL;
 	if ((modifierFlags & OS.NSCommandKeyMask) != 0) event.stateMask |= SWT.COMMAND;
 
-	int state = OS.GetCurrentEventButtonState ();
+	long state = NSEvent.pressedMouseButtons();
 	if ((state & 0x1) != 0) event.stateMask |= SWT.BUTTON1;
 	if ((state & 0x2) != 0) event.stateMask |= SWT.BUTTON3;
 	if ((state & 0x4) != 0) event.stateMask |= SWT.BUTTON2;
@@ -1818,7 +1818,7 @@ boolean setKeyState (Event event, int type, NSEvent nsEvent) {
 
 						int maxStringLength = 256;
 						char [] output = new char [maxStringLength];
-						int [] actualStringLength = new int [1];
+						long [] actualStringLength = new long [1];
 						int [] deadKeyState = new int[1];
 						OS.UCKeyTranslate (uchrPtr, (short)keyCode, (short)(event.type == SWT.KeyDown ? OS.kUCKeyActionDown : OS.kUCKeyActionUp), 0, (int)keyboardType, 0, deadKeyState, maxStringLength, actualStringLength, output);
 						if (actualStringLength[0] < 1) {
@@ -2080,14 +2080,6 @@ void touchesMovedWithEvent (long id, long sel, long event) {
 	callSuper(id, sel, event);
 }
 
-void beginGestureWithEvent (long id, long sel, long event) {
-	callSuper(id, sel, event);
-}
-
-void endGestureWithEvent (long id, long sel, long event) {
-	callSuper(id, sel, event);
-}
-
 void magnifyWithEvent (long id, long sel, long event) {
 	callSuper(id, sel, event);
 }
