@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -18,14 +18,13 @@ import org.eclipse.swt.*;
 import org.eclipse.swt.internal.gtk.*;
 
 /**
- * Instances of this class manage the operating system resources that
- * implement SWT's RGB color model. To create a color you can either
+ * Instances of this store color information. To create a color you can either
  * specify the individual color components as integers in the range
  * 0 to 255 or provide an instance of an <code>RGB</code> or <code>RGBA</code>.
  * <p>
- * Application code must explicitly invoke the <code>Color.dispose()</code>
- * method to release the operating system resources managed by each instance
- * when those instances are no longer required.
+ * Colors do not need to be disposed, however to maintain compatibility
+ * with older code, disposing a Color is not an error. As Colors do not require
+ * disposal, the constructors which do not require a Device are recommended.
  * </p>
  *
  * @see RGB
@@ -51,6 +50,10 @@ public final class Color extends Resource {
 	public GdkRGBA handle;
 	int alpha = 0;
 
+Color() {
+	super();
+}
+
 Color(Device device) {
 	super(device);
 }
@@ -58,14 +61,7 @@ Color(Device device) {
 /**
  * Constructs a new instance of this class given a device and the
  * desired red, green and blue values expressed as ints in the range
- * 0 to 255 (where 0 is black and 255 is full brightness). On limited
- * color devices, the color instance created by this call may not have
- * the same RGB values as the ones specified by the arguments. The
- * RGB values on the returned instance will be the color values of
- * the operating system color.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
+ * 0 to 255 (where 0 is black and 255 is full brightness).
  *
  * @param device the device on which to allocate the color
  * @param red the amount of red in the color
@@ -77,7 +73,7 @@ Color(Device device) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green or blue argument is not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(int, int, int) The equivalent constructor not requiring a Device
  */
 public Color(Device device, int red, int green, int blue) {
 	super(device);
@@ -85,17 +81,29 @@ public Color(Device device, int red, int green, int blue) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given the
+ * desired red, green and blue values expressed as ints in the range
+ * 0 to 255 (where 0 is black and 255 is full brightness).
+ *
+ * @param red the amount of red in the color
+ * @param green the amount of green in the color
+ * @param blue the amount of blue in the color
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green or blue argument is not between 0 and 255</li>
+ * </ul>
+ * @since 3.115
+ */
+public Color(int red, int green, int blue) {
+	super();
+	init(red, green, blue, 255);
+}
+
 /**
  * Constructs a new instance of this class given a device and the
  * desired red, green, blue &amp; alpha values expressed as ints in the range
- * 0 to 255 (where 0 is black and 255 is full brightness). On limited
- * color devices, the color instance created by this call may not have
- * the same RGB values as the ones specified by the arguments. The
- * RGB values on the returned instance will be the color values of
- * the operating system color.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
+ * 0 to 255 (where 0 is black and 255 is full brightness).
  *
  * @param device the device on which to allocate the color
  * @param red the amount of red in the color
@@ -108,7 +116,8 @@ public Color(Device device, int red, int green, int blue) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha argument is not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(int, int, int, int) The equivalent constructor not requiring a Device
+ *
  * @since 3.104
  */
 public Color(Device device, int red, int green, int blue, int alpha) {
@@ -117,16 +126,30 @@ public Color(Device device, int red, int green, int blue, int alpha) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given the
+ * desired red, green, blue &amp; alpha values expressed as ints in the range
+ * 0 to 255 (where 0 is black and 255 is full brightness).
+ *
+ * @param red the amount of red in the color
+ * @param green the amount of green in the color
+ * @param blue the amount of blue in the color
+ * @param alpha the amount of alpha in the color. Currently, SWT only honors extreme values for alpha i.e. 0 (transparent) or 255 (opaque).
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha argument is not between 0 and 255</li>
+ * </ul>
+ *
+ * @since 3.115
+ */
+public Color(int red, int green, int blue, int alpha) {
+	super();
+	init(red, green, blue, alpha);
+}
+
 /**
  * Constructs a new instance of this class given a device and an
  * <code>RGB</code> describing the desired red, green and blue values.
- * On limited color devices, the color instance created by this call
- * may not have the same RGB values as the ones specified by the
- * argument. The RGB values on the returned instance will be the color
- * values of the operating system color.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
  *
  * @param device the device on which to allocate the color
  * @param rgb the RGB values of the desired color
@@ -137,7 +160,7 @@ public Color(Device device, int red, int green, int blue, int alpha) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green or blue components of the argument are not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(RGB) The equivalent constructor not requiring a Device
  */
 public Color(Device device, RGB rgb) {
 	super(device);
@@ -146,16 +169,27 @@ public Color(Device device, RGB rgb) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given an
+ * <code>RGB</code> describing the desired red, green and blue values.
+ *
+ * @param rgb the RGB values of the desired color
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_NULL_ARGUMENT - if the rgb argument is null</li>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green or blue components of the argument are not between 0 and 255</li>
+ * </ul>
+ * @since 3.115
+ */
+public Color(RGB rgb) {
+	super();
+	if (rgb == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
+	init(rgb.red, rgb.green, rgb.blue, 255);
+}
+
 /**
  * Constructs a new instance of this class given a device and an
  * <code>RGBA</code> describing the desired red, green, blue &amp; alpha values.
- * On limited color devices, the color instance created by this call
- * may not have the same RGBA values as the ones specified by the
- * argument. The RGBA values on the returned instance will be the color
- * values of the operating system color + alpha.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
  *
  * @param device the device on which to allocate the color
  * @param rgba the RGBA values of the desired color. Currently, SWT only honors extreme values for alpha i.e. 0 (transparent) or 255 (opaque).
@@ -166,7 +200,8 @@ public Color(Device device, RGB rgb) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha components of the argument are not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(RGBA) The equivalent constructor not requiring a Device
+ *
  * @since 3.104
  */
 public Color(Device device, RGBA rgba) {
@@ -176,17 +211,29 @@ public Color(Device device, RGBA rgba) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given an
+ * <code>RGBA</code> describing the desired red, green, blue &amp; alpha values.
+ *
+ * @param rgba the RGBA values of the desired color. Currently, SWT only honors extreme values for alpha i.e. 0 (transparent) or 255 (opaque).
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_NULL_ARGUMENT - if the rgba argument is null</li>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha components of the argument are not between 0 and 255</li>
+ * </ul>
+ *
+ * @since 3.115
+ */
+public Color(RGBA rgba) {
+	super();
+	if (rgba == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
+	init(rgba.rgb.red, rgba.rgb.green, rgba.rgb.blue, rgba.alpha);
+}
+
 /**
  * Constructs a new instance of this class given a device, an
  * <code>RGB</code> describing the desired red, green and blue values,
  * alpha specifying the level of transparency.
- * On limited color devices, the color instance created by this call
- * may not have the same RGB values as the ones specified by the
- * argument. The RGB values on the returned instance will be the color
- * values of the operating system color.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
  *
  * @param device the device on which to allocate the color
  * @param rgb the RGB values of the desired color
@@ -198,7 +245,8 @@ public Color(Device device, RGBA rgba) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha components of the argument are not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(RGB, int) The equivalent constructor not requiring a Device
+ *
  * @since 3.104
  */
 public Color(Device device, RGB rgb, int alpha) {
@@ -208,11 +256,67 @@ public Color(Device device, RGB rgb, int alpha) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given an
+ * <code>RGB</code> describing the desired red, green and blue values,
+ * alpha specifying the level of transparency.
+ *
+ * @param rgb the RGB values of the desired color
+ * @param alpha the alpha value of the desired color. Currently, SWT only honors extreme values for alpha i.e. 0 (transparent) or 255 (opaque).
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_NULL_ARGUMENT - if the rgb argument is null</li>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha components of the argument are not between 0 and 255</li>
+ * </ul>
+ *
+ * @since 3.115
+ */
+public Color(RGB rgb, int alpha) {
+	super();
+	if (rgb == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
+	init(rgb.red, rgb.green, rgb.blue, alpha);
+}
+
 @Override
 void destroy() {
 	handle = null;
 }
 
+/**
+ * Colors do not need to be disposed, however to maintain compatibility
+ * with older code, disposing a Color is not an error.
+ */
+@Override
+public void dispose() {
+	// Does as below to maintain API contract with Resource. Does
+	// not use super.dispose() because that untracks the Color
+	// from the Device tracking, however init() is overridden
+	// to prevent the tracking in the first place.
+	destroy();
+	device = null;
+}
+
+/**
+ * Returns the <code>Device</code> where this resource was
+ * created. In cases where no <code>Device</code> was used
+ * at creation, returns the current or default Device.
+ *
+ * <p>
+ * As Color does not require a Device it is recommended to not
+ * use {@link Color#getDevice()}.
+ * </p>
+ *
+ * @return <code>Device</code> the device of the receiver
+ * @since 3.2
+ */
+@Override
+public Device getDevice() {
+	// Fall back on Device.getDevice only if we haven't been disposed
+	// already.
+	if (this.device == null && this.handle != null) return Device.getDevice();
+	return super.getDevice();
+}
+
 /**
  * Compares the argument to the receiver, and returns true
  * if they represent the <em>same</em> object using a class
@@ -230,9 +334,11 @@ public boolean equals(Object object) {
 	Color color = (Color)object;
 	GdkRGBA gdkRGBA = color.handle;
 	if (handle == gdkRGBA) return true;
-	return device == color.device && Double.compare(handle.red, gdkRGBA.red) == 0 &&
-			Double.compare(handle.green, gdkRGBA.green) == 0 && Double.compare(handle.blue, gdkRGBA.blue) == 0 &&
-			Double.compare(handle.alpha, gdkRGBA.alpha) == 0;
+	if (this.getRed() != color.getRed()) return false;
+	if (this.getGreen() != color.getGreen()) return false;
+	if (this.getBlue() != color.getBlue()) return false;
+	if (this.getAlpha() != color.getAlpha()) return false;
+	return true;
 }
 
 /**
@@ -261,7 +367,12 @@ public int getAlpha() {
  */
 public int getBlue() {
 	if (isDisposed()) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
-	return (int) (handle.blue * 255) & 0xFF;
+	/*
+	 * Conversion formula comes from Cairo's _cairo_color_double_to_short()
+	 * and color_to_pixel() functions. See bug 549181 and 549101 for more info.
+	 */
+	int b = (((int)(handle.blue * 65535.0 + 0.5)) >> 8);
+	return Math.min(b, 255);
 }
 
 /**
@@ -275,7 +386,12 @@ public int getBlue() {
  */
 public int getGreen() {
 	if (isDisposed()) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
-	return (int) (handle.green * 255) & 0xFF;
+	/*
+	 * Conversion formula comes from Cairo's _cairo_color_double_to_short()
+	 * and color_to_pixel() functions. See bug 549181 and 549101 for more info.
+	 */
+	int g = (((int)(handle.green * 65535.0 + 0.5)) >> 8);
+	return Math.min(g, 255);
 }
 
 /**
@@ -289,7 +405,12 @@ public int getGreen() {
  */
 public int getRed() {
 	if (isDisposed()) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
-	return (int) (handle.red * 255) & 0xFF;
+	/*
+	 * Conversion formula comes from Cairo's _cairo_color_double_to_short()
+	 * and color_to_pixel() functions. See bug 549181 and 549101 for more info.
+	 */
+	int r = (((int)(handle.red * 65535.0 + 0.5)) >> 8);
+	return Math.min(r, 255);
 }
 
 /**
@@ -305,8 +426,7 @@ public int getRed() {
 @Override
 public int hashCode() {
 	if (isDisposed()) return 0;
-	return Double.hashCode(handle.red) ^ Double.hashCode(handle.green) ^ Double.hashCode(handle.blue)
-			^ Double.hashCode(handle.alpha);
+	return (((this.getAlpha() * 31) + this.getGreen()) * 31 + this.getBlue()) * 31 + this.getRed();
 }
 
 /**
@@ -396,8 +516,6 @@ public static Color gtk_new(Device device, GdkRGBA gdkRGBA, int alpha) {
  * @exception IllegalArgumentException <ul>
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha argument is not between 0 and 255</li>
  * </ul>
- *
- * @see #dispose
  */
 void init(int red, int green, int blue, int alpha) {
 	if ((red > 255) || (red < 0) ||
@@ -415,6 +533,14 @@ void init(int red, int green, int blue, int alpha) {
 	handle = rgba;
 }
 
+@Override
+void init() {
+	// Resource init simply tracks this resource in the Device
+	// if DEBUG is on. Since Colors don't require disposal,
+	// the tracking would be a memory leak and a misreport
+	// on what resources are in use.
+}
+
 /**
  * Returns <code>true</code> if the color has been disposed,
  * and <code>false</code> otherwise.
