@@ -97,13 +97,6 @@ public abstract class Device implements Drawable {
 	/* Device dpi */
 	Point dpi;
 
-	/*Device Scale Factor in percentage*/
-	/**
-	 * @noreference This field is not intended to be referenced by clients.
-	 * @since 3.105
-	 */
-	protected int scaleFactor;
-
 	long emptyTab;
 
 	/*
@@ -168,9 +161,7 @@ public Device(DeviceData data) {
 			tracking = data.tracking;
 		}
 		if (tracking) {
-			errors = new Error [128];
-			objects = new Object [128];
-			trackingLock = new Object ();
+			startTracking();
 		}
 		create (data);
 		init ();
@@ -178,6 +169,51 @@ public Device(DeviceData data) {
 	}
 }
 
+/**
+ *
+ * @exception SWTException <ul>
+ *    <li>ERROR_DEVICE_DISPOSED - if the receiver has been disposed</li>
+ * </ul>
+ * @since 3.115
+ */
+public boolean isTracking() {
+	checkDevice();
+	return tracking;
+}
+
+/**
+ * @exception SWTException <ul>
+ *    <li>ERROR_DEVICE_DISPOSED - if the receiver has been disposed</li>
+ * </ul>
+ * @since 3.115
+ */
+public void setTracking(boolean tracking) {
+	checkDevice();
+	if (tracking == this.tracking) {
+		return;
+	}
+	this.tracking = tracking;
+	if (tracking) {
+		startTracking();
+	} else {
+		stopTracking();
+	}
+}
+
+private void startTracking() {
+	errors = new Error [128];
+	objects = new Object [128];
+	trackingLock = new Object ();
+}
+
+private void stopTracking() {
+	synchronized (trackingLock) {
+		objects = null;
+		errors = null;
+		trackingLock = null;
+	}
+}
+
 /**
  * Throws an <code>SWTException</code> if the receiver can not
  * be accessed by the caller. This may include both checks on
@@ -239,11 +275,8 @@ public void dispose () {
 		xDisplay = 0;
 		disposed = true;
 		if (tracking) {
-			synchronized (trackingLock) {
-				objects = null;
-				errors = null;
-				trackingLock = null;
-			}
+			tracking = false;
+			stopTracking();
 		}
 	}
 }
@@ -473,21 +506,10 @@ public FontData[] getFontList (String faceName, boolean scalable) {
 }
 
 Point getScreenDPI () {
-	int dpi = 96; //default value
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-		long display = GDK.gdk_display_get_default();
-		long pMonitor = GDK.gdk_display_get_primary_monitor(display);
-		if (pMonitor == 0) {
-			pMonitor = GDK.gdk_display_get_monitor(display, 0);
-		}
-		int widthMM = GDK.gdk_monitor_get_width_mm(pMonitor);
-		if (widthMM == 0) return new Point (dpi, dpi);
-		int scaleFactor = GDK.gdk_monitor_get_scale_factor(pMonitor);
-		GdkRectangle monitorGeometry = new GdkRectangle ();
-		GDK.gdk_monitor_get_geometry(pMonitor, monitorGeometry);
-		dpi = Compatibility.round (254 * monitorGeometry.width * scaleFactor, widthMM * 10);
-	}
-	return new Point (dpi, dpi);
+	long screen = GDK.gdk_screen_get_default();
+	int dpi = (int) GDK.gdk_screen_get_resolution(screen);
+	Point ptDPI = dpi == -1 ? new Point (96, 96) : new Point (dpi, dpi);
+	return ptDPI;
 }
 
 /**
@@ -587,8 +609,7 @@ public boolean getWarnings () {
  */
 protected void init () {
 	this.dpi = getDPI();
-	this.scaleFactor = getDeviceZoom ();
-	DPIUtil.setDeviceZoom (scaleFactor);
+	DPIUtil.setDeviceZoom (getDeviceZoom ());
 
 	if (debug) {
 		if (xDisplay != 0) {
@@ -603,10 +624,8 @@ protected void init () {
 				if (index == Devices.length) {
 					XErrorCallback = new Callback (clazz, "XErrorProc", 2);
 					XNullErrorProc = XErrorCallback.getAddress ();
-					if (XNullErrorProc == 0) SWT.error (SWT.ERROR_NO_MORE_CALLBACKS);
 					XIOErrorCallback = new Callback (clazz, "XIOErrorProc", 1);
 					XNullIOErrorProc = XIOErrorCallback.getAddress ();
-					if (XNullIOErrorProc == 0) SWT.error (SWT.ERROR_NO_MORE_CALLBACKS);
 					XErrorProc = OS.XSetErrorHandler (XNullErrorProc);
 					XIOErrorProc = OS.XSetIOErrorHandler (XNullIOErrorProc);
 				}
@@ -619,7 +638,6 @@ protected void init () {
 	if (xDisplay != 0) {
 		logCallback = new Callback (this, "logProc", 4);
 		logProc = logCallback.getAddress ();
-		if (logProc == 0) SWT.error (SWT.ERROR_NO_MORE_CALLBACKS);
 
 		/* Set GTK warning and error handlers */
 		if (debug) {
@@ -632,29 +650,33 @@ protected void init () {
 	}
 
 	/* Create the standard colors */
-	COLOR_TRANSPARENT = new Color (this, 0xFF,0xFF,0xFF,0);
-	COLOR_BLACK = new Color (this, 0,0,0);
-	COLOR_DARK_RED = new Color (this, 0x80,0,0);
-	COLOR_DARK_GREEN = new Color (this, 0,0x80,0);
-	COLOR_DARK_YELLOW = new Color (this, 0x80,0x80,0);
-	COLOR_DARK_BLUE = new Color (this, 0,0,0x80);
-	COLOR_DARK_MAGENTA = new Color (this, 0x80,0,0x80);
-	COLOR_DARK_CYAN = new Color (this, 0,0x80,0x80);
-	COLOR_GRAY = new Color (this, 0xC0,0xC0,0xC0);
-	COLOR_DARK_GRAY = new Color (this, 0x80,0x80,0x80);
-	COLOR_RED = new Color (this, 0xFF,0,0);
-	COLOR_GREEN = new Color (this, 0,0xFF,0);
-	COLOR_YELLOW = new Color (this, 0xFF,0xFF,0);
-	COLOR_BLUE = new Color (this, 0,0,0xFF);
-	COLOR_MAGENTA = new Color (this, 0xFF,0,0xFF);
-	COLOR_CYAN = new Color (this, 0,0xFF,0xFF);
-	COLOR_WHITE = new Color (this, 0xFF,0xFF,0xFF);
+	COLOR_TRANSPARENT = new Color (0xFF, 0xFF,0xFF,0);
+	COLOR_BLACK = new Color (0, 0,0);
+	COLOR_DARK_RED = new Color (0x80, 0,0);
+	COLOR_DARK_GREEN = new Color (0, 0x80,0);
+	COLOR_DARK_YELLOW = new Color (0x80, 0x80,0);
+	COLOR_DARK_BLUE = new Color (0, 0,0x80);
+	COLOR_DARK_MAGENTA = new Color (0x80, 0,0x80);
+	COLOR_DARK_CYAN = new Color (0, 0x80,0x80);
+	COLOR_GRAY = new Color (0xC0, 0xC0,0xC0);
+	COLOR_DARK_GRAY = new Color (0x80, 0x80,0x80);
+	COLOR_RED = new Color (0xFF, 0,0);
+	COLOR_GREEN = new Color (0, 0xFF,0);
+	COLOR_YELLOW = new Color (0xFF, 0xFF,0);
+	COLOR_BLUE = new Color (0, 0,0xFF);
+	COLOR_MAGENTA = new Color (0xFF, 0,0xFF);
+	COLOR_CYAN = new Color (0, 0xFF,0xFF);
+	COLOR_WHITE = new Color (0xFF, 0xFF,0xFF);
 
 	emptyTab = OS.pango_tab_array_new(1, false);
 	if (emptyTab == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	OS.pango_tab_array_set_tab(emptyTab, 0, OS.PANGO_TAB_LEFT, 1);
 
-	shellHandle = GTK.gtk_window_new(GTK.GTK_WINDOW_TOPLEVEL);
+	if (GTK.GTK4) {
+		shellHandle = GTK.gtk_window_new();
+	} else {
+		shellHandle = GTK.gtk_window_new (GTK.GTK_WINDOW_TOPLEVEL);
+	}
 	if (shellHandle == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	GTK.gtk_widget_realize(shellHandle);
 
@@ -670,7 +692,7 @@ protected void init () {
 			surface = GDK.gdk_window_create_similar_surface(gdkResource, Cairo.CAIRO_CONTENT_COLOR, 10, 10);
 		}
 		Cairo.cairo_surface_get_device_scale(surface, sx, sy);
-		DPIUtil.setUseCairoAutoScale((sx[0]*100) == scaleFactor || OS.isGNOME);
+		DPIUtil.setUseCairoAutoScale((sx[0]*100) == DPIUtil.getDeviceZoom() || OS.isGNOME);
 	}
 
 	/* Initialize the system font slot */
@@ -679,7 +701,7 @@ protected void init () {
 	long context = GTK.gtk_widget_get_style_context (shellHandle);
 	if ("ppc64le".equals(System.getProperty("os.arch"))) {
 		defaultFont = GTK.gtk_style_context_get_font (context, GTK.GTK_STATE_FLAG_NORMAL);
-	} else if (GTK.GTK_VERSION >= OS.VERSION(3, 18, 0)) {
+	} else {
 		GTK.gtk_style_context_save(context);
 		GTK.gtk_style_context_set_state(context, GTK.GTK_STATE_FLAG_NORMAL);
 		if (GTK.GTK4) {
@@ -689,9 +711,6 @@ protected void init () {
 		}
 		GTK.gtk_style_context_restore(context);
 		defaultFont = defaultFontArray [0];
-	} else {
-		GTK.gtk_style_context_get(context, GTK.GTK_STATE_FLAG_NORMAL, GTK.gtk_style_property_font, defaultFontArray, 0);
-		defaultFont = defaultFontArray [0];
 	}
 	defaultFont = OS.pango_font_description_copy (defaultFont);
 	Point dpi = getDPI(), screenDPI = getScreenDPI();
@@ -741,11 +760,7 @@ private void overrideThemeValues () {
 	StringBuilder combinedCSS = new StringBuilder();
 
 	// Load functional CSS fixes. Such as keyboard functionality for some widgets.
-	combinedCSS.append(load.apply(
-		GTK.GTK_VERSION < OS.VERSION(3, 20, 0) ?
-				"/org/eclipse/swt/internal/gtk/swt_functional_gtk_pre_3_20.css" :
-				"/org/eclipse/swt/internal/gtk/swt_functional_gtk_3_20.css"
-			, true));
+	combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_functional_gtk_3_20.css", true));
 
 	// By default, load CSS theme fixes to overcome things such as excessive padding that breaks SWT otherwise.
 	// Initially designed for Adwaita light/dark theme, but after investigation other themes (like Ubuntu's Ambiance + dark) seem to benefit from this also.
@@ -756,19 +771,15 @@ private void overrideThemeValues () {
 	// - These fixes should not contain any color information, otherwise it might break a light/dark variant of the theme.
 	//   Color fixes should be put either into the theme itself or via swt user api.
 	if (System.getProperty("org.eclipse.swt.internal.gtk.noThemingFixes") == null) {
-		if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
-			combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_3_20.css", true));
-			if (GTK.GTK_VERSION >= OS.VERSION(3, 24, 5)) {
-				combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_3_24_5.css", true));
-			}
-		} else {
-			combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_pre_3_20.css", true));
+		combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_3_20.css", true));
+		if (GTK.GTK_VERSION >= OS.VERSION(3, 24, 5)) {
+			combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_3_24_5.css", true));
 		}
 	}
 
 	// Load CSS from user-defined CSS file.
 	String additionalCSSPath = System.getProperty("org.eclipse.swt.internal.gtk.cssFile");
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0) && additionalCSSPath != null){
+	if (additionalCSSPath != null){
 		// Warning:
 		// - gtk css syntax changed in 3.20. If you load custom css, it could break things depending on gtk version on system.
 		// - Also, a lot of custom css/themes are buggy and may result in additional console warnings.
@@ -949,22 +960,6 @@ protected void release () {
 	if (systemFont != null) systemFont.dispose ();
 	systemFont = null;
 
-	if (COLOR_BLACK != null) COLOR_BLACK.dispose();
-	if (COLOR_DARK_RED != null) COLOR_DARK_RED.dispose();
-	if (COLOR_DARK_GREEN != null) COLOR_DARK_GREEN.dispose();
-	if (COLOR_DARK_YELLOW != null) COLOR_DARK_YELLOW.dispose();
-	if (COLOR_DARK_BLUE != null) COLOR_DARK_BLUE.dispose();
-	if (COLOR_DARK_MAGENTA != null) COLOR_DARK_MAGENTA.dispose();
-	if (COLOR_DARK_CYAN != null) COLOR_DARK_CYAN.dispose();
-	if (COLOR_GRAY != null) COLOR_GRAY.dispose();
-	if (COLOR_DARK_GRAY != null) COLOR_DARK_GRAY.dispose();
-	if (COLOR_RED != null) COLOR_RED.dispose();
-	if (COLOR_GREEN != null) COLOR_GREEN.dispose();
-	if (COLOR_YELLOW != null) COLOR_YELLOW.dispose();
-	if (COLOR_BLUE != null) COLOR_BLUE.dispose();
-	if (COLOR_MAGENTA != null) COLOR_MAGENTA.dispose();
-	if (COLOR_CYAN != null) COLOR_CYAN.dispose();
-	if (COLOR_WHITE != null) COLOR_WHITE.dispose();
 	COLOR_BLACK = COLOR_DARK_RED = COLOR_DARK_GREEN = COLOR_DARK_YELLOW = COLOR_DARK_BLUE =
 	COLOR_DARK_MAGENTA = COLOR_DARK_CYAN = COLOR_GRAY = COLOR_DARK_GRAY = COLOR_RED =
 	COLOR_GREEN = COLOR_YELLOW = COLOR_BLUE = COLOR_MAGENTA = COLOR_CYAN = COLOR_WHITE = null;
@@ -1065,15 +1060,6 @@ static long XIOErrorProc (long xDisplay) {
 	return 0;
 }
 
-/**
- * Returns DPI in x direction. In the modern monitors DPI for
- * X and Y directions is same.
- *
- * @return the horizontal DPI
- */
-int _getDPIx () {
-	return scaleFactor * 96/100;
-}
 /**
  * Gets the scaling factor from the device and calculates the zoom level.
  * @return zoom in percentage
@@ -1103,18 +1089,5 @@ protected int getDeviceZoom() {
 	}
 	return DPIUtil.mapDPIToZoom (dpi);
 }
-/**
- * @noreference This method is not intended to be referenced by clients.
- * @nooverride This method is not intended to be re-implemented or extended by clients.
- * @since 3.105
- */
-protected long gsettingsProc (long gobject, long arg1, long user_data) {
-	switch((int)user_data) {
-		case CHANGE_SCALEFACTOR:
-			this.scaleFactor = getDeviceZoom ();
-			DPIUtil.setDeviceZoom (scaleFactor);
-	}
-	return 0;
-}
 
 }
