@@ -21,6 +21,7 @@ import java.util.*;
 import org.eclipse.swt.*;
 import org.eclipse.swt.internal.*;
 import org.eclipse.swt.internal.gtk.*;
+import org.eclipse.swt.internal.image.*;
 
 /**
  * Instances of this class are used to load images from,
@@ -343,6 +344,7 @@ int getImageFormat(long loader) {
 		case "ico": return SWT.IMAGE_ICO;
 		case "jpeg": return SWT.IMAGE_JPEG;
 		case "png": return SWT.IMAGE_PNG;
+		case "svg": return SWT.IMAGE_SVG;
 		default: return SWT.IMAGE_UNDEFINED;
 	}
 }
@@ -463,8 +465,16 @@ public void save(OutputStream stream, int format) {
 	boolean has_alpha = imgData.alphaData != null && alpha_supported;
 	int width = imgData.width;
 	int height = imgData.height;
-	int n_channels = imgData.bytesPerLine / width;	// original n_channels 3 or 4
-	int bytes_per_pixel = imgData.bytesPerLine / width; // n_channels for original ImageData (width * height * bytes_per_pixel) = imgData.length
+	// original n_channels. Native implementation will only be used in case of 3 or 4
+	int n_channels = imgData.bytesPerLine / width;
+
+	// Native implementation only supports a subset of possible image configurations.
+	// Redirect the not supported variants to the Java implementation.
+	// See also https://bugs.eclipse.org/bugs/show_bug.cgi?id=558043
+	if (!imgData.palette.isDirect || n_channels < 3 || n_channels > 4) {
+		FileFormat.save(stream, format, this);
+		return;
+	}
 
 	/*
 	 * Destination offsets, GdkPixbuf data is stored in RGBA format.
@@ -487,18 +497,15 @@ public void save(OutputStream stream, int format) {
 		ob = 0;
 	}
 
-	if (has_alpha && bytes_per_pixel == 3) {
-		bytes_per_pixel = 4;
-	}
-
-	// We use alpha by default now so just hard code bytes per pixel to 4
-	byte[] srcData = new byte[(width * height * 4)];
+	// We use alpha by default now so all images saved are 32 bit, if there is no alpha we set it to 255
+	int bytes_per_pixel = 4;
+	byte[] srcData = new byte[(width * height * bytes_per_pixel)];
 
 	int alpha_offset = n_channels == 4 ? 1 : 0;
 	if (has_alpha) {
-		for (int y = 0, offset = 0, new_offset = 0, alphaOffset = 0; y < height; y++) {
+		for (int y = 0, offset = 0, new_offset = 0, alphaIndex = 0; y < height; y++) {
 			for (int x = 0; x < width; x++, offset += n_channels, new_offset += bytes_per_pixel) {
-				byte a = imgData.alphaData[alphaOffset++];
+				byte a = imgData.alphaData[alphaIndex++];
 				byte r = imgData.data[offset + alpha_offset + or];
 				byte g = imgData.data[offset + alpha_offset + og];
 				byte b = imgData.data[offset + alpha_offset + ob];
@@ -547,6 +554,7 @@ public void save(OutputStream stream, int format) {
 		case SWT.IMAGE_JPEG: typeStr = "jpeg"; break;
 		case SWT.IMAGE_PNG: typeStr = "png"; break;
 		case SWT.IMAGE_TIFF: typeStr = "tiff"; break;
+		case SWT.IMAGE_SVG: typeStr = "svg"; break;
 	}
 	byte [] type = Converter.wcsToMbcs(typeStr, true);
 
