@@ -362,14 +362,14 @@ Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 	int xborder = 0, yborder = 0;
 		GtkBorder tmp = new GtkBorder ();
 		long context = GTK.gtk_widget_get_style_context (GTK.GTK4 ? spinButtonHandle :textEntryHandle);
-		int state_flag = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(textEntryHandle);
+		int state_flag = GTK.gtk_widget_get_state_flags(textEntryHandle);
 		gtk_style_context_get_padding(context, state_flag, tmp);
 		trim.x -= tmp.left;
 		trim.y -= tmp.top;
 		trim.width += tmp.left + tmp.right;
 		trim.height += tmp.top + tmp.bottom;
 		if ((style & SWT.BORDER) != 0) {
-			int state = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(textEntryHandle);
+			int state = GTK.gtk_widget_get_state_flags(textEntryHandle);
 			gtk_style_context_get_border(context, state, tmp);
 			trim.x -= tmp.left;
 			trim.y -= tmp.top;
@@ -410,9 +410,6 @@ void createHandle () {
 			createHandleForDateTime ();
 		}
 		GTK.gtk_editable_set_editable (textEntryHandle, (style & SWT.READ_ONLY) == 0);
-		if (GTK.GTK_VERSION <= OS.VERSION(3, 20, 0)) {
-			GTK.gtk_entry_set_has_frame (textEntryHandle, (style & SWT.BORDER) != 0);
-		}
 	}
 }
 
@@ -432,11 +429,19 @@ private void createHandleForCalendar () {
 
 	GTK.gtk_container_add (fixedHandle, calendarHandle);
 
-	int flags = GTK.GTK_CALENDAR_SHOW_HEADING | GTK.GTK_CALENDAR_SHOW_DAY_NAMES;
-	if (showWeekNumbers()) {
-		flags |= GTK.GTK_CALENDAR_SHOW_WEEK_NUMBERS;
+
+	if (GTK.GTK4) {
+		GTK.gtk_calendar_set_show_heading(calendarHandle, true);
+		GTK.gtk_calendar_set_show_day_names(calendarHandle, true);
+		GTK.gtk_calendar_set_show_week_numbers(calendarHandle, showWeekNumbers());
+	} else {
+		int flags = GTK.GTK_CALENDAR_SHOW_HEADING | GTK.GTK_CALENDAR_SHOW_DAY_NAMES;
+		if (showWeekNumbers()) {
+			flags |= GTK.GTK_CALENDAR_SHOW_WEEK_NUMBERS;
+		}
+		GTK.gtk_calendar_set_display_options (calendarHandle, flags);
 	}
-	GTK.gtk_calendar_set_display_options (calendarHandle, flags);
+
 	GTK.gtk_widget_show (calendarHandle);
 }
 
@@ -714,7 +719,14 @@ void getDate () {
 	int [] y = new int [1];
 	int [] m = new int [1];
 	int [] d = new int [1];
-	GTK.gtk_calendar_get_date (calendarHandle, y, m, d);
+
+	if (GTK.GTK4) {
+		long dateTime = GTK.gtk_calendar_get_date(calendarHandle);
+		OS.g_date_time_get_ymd(dateTime, y, m, d);
+	} else {
+		GTK.gtk_calendar_get_date (calendarHandle, y, m, d);
+	}
+
 	year = y[0];
 	month = m[0];
 	day = d[0];
@@ -1353,8 +1365,14 @@ void sendSelectionEvent () {
 	int [] y = new int [1];
 	int [] m = new int [1];
 	int [] d = new int [1];
-	GTK.gtk_calendar_get_date (calendarHandle, y, m, d);
-	//TODO: hours, minutes, seconds?
+
+	if (GTK.GTK4) {
+		long dateTime = GTK.gtk_calendar_get_date(calendarHandle);
+		OS.g_date_time_get_ymd(dateTime, y, m, d);
+	} else {
+		GTK.gtk_calendar_get_date (calendarHandle, y, m, d);
+	}
+
 	if (d[0] != day ||
 		m[0] != month ||
 		y[0] != year) {
@@ -1392,22 +1410,18 @@ void setBackgroundGdkRGBA (GdkRGBA rgba) {
 void setBackgroundGdkRGBA (long context, long handle, GdkRGBA rgba) {
 	// We need to override here because DateTime widgets use "background" instead of
 	// "background-color" as their CSS property.
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		// Form background string
-		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? display.gtk_widget_class_get_css_name(handle)
-				: display.gtk_widget_get_name(handle);
-		String css = name + " {background: " + display.gtk_rgba_to_css_string (rgba) + ";}\n" +
-				name + ":selected" + " {background: " + display.gtk_rgba_to_css_string(display.COLOR_LIST_SELECTION_RGBA) + ";}";
 
-		// Cache background
-		cssBackground = css;
+	// Form background string
+	String name = display.gtk_widget_class_get_css_name(handle);
+	String css = name + " {background: " + display.gtk_rgba_to_css_string (rgba) + ";}\n" +
+			name + ":selected" + " {background: " + display.gtk_rgba_to_css_string(display.COLOR_LIST_SELECTION_RGBA) + ";}";
 
-		// Apply background color and any cached foreground color
-		String finalCss = display.gtk_css_create_css_color_string (cssBackground, cssForeground, SWT.BACKGROUND);
-		gtk_css_provider_load_from_css (context, finalCss);
-	} else {
-		super.setBackgroundGdkRGBA(context, handle, rgba);
-	}
+	// Cache background
+	cssBackground = css;
+
+	// Apply background color and any cached foreground color
+	String finalCss = display.gtk_css_create_css_color_string (cssBackground, cssForeground, SWT.BACKGROUND);
+	gtk_css_provider_load_from_css (context, finalCss);
 }
 
 @Override
@@ -1482,8 +1496,14 @@ public void setDate (int year, int month, int day) {
 		this.year = year;
 		this.month = month;
 		this.day = day;
-		GTK.gtk_calendar_select_month (calendarHandle, month, year);
-		GTK.gtk_calendar_select_day (calendarHandle, day);
+
+		if (GTK.GTK4) {
+			long dateTime = OS.g_date_time_new_local(year, month, day, 0, 0, 0);
+			GTK.gtk_calendar_select_day(calendarHandle, dateTime);
+		} else {
+			GTK.gtk_calendar_select_month (calendarHandle, month, year);
+			GTK.gtk_calendar_select_day (calendarHandle, day);
+		}
 	} else {
 		calendar.set (year, month, day);
 		updateControl ();
@@ -1511,7 +1531,13 @@ public void setDay (int day) {
 	if (!isValidDate (getYear (), getMonth (), day)) return;
 	if (isCalendar ()) {
 		this.day = day;
-		GTK.gtk_calendar_select_day (calendarHandle, day);
+
+		if (GTK.GTK4) {
+			long dateTime = OS.g_date_time_new_local(this.year, this.month, day, 0, 0, 0);
+			GTK.gtk_calendar_select_day(calendarHandle, dateTime);
+		} else {
+			GTK.gtk_calendar_select_day (calendarHandle, day);
+		}
 	} else {
 		calendar.set (Calendar.DAY_OF_MONTH, day);
 		updateControl ();
@@ -1697,28 +1723,7 @@ void setBoundsInPixels (int x, int y, int width, int height) {
 		GTK.gtk_widget_set_size_request (sizingHandle, (newWidth >= 0) ? newWidth : 0, oldHeight);
 	}
 
-	/*
-	 * TAG_GTK_CALENDAR_VERTICAL_FILL_WORKAROUND_394534
-	 * Work around a GtkCalendar bug in GTK3:
-	 * https://bugzilla.gnome.org/show_bug.cgi?id=737670
-	 *
-	 * In GTK3.0 - 3.14.2 (but not Gtk2) if the calendar is expanded beyond a certain size,
-	 * (e.g in the case of 'Vertical fill' in ControlExample, then the days shift down
-	 * and they become un-selectable. e.g, see screen shot:
-	 * https://bug737670.bugzilla-attachments.gnome.org/attachment.cgi?id=287470
-	 *
-	 * To work around this, if gtk 3.0 - 3.14.2 is used, do not allow the calendar to expand beyond it's preffered
-	 * native height.
-	 */
-	int fixedGtkVersion = OS.VERSION (3, 14, 2);
-	if (isCalendar () && (GTK.GTK_VERSION < fixedGtkVersion)) {
-			int calendarPrefferedVerticalSize = computeSizeInPixels (SWT.DEFAULT, SWT.DEFAULT, true).y;
-			if (height > calendarPrefferedVerticalSize) {
-				height = calendarPrefferedVerticalSize;
-		}
-	}
 	super.setBoundsInPixels (x, y, width, height);
-
 }
 
 /**
@@ -1752,7 +1757,7 @@ GtkBorder getGtkBorderPadding () {
 	GtkBorder gtkBorderPadding = new GtkBorder ();
 	long contextHandle = GTK.GTK4 ? spinButtonHandle : textEntryHandle;
 	long context = GTK.gtk_widget_get_style_context (contextHandle);
-	int state_flag = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(contextHandle);
+	int state_flag = GTK.gtk_widget_get_state_flags(contextHandle);
 	gtk_style_context_get_padding(context, state_flag, gtkBorderPadding);
 	return gtkBorderPadding;
 }
@@ -1794,6 +1799,10 @@ boolean onNumberKeyInput(int key) {
 		}
 	} else {
 		char newText = keyToString(key);
+		// Don't allow non-digit character inputs for SWT.TIME, unless modifying the AM/PM field
+		if ((style & SWT.TIME) != 0 && fieldName != Calendar.AM_PM && !Character.isDigit(newText)) {
+			return false;
+		}
 		if (!Character.isAlphabetic(newText) && !Character.isDigit(newText)) {
 			return false;
 		}
@@ -1823,6 +1832,14 @@ boolean onNumberKeyInput(int key) {
 	setSelection(prefix.length() + typeBufferPos, prefix.length() + typeBuffer.length());
 	currentField.setBeginIndex(prefix.length());
 	currentField.setEndIndex(prefix.length() + typeBuffer.length());
+	if (!isCalendar()) {
+		try {
+			Date date = dateFormat.parse(getText());
+			calendar.setTime(date);
+		} catch (ParseException e) {
+			// invalid value, input will reset...
+		}
+	}
 	return false;
 }
 
@@ -1832,7 +1849,7 @@ private char keyToString(int key) {
 		// convert numberpad button to regular key;
 		key -= 65408;
 	}
-	return (char) key;
+	return (char) GDK.gdk_keyval_to_unicode(key);
 }
 
 void updateControl() {
@@ -1943,7 +1960,12 @@ void setText (String dateTimeText) {
 long gtk_key_press_event (long widget, long event) {
 	if (!isReadOnly () && (isTime () || isDate ())) {
 		int [] key = new int[1];
-		GDK.gdk_event_get_keyval(event, key);
+		if (GTK.GTK4) {
+			key[0] = GDK.gdk_key_event_get_keyval(event);
+		} else {
+			GDK.gdk_event_get_keyval(event, key);
+		}
+
 		switch (key[0]) {
 		case GDK.GDK_Up:
 		case GDK.GDK_KP_Up:
@@ -2097,7 +2119,12 @@ private int validateValueBounds(FieldPosition field, int value) {
 long gtk_button_release_event (long widget, long event) {
 	if (isDate () || isTime ()) {
 		int [] eventButton = new int [1];
-		GDK.gdk_event_get_button(event, eventButton);
+		if (GTK.GTK4) {
+			eventButton[0] = GDK.gdk_button_event_get_button(event);
+		} else {
+			GDK.gdk_event_get_button(event, eventButton);
+		}
+
 		if (eventButton[0] == 1) { // left mouse button.
 			onTextMouseClick ();
 		}
