@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -21,14 +21,13 @@ import org.eclipse.swt.internal.gtk.*;
 /**
  * Instances of this class represent a selectable user interface object
  * that represents a expandable item in a expand bar.
- * <p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>(none)</dd>
  * <dt><b>Events:</b></dt>
  * <dd>(none)</dd>
  * </dl>
- * </p><p>
+ * <p>
  * IMPORTANT: This class is <em>not</em> intended to be subclassed.
  * </p>
  *
@@ -42,7 +41,7 @@ public class ExpandItem extends Item {
 	ExpandBar parent;
 	Control control;
 	ImageList imageList;
-	long /*int*/ clientHandle, boxHandle, labelHandle, imageHandle;
+	long clientHandle, boxHandle, labelHandle, imageHandle;
 	boolean expanded;
 	int x, y, width, height;
 	int imageHeight, imageWidth;
@@ -162,13 +161,11 @@ void deregister() {
 
 @Override
 void release (boolean destroy) {
-	if (GTK.GTK3) {
-		//454940 ExpandBar DND fix.
-		//Since controls are now nested under the Item,
-		//Item is responsible for it's release.
-		if (control != null && !control.isDisposed ()) {
-			control.release (destroy);
-		}
+	//454940 ExpandBar DND fix.
+	//Since controls are now nested under the Item,
+	//Item is responsible for it's release.
+	if (control != null && !control.isDisposed ()) {
+		control.release (destroy);
 	}
 	super.release (destroy);
 }
@@ -349,7 +346,7 @@ int getPreferredWidth (GC gc) {
 }
 
 @Override
-long /*int*/ gtk_activate (long /*int*/ widget) {
+long gtk_activate (long widget) {
 	Event event = new Event ();
 	event.item = this;
 	int type = GTK.gtk_expander_get_expanded (handle) ? SWT.Collapse : SWT.Expand;
@@ -358,26 +355,41 @@ long /*int*/ gtk_activate (long /*int*/ widget) {
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_event (long widget, long event) {
+	if (!GTK.GTK4) return 0;
+	int eventType = GDK.gdk_event_get_event_type(event);
+	switch (eventType) {
+		case GDK.GDK4_BUTTON_PRESS: {
+			return gtk_button_press_event(widget, event);
+		}
+		case GDK.GDK4_BUTTON_RELEASE: {
+			return gtk_button_release_event(widget, event);
+		}
+	}
+	return 0;
+}
+
+@Override
+long gtk_button_press_event (long widget, long event) {
 	setFocus ();
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_focus_out_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_focus_out_event (long widget, long event) {
 	GTK.gtk_widget_set_can_focus (handle, false);
 	parent.lastFocus = this;
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_size_allocate (long /*int*/ widget, long /*int*/ allocation) {
+long gtk_size_allocate (long widget, long allocation) {
 	parent.layoutItems (0, false);
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_enter_notify_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_enter_notify_event (long widget, long event) {
 	parent.gtk_enter_notify_event(widget, event);
 	return 0;
 }
@@ -391,10 +403,23 @@ void hookEvents () {
 	super.hookEvents ();
 	OS.g_signal_connect_closure (handle, OS.activate, display.getClosure (ACTIVATE), false);
 	OS.g_signal_connect_closure (handle, OS.activate, display.getClosure (ACTIVATE_INVERSE), true);
-	OS.g_signal_connect_closure_by_id (handle, display.signalIds [BUTTON_PRESS_EVENT], 0, display.getClosure (BUTTON_PRESS_EVENT), false);
+	if (GTK.GTK4) {
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [EVENT], 0, display.getClosure (EVENT), false);
+	} else {
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [BUTTON_PRESS_EVENT], 0, display.getClosure (BUTTON_PRESS_EVENT), false);
+	}
 	OS.g_signal_connect_closure_by_id (handle, display.signalIds [FOCUS_OUT_EVENT], 0, display.getClosure (FOCUS_OUT_EVENT), false);
 	OS.g_signal_connect_closure (clientHandle, OS.size_allocate, display.getClosure (SIZE_ALLOCATE), true);
-	OS.g_signal_connect_closure_by_id (handle, display.signalIds [ENTER_NOTIFY_EVENT], 0, display.getClosure (ENTER_NOTIFY_EVENT), false);
+	if (GTK.GTK4) {
+		long motionController = GTK.gtk_event_controller_motion_new();
+		GTK.gtk_widget_add_controller(handle, motionController);
+		GTK.gtk_event_controller_set_propagation_phase(motionController, GTK.GTK_PHASE_TARGET);
+
+		long enterAddress = display.enterMotionScrollCallback.getAddress();
+		OS.g_signal_connect (motionController, OS.enter, enterAddress, ENTER);
+	} else {
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [ENTER_NOTIFY_EVENT], 0, display.getClosure (ENTER_NOTIFY_EVENT), false);
+	}
 }
 
 void redraw () {
@@ -440,16 +465,22 @@ void resizeControl (int yScroll) {
 		* As of GTK3, the hierarchy is changed, this affected child-size allocation and a fix
 		* is now neccessary.
 		* See also other 454940 notes and similar fix in: 453827 */
-		int x = (GTK.GTK3) ? 0 : allocation.x;
-		int y = (GTK.GTK3) ? 0 : allocation.y;
+		int x = 0 ;
+		int y = 0;
 
 		if (x != -1 && y != -1) {
 			int width = allocation.width;
 			int height = allocation.height;
-			int [] property = new int [1];
-			GTK.gtk_widget_style_get (handle, OS.focus_line_width, property, 0);
-			y += property [0] * 2;
-			height -= property [0] * 2;
+			/*
+			 * Focus line width is done via CSS in GTK4, and does not contribute
+			 * to the size of the widget.
+			 */
+			if (!GTK.GTK4) {
+				int [] property = new int [1];
+				GTK.gtk_widget_style_get (handle, OS.focus_line_width, property, 0);
+				y += property [0] * 2;
+				height -= property [0] * 2;
+			}
 
 			/*
 			* Feature in GTK. When the ExpandBar is resize too small the control
@@ -467,19 +498,14 @@ void resizeControl (int yScroll) {
 				}
 			}
 			// Bug 479242: Bound calculation is correct without needing to use yScroll in GTK3
-			if (GTK.GTK3) {
-				/*
-				 * Bug 538114: ExpandBar has no content until resized or collapsed/expanded.
-				 * When widget is first created inside ExpandItem's control, the size is allocated
-				 * to be zero, and the widget is never shown during a layout operation, similar to
-				 * Bug 487757. The fix is to show the control before setting any bounds.
-				 */
-				if (visible) GTK.gtk_widget_show(control.topHandle ());
-				control.setBounds (x, y, width, Math.max (0, height), true, true);
-			}
-			else {
-				control.setBounds (x, y - yScroll, width, Math.max (0, height), true, true);
-			}
+			/*
+			 * Bug 538114: ExpandBar has no content until resized or collapsed/expanded.
+			 * When widget is first created inside ExpandItem's control, the size is allocated
+			 * to be zero, and the widget is never shown during a layout operation, similar to
+			 * Bug 487757. The fix is to show the control before setting any bounds.
+			 */
+			if (visible) GTK.gtk_widget_show(control.topHandle ());
+			control.setBounds (x, y, width, Math.max (0, height), true, true);
 		}
 		control.setVisible (visible);
 	}
@@ -533,20 +559,18 @@ public void setControl (Control control) {
 	this.control = control;
 	if (control != null) {
 		control.setVisible (expanded);
-		if (GTK.GTK3) {
-			//454940 ExpandBar DND fix.
-			//Reparenting on the GTK side.
-			//Proper hierachy on gtk side is required for DND to function properly.
-			//As ExpandItem's child can be created before the ExpandItem, our only
-			//option is to reparent the child upon the setControl(..) call.
-			//This is simmilar to TabFolder.
-			Control.gtk_widget_reparent (control, clientHandle ());
-		}
+		//454940 ExpandBar DND fix.
+		//Reparenting on the GTK side.
+		//Proper hierachy on gtk side is required for DND to function properly.
+		//As ExpandItem's child can be created before the ExpandItem, our only
+		//option is to reparent the child upon the setControl(..) call.
+		//This is simmilar to TabFolder.
+		Control.gtk_widget_reparent (control, clientHandle ());
 	}
 	parent.layoutItems (0, true);
 }
 
-long /*int*/ clientHandle () {
+long clientHandle () {
 	return clientHandle;
 }
 
@@ -579,21 +603,13 @@ boolean setFocus () {
 	return result;
 }
 
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	setFontDescription (handle, font);
 	if (labelHandle != 0) setFontDescription (labelHandle, font);
 	if (imageHandle != 0) setFontDescription (imageHandle, font);
 }
 
-void setForegroundColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	setForegroundColor (handle, color);
-	if (labelHandle != 0) setForegroundColor (labelHandle, color);
-	if (imageHandle != 0) setForegroundColor (imageHandle, color);
-}
-
 void setForegroundRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	parent.setForegroundGdkRGBA (handle, rgba);
 	if (labelHandle != 0) parent.setForegroundGdkRGBA (labelHandle, rgba);
 	if (imageHandle != 0) parent.setForegroundGdkRGBA (imageHandle, rgba);
@@ -631,13 +647,12 @@ public void setImage (Image image) {
 	if (image != null) {
 		if (image.isDisposed ()) error (SWT.ERROR_INVALID_ARGUMENT);
 		imageList = new ImageList ();
-		int imageIndex = imageList.add (image);
-		long /*int*/ pixbuf = imageList.getPixbuf (imageIndex);
-		gtk_image_set_from_pixbuf (imageHandle, pixbuf);
+		imageList.add (image);
+		GTK.gtk_image_set_from_surface(imageHandle, image.surface);
 		if (text.length () == 0) GTK.gtk_widget_hide (labelHandle);
 		GTK.gtk_widget_show (imageHandle);
 	} else {
-		gtk_image_set_from_pixbuf (imageHandle, 0);
+		GTK.gtk_image_set_from_surface(imageHandle, 0);
 		GTK.gtk_widget_show (labelHandle);
 		GTK.gtk_widget_hide (imageHandle);
 	}
@@ -668,12 +683,12 @@ void showWidget (int index) {
 		if (boxHandle != 0)
 			GTK.gtk_widget_show (boxHandle);
 		GTK.gtk_container_add (parent.handle, handle);
-		GTK.gtk_box_set_child_packing (parent.handle, handle, false, false, 0, GTK.GTK_PACK_START);
+		gtk_box_set_child_packing (parent.handle, handle, false, false, 0, GTK.GTK_PACK_START);
 }
 
 @Override
-long /*int*/ windowProc (long /*int*/ handle, long /*int*/ user_data) {
-	switch ((int)/*64*/user_data) {
+long windowProc (long handle, long user_data) {
+	switch ((int)user_data) {
 		case ACTIVATE_INVERSE: {
 			expanded = GTK.gtk_expander_get_expanded (handle);
 			parent.layoutItems (0, false);
@@ -682,4 +697,16 @@ long /*int*/ windowProc (long /*int*/ handle, long /*int*/ user_data) {
 	}
 	return super.windowProc (handle, user_data);
 }
+
+@Override
+long dpiChanged(long object, long arg0) {
+	super.dpiChanged(object, arg0);
+
+	if (image != null) {
+		image.internal_gtk_refreshImageForZoom();
+		setImage(image);
+	}
+
+	return 0;
+}
 }
