@@ -108,11 +108,16 @@ String computeResultChooserDialog () {
 	fullPath = null;
 	if ((style & SWT.MULTI) != 0) {
 		long list = 0;
-		if (uriMode) {
-			list = GTK.gtk_file_chooser_get_uris (handle);
+		if (GTK.GTK4) {
+			list = GTK.gtk_file_chooser_get_files(handle);
 		} else {
-			list = GTK.gtk_file_chooser_get_filenames (handle);
+			if (uriMode) {
+				list = GTK.gtk_file_chooser_get_uris (handle);
+			} else {
+				list = GTK.gtk_file_chooser_get_filenames (handle);
+			}
 		}
+
 		int listLength = OS.g_slist_length (list);
 		fileNames = new String [listLength];
 		long current = list;
@@ -121,8 +126,16 @@ String computeResultChooserDialog () {
 			long name = OS.g_slist_data (current);
 			long utf8Ptr = 0;
 			if (uriMode) {
-				utf8Ptr = name;
+				if (GTK.GTK4) {
+					utf8Ptr = OS.g_file_get_uri(name);
+				} else {
+					utf8Ptr = name;
+				}
 			} else {
+				if (GTK.GTK4) {
+					name = OS.g_file_get_path(name);
+				}
+
 				utf8Ptr = OS.g_filename_to_utf8 (name, -1, null, null, null);
 				if (utf8Ptr == 0) utf8Ptr = OS.g_filename_display_name (name);
 			}
@@ -151,9 +164,21 @@ String computeResultChooserDialog () {
 	} else {
 		long utf8Ptr = 0;
 		if (uriMode) {
-			utf8Ptr = GTK.gtk_file_chooser_get_uri (handle);
+			if (GTK.GTK4) {
+				long file = GTK.gtk_file_chooser_get_file(handle);
+				utf8Ptr = OS.g_file_get_uri(file);
+			} else {
+				utf8Ptr = GTK.gtk_file_chooser_get_uri (handle);
+			}
 		} else {
-			long path = GTK.gtk_file_chooser_get_filename (handle);
+			long path;
+			if (GTK.GTK4) {
+				long file = GTK.gtk_file_chooser_get_file(handle);
+				path = OS.g_file_get_path(file);
+			} else {
+				path = GTK.gtk_file_chooser_get_filename (handle);
+			}
+
 			if (path != 0) {
 				utf8Ptr = OS.g_filename_to_utf8 (path, -1, null, null, null);
 				if (utf8Ptr == 0) utf8Ptr = OS.g_filename_display_name (path);
@@ -301,11 +326,7 @@ public boolean getOverwrite () {
  * </ul>
  */
 public String open () {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
-		return openNativeChooserDialog();
-	} else {
-		return openChooserDialog();
-	}
+	return openNativeChooserDialog();
 }
 /**
  * Open the file chooser dialog using the GtkFileChooserNative API (GTK3.20+) for running applications
@@ -316,7 +337,6 @@ public String open () {
  * @return a string describing the absolute path of the first selected file, or null
  */
 String openNativeChooserDialog () {
-	assert GTK.GTK_VERSION >= OS.VERSION(3, 20, 0);
 	byte [] titleBytes = Converter.wcsToMbcs (title, true);
 	int action = (style & SWT.SAVE) != 0 ? GTK.GTK_FILE_CHOOSER_ACTION_SAVE : GTK.GTK_FILE_CHOOSER_ACTION_OPEN;
 	long shellHandle = parent.topHandle ();
@@ -324,7 +344,8 @@ String openNativeChooserDialog () {
 	handle = GTK.gtk_file_chooser_native_new(titleBytes, shellHandle, action, null, null);
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 
-	if (uriMode) {
+	if (uriMode && !GTK.GTK4) {
+		// GTK4 file chooser works on GFiles and does not need to worry about this
 		GTK.gtk_file_chooser_set_local_only (handle, false);
 	}
 	presetChooserDialog ();
@@ -336,6 +357,7 @@ String openNativeChooserDialog () {
 		signalId = OS.g_signal_lookup (OS.map, GTK.GTK_TYPE_WIDGET());
 		hookId = OS.g_signal_add_emission_hook (signalId, 0, display.emissionProc, handle, 0);
 	}
+	display.externalEventLoop = true;
 	display.sendPreExternalEventDispatchEvent ();
 	int response = 0;
 	response = GTK.gtk_native_dialog_run(handle);
@@ -346,6 +368,7 @@ String openNativeChooserDialog () {
 	* thread leaves the GTK lock acquired by the function above.
 	*/
 	if (!GTK.GTK4) GDK.gdk_threads_leave();
+	display.externalEventLoop = false;
 	display.sendPostExternalEventDispatchEvent ();
 	if ((style & SWT.RIGHT_TO_LEFT) != 0) {
 		OS.g_signal_remove_emission_hook (signalId, hookId);
@@ -356,67 +379,7 @@ String openNativeChooserDialog () {
 	display.removeIdleProc ();
 	return answer;
 }
-String openChooserDialog () {
-	byte [] titleBytes = Converter.wcsToMbcs (title, true);
-	int action = (style & SWT.SAVE) != 0 ?
-		GTK.GTK_FILE_CHOOSER_ACTION_SAVE :
-		GTK.GTK_FILE_CHOOSER_ACTION_OPEN;
-	long shellHandle = parent.topHandle ();
-	Display display = parent != null ? parent.getDisplay (): Display.getCurrent ();
-	if (display.getDismissalAlignment() == SWT.RIGHT) {
-		handle = GTK.gtk_file_chooser_dialog_new (titleBytes, shellHandle, action, GTK.GTK_NAMED_LABEL_CANCEL, GTK.GTK_RESPONSE_CANCEL, GTK.GTK_NAMED_LABEL_OK, GTK.GTK_RESPONSE_OK, 0);
-	} else {
-		handle = GTK.gtk_file_chooser_dialog_new (titleBytes, shellHandle, action, GTK.GTK_NAMED_LABEL_OK, GTK.GTK_RESPONSE_OK, GTK.GTK_NAMED_LABEL_CANCEL, GTK.GTK_RESPONSE_CANCEL, 0);
-	}
-	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_window_set_modal (handle, true);
-	long group = GTK.gtk_window_get_group(0);
-	GTK.gtk_window_group_add_window (group, handle);
-	long pixbufs = GTK.gtk_window_get_icon_list (shellHandle);
-	if (pixbufs != 0) {
-		GTK.gtk_window_set_icon_list (handle, pixbufs);
-		OS.g_list_free (pixbufs);
-	}
-	if (uriMode) {
-		GTK.gtk_file_chooser_set_local_only (handle, false);
-	}
-	presetChooserDialog ();
-	display.addIdleProc ();
-	String answer = null;
-	Dialog oldModal = null;
-	if (GTK.gtk_window_get_modal (handle)) {
-		oldModal = display.getModalDialog ();
-		display.setModalDialog (this);
-	}
-	int signalId = 0;
-	long hookId = 0;
-	if ((style & SWT.RIGHT_TO_LEFT) != 0) {
-		signalId = OS.g_signal_lookup (OS.map, GTK.GTK_TYPE_WIDGET());
-		hookId = OS.g_signal_add_emission_hook (signalId, 0, display.emissionProc, handle, 0);
-	}
-	display.sendPreExternalEventDispatchEvent ();
-	int response = GTK.gtk_dialog_run (handle);
-	/*
-	* This call to gdk_threads_leave() is a temporary work around
-	* to avoid deadlocks when gdk_threads_init() is called by native
-	* code outside of SWT (i.e AWT, etc). It ensures that the current
-	* thread leaves the GTK lock acquired by the function above.
-	*/
-	if (!GTK.GTK4) GDK.gdk_threads_leave();
-	display.sendPostExternalEventDispatchEvent ();
-	if ((style & SWT.RIGHT_TO_LEFT) != 0) {
-		OS.g_signal_remove_emission_hook (signalId, hookId);
-	}
-	if (GTK.gtk_window_get_modal (handle)) {
-		display.setModalDialog (oldModal);
-	}
-	if (response == GTK.GTK_RESPONSE_OK) {
-		answer = computeResultChooserDialog ();
-	}
-	display.removeIdleProc ();
-	GTK.gtk_widget_destroy (handle);
-	return answer;
-}
+
 void presetChooserDialog () {
 	/* MULTI is only valid if the native dialog's action is Open */
 	if ((style & (SWT.SAVE | SWT.MULTI)) == SWT.MULTI) {
@@ -431,7 +394,15 @@ void presetChooserDialog () {
 		if (filterPath.length () > 0) {
 			if (uriMode) {
 				byte [] buffer = Converter.wcsToMbcs (filterPath, true);
-				GTK.gtk_file_chooser_set_current_folder_uri (handle, buffer);
+
+				if (GTK.GTK4) {
+					long file = OS.g_file_new_for_uri(buffer);
+					GTK.gtk_file_chooser_set_current_folder (handle, file, 0);
+					OS.g_object_unref(file);
+				} else {
+					GTK.gtk_file_chooser_set_current_folder_uri (handle, buffer);
+				}
+
 			} else {
 				/* filename must be a full path */
 				byte [] buffer = Converter.wcsToMbcs (SEPARATOR + filterPath, true);
@@ -442,7 +413,13 @@ void presetChooserDialog () {
 				 */
 				long ptr = OS.realpath (buffer, null);
 				if (ptr != 0) {
-					GTK.gtk_file_chooser_set_current_folder (handle, ptr);
+					if (GTK.GTK4) {
+						long file = OS.g_file_new_for_path(buffer);
+						GTK.gtk_file_chooser_set_current_folder (handle, file, 0);
+						OS.g_object_unref(file);
+					} else {
+						GTK.gtk_file_chooser_set_current_folder (handle, ptr);
+					}
 					OS.g_free (ptr);
 				}
 			}
@@ -490,29 +467,52 @@ void presetChooserDialog () {
 			stringBuilder.append(fileName);
 		}
 		byte [] buffer = Converter.wcsToMbcs (stringBuilder.toString(), true);
-		if (uriMode) {
-			GTK.gtk_file_chooser_set_uri (handle, buffer);
-		} else {
-			/*
-			 * in GTK version 2.10, gtk_file_chooser_set_current_folder requires path
-			 * to be true canonical path. So using realpath to convert the path to
-			 * true canonical path.
-			 */
-			long ptr = OS.realpath (buffer, null);
-			if (ptr != 0) {
+
+		if (GTK.GTK4) {
+			long file;
+			if (uriMode) {
+				file = OS.g_file_new_for_uri(buffer);
+				GTK.gtk_file_chooser_set_file (handle, file, 0);
+			} else {
+				file = OS.g_file_new_for_path(buffer);
+
 				if (fileName.length() > 0) {
-					GTK.gtk_file_chooser_set_filename (handle, ptr);
+					GTK.gtk_file_chooser_set_file (handle, file, 0);
 				} else {
-					GTK.gtk_file_chooser_set_current_folder (handle, ptr);
+					GTK.gtk_file_chooser_set_current_folder (handle, file, 0);
+				}
+			}
+
+			OS.g_object_unref(file);
+		} else {
+			if (uriMode) {
+				GTK.gtk_file_chooser_set_uri (handle, buffer);
+			} else {
+				/*
+				 * in GTK version 2.10, gtk_file_chooser_set_current_folder requires path
+				 * to be true canonical path. So using realpath to convert the path to
+				 * true canonical path.
+				 */
+				long ptr = OS.realpath (buffer, null);
+				if (ptr != 0) {
+					if (fileName.length() > 0) {
+						GTK.gtk_file_chooser_set_filename (handle, ptr);
+					} else {
+						GTK.gtk_file_chooser_set_current_folder (handle, ptr);
+					}
+					OS.g_free (ptr);
 				}
-				OS.g_free (ptr);
 			}
 		}
 	}
 
 	/* Set overwrite mode */
 	if ((style & SWT.SAVE) != 0) {
-		GTK.gtk_file_chooser_set_do_overwrite_confirmation (handle, overwrite);
+		if (GTK.GTK4) {
+			// TODO: GTK4 does not this property for the file chooser, not sure what the default behavior is. Must test before trying an alternative.
+		} else {
+			GTK.gtk_file_chooser_set_do_overwrite_confirmation (handle, overwrite);
+		}
 	}
 
 	/* Set the extension filters */
