@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -53,7 +53,7 @@ import org.eclipse.swt.internal.gtk.*;
  * @noextend This class is not intended to be subclassed by clients.
  */
 public class Label extends Control {
-	long /*int*/ frameHandle, labelHandle, imageHandle, boxHandle;
+	long frameHandle, labelHandle, imageHandle, boxHandle;
 	ImageList imageList;
 	Image image;
 	String text;
@@ -117,7 +117,7 @@ void addRelation (Control control) {
 }
 
 @Override
-Point computeNativeSize (long /*int*/ h, int wHint, int hHint, boolean changed) {
+Point computeNativeSize (long h, int wHint, int hHint, boolean changed) {
 	int width = wHint, height = hHint;
 	/*
 	 * Feature in GTK3: Labels with long text have an extremely large natural width.
@@ -125,8 +125,8 @@ Point computeNativeSize (long /*int*/ h, int wHint, int hHint, boolean changed)
 	 * is to use the minimum width instead of the natural width when SWT.WRAP is specified.
 	 * In all other cases, use the natural width. See bug 534768.
 	 */
-	boolean wrapGTK3 = GTK.GTK3 && labelHandle != 0 && (style & SWT.WRAP) != 0 && GTK.gtk_widget_get_visible (labelHandle);
-	if (wrapGTK3 && wHint == SWT.DEFAULT && hHint == SWT.DEFAULT) {
+	boolean wrap = labelHandle != 0 && (style & SWT.WRAP) != 0 && GTK.gtk_widget_get_visible (labelHandle);
+	if (wrap && wHint == SWT.DEFAULT && hHint == SWT.DEFAULT) {
 		GtkRequisition naturalSize = new GtkRequisition ();
 		GtkRequisition minimumSize = new GtkRequisition ();
 		GTK.gtk_widget_get_preferred_size(h, minimumSize, naturalSize);
@@ -158,7 +158,7 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	boolean fixWrap = labelHandle != 0 && (style & SWT.WRAP) != 0 && GTK.gtk_widget_get_visible (labelHandle);
 	if (fixWrap || frameHandle != 0) forceResize ();
 	if (fixWrap) {
-		long /*int*/ labelLayout = GTK.gtk_label_get_layout (labelHandle);
+		long labelLayout = GTK.gtk_label_get_layout (labelHandle);
 		int pangoWidth = OS.pango_layout_get_width (labelLayout);
 		if (wHint != SWT.DEFAULT) {
 			OS.pango_layout_set_width (labelLayout, wHint * OS.PANGO_SCALE);
@@ -202,29 +202,23 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	* muliple lines of text.
 	*/
 	if (hHint == SWT.DEFAULT && labelHandle != 0) {
-		long /*int*/ layout = GTK.gtk_label_get_layout (labelHandle);
-		long /*int*/ context = OS.pango_layout_get_context (layout);
-		long /*int*/ lang = OS.pango_context_get_language (context);
-		long /*int*/ font = getFontDescription ();
-		long /*int*/ metrics = OS.pango_context_get_metrics (context, font, lang);
+		long layout = GTK.gtk_label_get_layout (labelHandle);
+		long context = OS.pango_layout_get_context (layout);
+		long lang = OS.pango_context_get_language (context);
+		long font = getFontDescription ();
+		long metrics = OS.pango_context_get_metrics (context, font, lang);
 		int ascent = OS.PANGO_PIXELS (OS.pango_font_metrics_get_ascent (metrics));
 		int descent = OS.PANGO_PIXELS (OS.pango_font_metrics_get_descent (metrics));
 		OS.pango_font_metrics_unref (metrics);
 		int fontHeight = ascent + descent;
-		if (GTK.GTK3) {
-			int [] bufferBottom = new int [1];
-			int [] bufferTop = new int [1];
-			OS.g_object_get(labelHandle, OS.margin_bottom, bufferBottom, 0);
-			OS.g_object_get(labelHandle, OS.margin_top, bufferTop, 0);
-			fontHeight += bufferBottom [0] + bufferTop [0];
-		} else {
-			int [] bufferYpad = new int[1];
-			OS.g_object_get (labelHandle, OS.ypad, bufferYpad, 0);
-			fontHeight += 2 * bufferYpad [0];
-		}
+		int [] bufferBottom = new int [1];
+		int [] bufferTop = new int [1];
+		OS.g_object_get(labelHandle, OS.margin_bottom, bufferBottom, 0);
+		OS.g_object_get(labelHandle, OS.margin_top, bufferTop, 0);
+		fontHeight += bufferBottom [0] + bufferTop [0];
 		if (frameHandle != 0) {
 			fontHeight += 2 * getThickness (frameHandle).y;
-			fontHeight += 2 * GTK.gtk_container_get_border_width (frameHandle);
+			fontHeight += 2 * gtk_container_get_border_width_or_margin (frameHandle);
 		}
 		size.y = Math.max (size.y, fontHeight);
 	}
@@ -236,41 +230,52 @@ void createHandle (int index) {
 	state |= HANDLE | THEME_BACKGROUND;
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (fixedHandle, true);
+	gtk_widget_set_has_surface_or_window (fixedHandle, true);
 	if ((style & SWT.SEPARATOR) != 0) {
 		if ((style & SWT.HORIZONTAL)!= 0) {
-			handle = gtk_separator_new (GTK.GTK_ORIENTATION_HORIZONTAL);
-			if (handle != 0 && GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
+			handle = GTK.gtk_separator_new (GTK.GTK_ORIENTATION_HORIZONTAL);
+			if (handle != 0) {
 				GTK.gtk_widget_set_valign(handle, GTK.GTK_ALIGN_CENTER);
 			}
 		} else {
-			handle = gtk_separator_new (GTK.GTK_ORIENTATION_VERTICAL);
-			if (handle != 0 && GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
+			handle = GTK.gtk_separator_new (GTK.GTK_ORIENTATION_VERTICAL);
+			if (handle != 0) {
 				GTK.gtk_widget_set_halign(handle, GTK.GTK_ALIGN_CENTER);
 			}
 		}
 		if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 	} else {
-		handle = GTK.gtk_event_box_new();
+		if (GTK.GTK4) {
+			handle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 0);
+		} else {
+			handle = GTK.gtk_event_box_new();
+			boxHandle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 0);
+			if (boxHandle == 0) error (SWT.ERROR_NO_HANDLES);
+		}
 		if (handle == 0) error (SWT.ERROR_NO_HANDLES);
-		boxHandle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 0);
-		if (boxHandle == 0) error (SWT.ERROR_NO_HANDLES);
 		labelHandle = GTK.gtk_label_new_with_mnemonic (null);
 		if (labelHandle == 0) error (SWT.ERROR_NO_HANDLES);
 		imageHandle = GTK.gtk_image_new ();
 		if (imageHandle == 0) error (SWT.ERROR_NO_HANDLES);
-		GTK.gtk_container_add (handle, boxHandle);
-		GTK.gtk_container_add (boxHandle, labelHandle);
-		GTK.gtk_container_add (boxHandle, imageHandle);
-		GTK.gtk_box_set_child_packing(boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_START);
-		GTK.gtk_box_set_child_packing(boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
+		if (GTK.GTK4) {
+			GTK.gtk_container_add (handle, labelHandle);
+			GTK.gtk_container_add (handle, imageHandle);
+			gtk_box_set_child_packing(handle, labelHandle, true, true, 0, GTK.GTK_PACK_START);
+			gtk_box_set_child_packing(handle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
+		} else {
+			GTK.gtk_container_add (handle, boxHandle);
+			GTK.gtk_container_add (boxHandle, labelHandle);
+			GTK.gtk_container_add (boxHandle, imageHandle);
+			gtk_box_set_child_packing(boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_START);
+			gtk_box_set_child_packing(boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
+		}
 	}
 	if ((style & SWT.BORDER) != 0) {
 		frameHandle = GTK.gtk_frame_new (null);
 		if (frameHandle == 0) error (SWT.ERROR_NO_HANDLES);
 		GTK.gtk_container_add (fixedHandle, frameHandle);
 		GTK.gtk_container_add (frameHandle, handle);
-		GTK.gtk_frame_set_shadow_type (frameHandle, GTK.GTK_SHADOW_ETCHED_IN);
+		if (!GTK.GTK4) GTK.gtk_frame_set_shadow_type (frameHandle, GTK.GTK_SHADOW_ETCHED_IN);
 	} else {
 		GTK.gtk_container_add (fixedHandle, handle);
 	}
@@ -281,9 +286,7 @@ void createHandle (int index) {
 	}
 	// In GTK 3 font description is inherited from parent widget which is not how SWT has always worked,
 	// reset to default font to get the usual behavior
-	if (GTK.GTK3) {
-		setFontDescription(defaultFont ().handle);
-	}
+	setFontDescription(defaultFont ().handle);
 	setAlignment ();
 }
 
@@ -303,12 +306,12 @@ void deregister () {
 }
 
 @Override
-long /*int*/ eventHandle () {
+long eventHandle () {
 	return fixedHandle;
 }
 
 @Override
-long /*int*/ cssHandle () {
+long cssHandle () {
 	if ((style & SWT.SEPARATOR) == 0) {
 		return labelHandle;
 	}
@@ -454,17 +457,12 @@ void releaseWidget () {
 
 @Override
 void resizeHandle (int width, int height) {
-	if (GTK.GTK3) {
-		OS.swt_fixed_resize (GTK.gtk_widget_get_parent (fixedHandle), fixedHandle, width, height);
-		long /*int*/ child = frameHandle != 0 ? frameHandle : handle;
-		Point sizes = resizeCalculationsGTK3 (child, width, height);
-		width = sizes.x;
-		height = sizes.y;
-		OS.swt_fixed_resize (GTK.gtk_widget_get_parent (child), child, width, height);
-	} else {
-		GTK.gtk_widget_set_size_request (fixedHandle, width, height);
-		GTK.gtk_widget_set_size_request (frameHandle != 0 ? frameHandle : handle, width, height);
-	}
+	OS.swt_fixed_resize (GTK.gtk_widget_get_parent (fixedHandle), fixedHandle, width, height);
+	long child = frameHandle != 0 ? frameHandle : handle;
+	Point sizes = resizeCalculationsGTK3 (child, width, height);
+	width = sizes.x;
+	height = sizes.y;
+	OS.swt_fixed_resize (GTK.gtk_widget_get_parent (child), child, width, height);
 }
 
 /**
@@ -491,39 +489,24 @@ public void setAlignment (int alignment) {
 
 void setAlignment () {
 	if ((style & SWT.LEFT) != 0) {
-		if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0)) {
-			gtk_widget_set_align(labelHandle,GTK.GTK_ALIGN_START, GTK.GTK_ALIGN_START); //Aligns widget
-			gtk_label_set_align (0.0f, 0.0f); //Aligns text inside the widget.
-			gtk_widget_set_align(imageHandle, GTK.GTK_ALIGN_START, GTK.GTK_ALIGN_CENTER);
-		} else {
-			GTK.gtk_misc_set_alignment (labelHandle, 0.0f, 0.0f);
-			GTK.gtk_misc_set_alignment (imageHandle, 0.0f, 0.5f);
-		}
+		gtk_widget_set_align(labelHandle,GTK.GTK_ALIGN_START, GTK.GTK_ALIGN_START); //Aligns widget
+		gtk_label_set_align (0.0f, 0.0f); //Aligns text inside the widget.
+		gtk_widget_set_align(imageHandle, GTK.GTK_ALIGN_START, GTK.GTK_ALIGN_CENTER);
 		GTK.gtk_label_set_justify (labelHandle, GTK.GTK_JUSTIFY_LEFT);
 		return;
 	}
 	if ((style & SWT.CENTER) != 0) {
-		if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0)) {
-			gtk_widget_set_align(labelHandle,GTK.GTK_ALIGN_CENTER, GTK.GTK_ALIGN_START); //Aligns widget
-			gtk_label_set_align (0.5f, 0.0f); //Aligns text inside the widget.
-			gtk_widget_set_align(imageHandle, GTK.GTK_ALIGN_CENTER, GTK.GTK_ALIGN_CENTER);
-		} else {
-			GTK.gtk_misc_set_alignment (labelHandle, 0.5f, 0.0f);
-			GTK.gtk_misc_set_alignment (imageHandle, 0.5f, 0.5f);
-		}
+		gtk_widget_set_align(labelHandle,GTK.GTK_ALIGN_CENTER, GTK.GTK_ALIGN_START); //Aligns widget
+		gtk_label_set_align (0.5f, 0.0f); //Aligns text inside the widget.
+		gtk_widget_set_align(imageHandle, GTK.GTK_ALIGN_CENTER, GTK.GTK_ALIGN_CENTER);
 
 		GTK.gtk_label_set_justify (labelHandle, GTK.GTK_JUSTIFY_CENTER);
 		return;
 	}
 	if ((style & SWT.RIGHT) != 0) {
-		if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0)) {
-			gtk_widget_set_align(labelHandle,GTK.GTK_ALIGN_END, GTK.GTK_ALIGN_START); //Aligns widget.
-			gtk_label_set_align (1.0f, 0.0f); //Aligns text inside the widget.
-			gtk_widget_set_align(imageHandle, GTK.GTK_ALIGN_END, GTK.GTK_ALIGN_CENTER);
-		} else  {
-			GTK.gtk_misc_set_alignment (labelHandle, 1.0f, 0.0f);
-			GTK.gtk_misc_set_alignment (imageHandle, 1.0f, 0.5f);
-		}
+		gtk_widget_set_align(labelHandle,GTK.GTK_ALIGN_END, GTK.GTK_ALIGN_START); //Aligns widget.
+		gtk_label_set_align (1.0f, 0.0f); //Aligns text inside the widget.
+		gtk_widget_set_align(imageHandle, GTK.GTK_ALIGN_END, GTK.GTK_ALIGN_CENTER);
 		GTK.gtk_label_set_justify (labelHandle, GTK.GTK_JUSTIFY_RIGHT);
 		return;
 	}
@@ -534,15 +517,6 @@ private void gtk_label_set_align (float xalign, float yalign) {
 	GTK.gtk_label_set_yalign (labelHandle, yalign);
 }
 
-@Override
-void setBackgroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	super.setBackgroundGdkColor (color);
-	setBackgroundGdkColor(fixedHandle, color);
-	if (labelHandle != 0) setBackgroundGdkColor(labelHandle, color);
-	if (imageHandle != 0) setBackgroundGdkColor(imageHandle, color);
-}
-
 @Override
 int setBounds (int x, int y, int width, int height, boolean move, boolean resize) {
 	/*
@@ -592,34 +566,22 @@ int setBounds (int x, int y, int width, int height, boolean move, boolean resize
 }
 
 @Override
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	super.setFontDescription (font);
 	if (labelHandle != 0) setFontDescription (labelHandle, font);
 	if (imageHandle != 0) setFontDescription (imageHandle, font);
 
 	// Bug 445801: Work around for computeSize not returning a different value after
 	// changing font, see https://bugzilla.gnome.org/show_bug.cgi?id=753116
-	if (GTK.GTK3) {
-		// This updates the pango context and also clears the size request cache on the GTK side.
-		int originalDirection = (style & SWT.RIGHT_TO_LEFT) != 0 ? GTK.GTK_TEXT_DIR_RTL : GTK.GTK_TEXT_DIR_LTR;
-		int tempDirection = (style & SWT.RIGHT_TO_LEFT) != 0 ? GTK.GTK_TEXT_DIR_LTR : GTK.GTK_TEXT_DIR_RTL;
-		GTK.gtk_widget_set_direction (labelHandle, tempDirection);
-		GTK.gtk_widget_set_direction (labelHandle, originalDirection);
-	}
-}
-
-@Override
-void setForegroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	super.setForegroundGdkColor(color);
-	setForegroundColor (fixedHandle, color);
-	if (labelHandle != 0) setForegroundColor (labelHandle, color);
-	if (imageHandle != 0) setForegroundColor (imageHandle, color);
+	// This updates the pango context and also clears the size request cache on the GTK side.
+	int originalDirection = (style & SWT.RIGHT_TO_LEFT) != 0 ? GTK.GTK_TEXT_DIR_RTL : GTK.GTK_TEXT_DIR_LTR;
+	int tempDirection = (style & SWT.RIGHT_TO_LEFT) != 0 ? GTK.GTK_TEXT_DIR_LTR : GTK.GTK_TEXT_DIR_RTL;
+	GTK.gtk_widget_set_direction (labelHandle, tempDirection);
+	GTK.gtk_widget_set_direction (labelHandle, originalDirection);
 }
 
 @Override
 void setForegroundGdkRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	super.setForegroundGdkRGBA (rgba);
 	setForegroundGdkRGBA (fixedHandle, rgba);
 	if (labelHandle != 0) setForegroundGdkRGBA (labelHandle, rgba);
@@ -661,13 +623,12 @@ public void setImage (Image image) {
 	imageList = null;
 	if (image != null) {
 		imageList = new ImageList ();
-		int imageIndex = imageList.add (image);
-		long /*int*/ pixbuf = imageList.getPixbuf (imageIndex);
-		gtk_image_set_from_pixbuf (imageHandle, pixbuf);
+		imageList.add (image);
+		GTK.gtk_image_set_from_surface(imageHandle, image.surface);
 		GTK.gtk_widget_hide (labelHandle);
 		GTK.gtk_widget_show (imageHandle);
 	} else {
-		gtk_image_set_from_pixbuf (imageHandle, 0);
+		GTK.gtk_image_set_from_surface(imageHandle, 0);
 		GTK.gtk_widget_show (labelHandle);
 		GTK.gtk_widget_hide (imageHandle);
 	}
@@ -718,12 +679,8 @@ public void setText (String string) {
 
 @Override
 void setWidgetBackground  () {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		GdkRGBA rgba = (state & BACKGROUND) != 0 ? getBackgroundGdkRGBA () : null;
-		super.setBackgroundGdkRGBA (handle, rgba);
-	} else {
-		super.setWidgetBackground();
-	}
+	GdkRGBA rgba = (state & BACKGROUND) != 0 ? getBackgroundGdkRGBA () : null;
+	super.setBackgroundGdkRGBA (handle, rgba);
 }
 
 @Override
@@ -734,35 +691,33 @@ void showWidget () {
 	if (boxHandle != 0) GTK.gtk_widget_show (boxHandle);
 }
 
-long /*int*/ gtk_separator_new (int orientation) {
-	long /*int*/ separator = 0;
-	if (GTK.GTK3) {
-		separator = GTK.gtk_separator_new (orientation);
-	} else {
-		if (orientation == GTK.GTK_ORIENTATION_HORIZONTAL) {
-			separator = GTK.gtk_hseparator_new ();
-		} else {
-			separator = GTK.gtk_vseparator_new ();
-		}
-	}
-	return separator;
-}
-
 @Override
-long /*int*/ windowProc (long /*int*/ handle, long /*int*/ arg0, long /*int*/ user_data) {
+long windowProc (long handle, long arg0, long user_data) {
 	/*
 	 * For Labels/Buttons, the first widget in the tree with a GdkWindow is SwtFixed.
 	 * Unfortunately this fails the check in !GTK_IS_CONTAINER check Widget.windowProc().
 	 * Instead lets override windowProc() here and check for paintHandle() compatibility.
 	 * Fixes bug 481485 without re-introducing bug 483791.
 	 */
-	switch ((int)/*64*/user_data) {
+	switch ((int)user_data) {
 		case DRAW: {
-			if (GTK.GTK_VERSION >= OS.VERSION(3, 9, 0) && paintHandle() == handle) {
+			if (paintHandle() == handle) {
 				return gtk_draw(handle, arg0);
 			}
 		}
 	}
 	return super.windowProc(handle, arg0, user_data);
 }
+
+@Override
+long dpiChanged(long object, long arg0) {
+	super.dpiChanged(object, arg0);
+
+	if (image != null) {
+		image.internal_gtk_refreshImageForZoom();
+		setImage(image);
+	}
+
+	return 0;
+}
 }
