@@ -153,7 +153,7 @@ void createHandle(int index) {
 	gtk_widget_set_has_surface_or_window (handle, true);
 	GTK.gtk_widget_set_can_focus (handle, true);
 	layout = new TextLayout (display);
-	disabledColor = new Color (display, LINK_DISABLED_FOREGROUND);
+	disabledColor = new Color (LINK_DISABLED_FOREGROUND);
 	offsets = new Point [0];
 	ids = new String [0];
 	mnemonics = new int [0];
@@ -330,13 +330,25 @@ public String getText () {
 long gtk_button_press_event (long widget, long event) {
 	long result = super.gtk_button_press_event (widget, event);
 	if (result != 0) return result;
+
 	int eventType = GDK.gdk_event_get_event_type(event);
 	eventType = fixGdkEventTypeValues(eventType);
+
 	int [] eventButton = new int [1];
-	GDK.gdk_event_get_button(event, eventButton);
+	if (GTK.GTK4) {
+		eventButton[0] = GDK.gdk_button_event_get_button(event);
+	} else {
+		GDK.gdk_event_get_button(event, eventButton);
+	}
+
 	double [] eventX = new double [1];
 	double [] eventY = new double [1];
-	GDK.gdk_event_get_coords(event, eventX, eventY);
+	if (GTK.GTK4) {
+		GDK.gdk_event_get_position(event, eventX, eventY);
+	} else {
+		GDK.gdk_event_get_coords(event, eventX, eventY);
+	}
+
 	if (eventButton[0] == 1 && eventType == GDK.GDK_BUTTON_PRESS) {
 		if (focusIndex != -1) setFocus ();
 		int x = (int) eventX[0];
@@ -376,11 +388,22 @@ long gtk_button_release_event (long widget, long event) {
 	long result = super.gtk_button_release_event (widget, event);
 	if (result != 0) return result;
 	if (focusIndex == -1) return result;
+
 	int [] eventButton = new int [1];
-	GDK.gdk_event_get_button(event, eventButton);
+	if (GTK.GTK4) {
+		eventButton[0] = GDK.gdk_button_event_get_button(event);
+	} else {
+		GDK.gdk_event_get_button(event, eventButton);
+	}
+
 	double [] eventX = new double [1];
 	double [] eventY = new double [1];
-	GDK.gdk_event_get_coords(event, eventX, eventY);
+	if (GTK.GTK4) {
+		GDK.gdk_event_get_position(event, eventX, eventY);
+	} else {
+		GDK.gdk_event_get_coords(event, eventX, eventY);
+	}
+
 	if (eventButton[0] == 1) {
 		int x = (int) eventX[0];
 		int y = (int) eventY[0];
@@ -401,16 +424,14 @@ long gtk_button_release_event (long widget, long event) {
 
 @Override
 long gtk_draw (long widget, long cairo) {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		long context = GTK.gtk_widget_get_style_context(widget);
-		GtkAllocation allocation = new GtkAllocation();
-		GTK.gtk_widget_get_allocation (widget, allocation);
-		int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
-		int height = (state & ZERO_HEIGHT) != 0 ? 0 : allocation.height;
-		// We specify a 0 value for x & y as we want the whole widget to be
-		// colored, not some portion of it.
-		GTK.gtk_render_background(context, cairo, 0, 0, width, height);
-	}
+	long context = GTK.gtk_widget_get_style_context(widget);
+	GtkAllocation allocation = new GtkAllocation();
+	GTK.gtk_widget_get_allocation (widget, allocation);
+	int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
+	int height = (state & ZERO_HEIGHT) != 0 ? 0 : allocation.height;
+	// We specify a 0 value for x & y as we want the whole widget to be
+	// colored, not some portion of it.
+	GTK.gtk_render_background(context, cairo, 0, 0, width, height);
 	return super.gtk_draw(widget, cairo);
 }
 
@@ -431,8 +452,14 @@ long gtk_key_press_event (long widget, long eventPtr) {
 	long result = super.gtk_key_press_event (widget, eventPtr);
 	if (result != 0) return result;
 	if (focusIndex == -1) return result;
-	int [] key = new int[1];
-	GDK.gdk_event_get_keyval(eventPtr, key);
+
+	int [] key = new int [1];
+	if (GTK.GTK4) {
+		key[0] = GDK.gdk_key_event_get_keyval(eventPtr);
+	} else {
+		GDK.gdk_event_get_keyval(eventPtr, key);
+	}
+
 	switch (key[0]) {
 		case GDK.GDK_Return:
 		case GDK.GDK_KP_Enter:
@@ -461,13 +488,22 @@ long gtk_key_press_event (long widget, long eventPtr) {
 long gtk_motion_notify_event (long widget, long event) {
 	long result = super.gtk_motion_notify_event (widget, event);
 	if (result != 0) return result;
+
 	double [] eventX = new double [1];
 	double [] eventY = new double [1];
-	GDK.gdk_event_get_coords(event, eventX, eventY);
+
+	int [] state = new int [1];
+	if (GTK.GTK4) {
+		GDK.gdk_event_get_position(event, eventX, eventY);
+		state[0] = GDK.gdk_event_get_modifier_state(event);
+	} else {
+		GDK.gdk_event_get_coords(event, eventX, eventY);
+		GDK.gdk_event_get_state(event, state);
+	}
+
 	int x = (int) eventX[0];
 	int y = (int) eventY[0];
-	int [] state = new int [1];
-	GDK.gdk_event_get_state(event, state);
+
 	if ((style & SWT.MIRRORED) != 0) x = getClientWidth () - x;
 	if ((state[0] & GDK.GDK_BUTTON1_MASK) != 0) {
 		int oldSelection = selection.y;
@@ -543,7 +579,6 @@ void releaseWidget () {
 	if (layout != null)	layout.dispose ();
 	layout = null;
 	linkColor = null;
-	if (disabledColor != null) disabledColor.dispose ();
 	disabledColor = null;
 	offsets = null;
 	ids = null;
