@@ -147,17 +147,15 @@ void createHandle (int index) {
 	GTK.gtk_widget_set_can_focus (handle, true);
 	if ((style & SWT.VERTICAL) != 0) {
 		if (GTK.GTK4) {
-			byte [] name = Converter.wcsToMbcs("w-resize", true);
-			defaultCursor = GDK.gdk_cursor_new_from_name(name, 0);
+			defaultCursor = GDK.gdk_cursor_new_from_name("sb_h_double_arrow", 0);
 		} else {
-			defaultCursor = GDK.gdk_cursor_new_for_display (GDK.gdk_display_get_default(), GDK.GDK_SB_H_DOUBLE_ARROW);
+			defaultCursor = GDK.gdk_cursor_new_from_name (GDK.gdk_display_get_default(), "sb_h_double_arrow");
 		}
 	} else {
 		if (GTK.GTK4) {
-			byte [] name = Converter.wcsToMbcs("ns-resize", true);
-			defaultCursor = GDK.gdk_cursor_new_from_name(name, 0);
+			defaultCursor = GDK.gdk_cursor_new_from_name("sb_v_double_arrow", 0);
 		} else {
-			defaultCursor = GDK.gdk_cursor_new_for_display (GDK.gdk_display_get_default(), GDK.GDK_SB_V_DOUBLE_ARROW);
+			defaultCursor = GDK.gdk_cursor_new_from_name (GDK.gdk_display_get_default(), "sb_v_double_arrow");
 		}
 	}
 }
@@ -172,11 +170,18 @@ long gtk_button_press_event (long widget, long event) {
 	if (result != 0) return result;
 	// Event fields
 	int [] eventButton = new int [1];
-	GDK.gdk_event_get_button(event, eventButton);
+	if (GTK.GTK4) {
+		eventButton[0] = GDK.gdk_button_event_get_button(event);
+	} else {
+		GDK.gdk_event_get_button(event, eventButton);
+	}
+
 	int eventType = GDK.gdk_event_get_event_type(event);
+
 	double [] eventRX = new double [1];
 	double [] eventRY = new double [1];
 	GDK.gdk_event_get_root_coords(event, eventRX, eventRY);
+
 	int eventTime = GDK.gdk_event_get_time(event);
 
 	int button = eventButton[0];
@@ -226,13 +231,21 @@ long gtk_button_press_event (long widget, long event) {
 long gtk_button_release_event (long widget, long event) {
 	long result = super.gtk_button_release_event (widget, event);
 	if (result != 0) return result;
+
 	int [] eventButton = new int [1];
-	GDK.gdk_event_get_button(event, eventButton);
+	if (GTK.GTK4) {
+		eventButton[0] = GDK.gdk_button_event_get_button(event);
+	} else {
+		GDK.gdk_event_get_button(event, eventButton);
+	}
+
 	int eventTime = GDK.gdk_event_get_time(event);
+
 	int button = eventButton[0];
 	if (button != 1) return 0;
 	if (!dragging) return 0;
 	dragging = false;
+
 	GtkAllocation allocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation (handle, allocation);
 	int width = allocation.width;
@@ -257,16 +270,14 @@ long gtk_button_release_event (long widget, long event) {
 
 @Override
 long gtk_draw (long widget, long cairo) {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		long context = GTK.gtk_widget_get_style_context(widget);
-		GtkAllocation allocation = new GtkAllocation();
-		GTK.gtk_widget_get_allocation (widget, allocation);
-		int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
-		int height = (state & ZERO_HEIGHT) != 0 ? 0 : allocation.height;
-		// We specify a 0 value for x & y as we want the whole widget to be
-		// colored, not some portion of it.
-		GTK.gtk_render_background(context, cairo, 0, 0, width, height);
-	}
+	long context = GTK.gtk_widget_get_style_context(widget);
+	GtkAllocation allocation = new GtkAllocation();
+	GTK.gtk_widget_get_allocation (widget, allocation);
+	int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
+	int height = (state & ZERO_HEIGHT) != 0 ? 0 : allocation.height;
+	// We specify a 0 value for x & y as we want the whole widget to be
+	// colored, not some portion of it.
+	GTK.gtk_render_background(context, cairo, 0, 0, width, height);
 	return super.gtk_draw(widget, cairo);
 }
 
@@ -288,10 +299,17 @@ long gtk_focus_in_event (long widget, long event) {
 long gtk_key_press_event (long widget, long eventPtr) {
 	long result = super.gtk_key_press_event (widget, eventPtr);
 	if (result != 0) return result;
-	int [] key = new int[1];
-	GDK.gdk_event_get_keyval(eventPtr, key);
+
+	int [] key = new int [1];
 	int [] state = new int[1];
-	GDK.gdk_event_get_state(eventPtr, state);
+	if (GTK.GTK4) {
+		key[0] = GDK.gdk_key_event_get_keyval(eventPtr);
+		state[0] = GDK.gdk_event_get_modifier_state(eventPtr);
+	} else {
+		GDK.gdk_event_get_keyval(eventPtr, key);
+		GDK.gdk_event_get_state(eventPtr, state);
+	}
+
 	switch (key[0]) {
 		case GDK.GDK_Left:
 		case GDK.GDK_Right:
@@ -371,8 +389,14 @@ long gtk_motion_notify_event (long widget, long eventPtr) {
 	double [] fetchedX = new double [1];
 	double [] fetchedY = new double [1];
 	GDK.gdk_event_get_root_coords(eventPtr, fetchedX, fetchedY);
+
 	int [] state = new int [1];
-	GDK.gdk_event_get_state(eventPtr, state);
+	if (GTK.GTK4) {
+		state[0] = GDK.gdk_event_get_modifier_state(eventPtr);
+	} else {
+		GDK.gdk_event_get_state(eventPtr, state);
+	}
+
 	long gdkResource = gdk_event_get_surface_or_window(eventPtr);
 	boolean isHint;
 	if (GTK.GTK4) {
