@@ -534,9 +534,9 @@ long gtk_button_press_event (long widget, long eventPtr) {
 }
 
 @Override
-long gtk_change_value (long widget, long scroll, long value1, long value2) {
-	detail = (int)scroll;
-	return 0;
+boolean gtk_change_value (long widget, int scroll, double value, long user_data) {
+	detail = scroll;
+	return false;
 }
 
 void gtk_range_get_slider_range (long widget, int [] slider_start, int [] slider_end) {
@@ -579,7 +579,12 @@ long gtk_event_after (long widget, long gdkEvent) {
 	switch (eventType) {
 		case GDK.GDK_BUTTON_RELEASE: {
 			int [] eventButton = new int [1];
-			GDK.gdk_event_get_button(gdkEvent, eventButton);
+			if (GTK.GTK4) {
+				eventButton[0] = GDK.gdk_button_event_get_button(gdkEvent);
+			} else {
+				GDK.gdk_event_get_button(gdkEvent, eventButton);
+			}
+
 			if (eventButton[0] == 1 && detail == GTK.GTK_SCROLL_JUMP) {
 				if (!dragSent) {
 					Event event = new Event ();
@@ -913,13 +918,6 @@ public void setValues (int selection, int minimum, int maximum, int thumb, int i
 	OS.g_signal_handlers_block_matched (adjustmentHandle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, VALUE_CHANGED);
 	GTK.gtk_adjustment_configure(adjustmentHandle, adjustment.value, adjustment.lower, adjustment.upper,
 		adjustment.step_increment, adjustment.page_increment, adjustment.page_size);
-	/*
-	 * gtk_adujustment_value_changed is deprecated on GTK3.18+.
-	 * GTK+ will emit "value-changed" itself whenever the value changes.
-	 * See bug 495413.
-	 */
-	if (GTK.GTK_VERSION < OS.VERSION(3, 18, 0))
-		GTK.gtk_adjustment_value_changed (adjustmentHandle);
 	OS.g_signal_handlers_unblock_matched (adjustmentHandle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, VALUE_CHANGED);
 }
 
