@@ -37,9 +37,12 @@ import org.eclipse.swt.internal.gtk.*;
  * @noextend This class is not intended to be subclassed by clients.
  */
 public abstract class Scrollable extends Control {
-	long /*int*/ scrolledHandle;
+	long scrolledHandle;
 	ScrollBar horizontalBar, verticalBar;
 
+	/** See bug 484682 */
+	static final boolean RESIZE_ON_GETCLIENTAREA = !OS.isX11() || Boolean.getBoolean("org.eclipse.swt.resizeOnGetClientArea");
+
 /**
  * Prevents uninitialized instances from being created outside the package.
  */
@@ -78,7 +81,7 @@ public Scrollable (Composite parent, int style) {
 	super (parent, style);
 }
 
-long /*int*/ clientHandle () {
+long clientHandle () {
 	return handle;
 }
 
@@ -118,14 +121,21 @@ public Rectangle computeTrim (int x, int y, int width, int height) {
 Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 	checkWidget();
 	int border = 0;
-	if (fixedHandle != 0) border += GTK.gtk_container_get_border_width (fixedHandle);
-	if (scrolledHandle != 0) border += GTK.gtk_container_get_border_width (scrolledHandle);
+	if (fixedHandle != 0) border += gtk_container_get_border_width_or_margin (fixedHandle);
+	if (scrolledHandle != 0) border += gtk_container_get_border_width_or_margin (scrolledHandle);
 	int trimX = x - border, trimY = y - border;
 	int trimWidth = width + (border * 2), trimHeight = height + (border * 2);
 	trimHeight += hScrollBarWidth ();
 	trimWidth  += vScrollBarWidth ();
 	if (scrolledHandle != 0) {
-		if (GTK.gtk_scrolled_window_get_shadow_type (scrolledHandle) != GTK.GTK_SHADOW_NONE) {
+		boolean hasFrame;
+		if (GTK.GTK4) {
+			hasFrame = GTK.gtk_scrolled_window_get_has_frame(scrolledHandle);
+		} else {
+			hasFrame = GTK.gtk_scrolled_window_get_shadow_type (scrolledHandle) != GTK.GTK_SHADOW_NONE;
+		}
+
+		if (hasFrame) {
 			Point thickness = getThickness (scrolledHandle);
 			int xthickness = thickness.x;
 			int ythickness = thickness.y;
@@ -202,10 +212,17 @@ void destroyScrollBar (ScrollBar bar) {
 int getBorderWidthInPixels () {
 	checkWidget();
 	int border = 0;
-	if (fixedHandle != 0) border += GTK.gtk_container_get_border_width (fixedHandle);
+	if (fixedHandle != 0) border += gtk_container_get_border_width_or_margin (fixedHandle);
 	if (scrolledHandle != 0) {
-		border += GTK.gtk_container_get_border_width (scrolledHandle);
-		if (GTK.gtk_scrolled_window_get_shadow_type (scrolledHandle) != GTK.GTK_SHADOW_NONE) {
+		border += gtk_container_get_border_width_or_margin (scrolledHandle);
+
+		boolean hasFrame;
+		if (GTK.GTK4) {
+			hasFrame = GTK.gtk_scrolled_window_get_has_frame(scrolledHandle);
+		} else {
+			hasFrame = GTK.gtk_scrolled_window_get_shadow_type (scrolledHandle) != GTK.GTK_SHADOW_NONE;
+		}
+		if (hasFrame) {
 			border += getThickness (scrolledHandle).x;
 		}
 	}
@@ -232,8 +249,10 @@ public Rectangle getClientArea () {
 
 Rectangle getClientAreaInPixels () {
 	checkWidget ();
-	forceResize ();
-	long /*int*/ clientHandle = clientHandle ();
+	if(RESIZE_ON_GETCLIENTAREA) {
+		forceResize ();
+	}
+	long clientHandle = clientHandle ();
 	GtkAllocation allocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation (clientHandle, allocation);
 	int x = allocation.x;
@@ -261,9 +280,11 @@ public ScrollBar getHorizontalBar () {
  * Returns the mode of the receiver's scrollbars. This will be
  * <em>bitwise</em> OR of one or more of the constants defined in class
  * <code>SWT</code>.<br>
+ * <ul>
  * <li><code>SWT.SCROLLBAR_OVERLAY</code> - if receiver
  * uses overlay scrollbars</li>
  * <li><code>SWT.NONE</code> - otherwise</li>
+ * </ul>
  *
  * @return the mode of scrollbars
  *
@@ -280,7 +301,7 @@ public ScrollBar getHorizontalBar () {
  */
 public int getScrollbarsMode () {
 	checkWidget();
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0) && GTK.gtk_scrolled_window_get_overlay_scrolling(scrolledHandle)) {
+	if (GTK.gtk_scrolled_window_get_overlay_scrolling(scrolledHandle)) {
 		return SWT.SCROLLBAR_OVERLAY;
 	}
 	return SWT.NONE;
@@ -302,8 +323,46 @@ public ScrollBar getVerticalBar () {
 }
 
 @Override
-long /*int*/ gtk_scroll_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ result = super.gtk_scroll_event (widget, eventPtr);
+long gtk_draw (long widget, long cairo) {
+	/*
+	 * Draw events destined for an SwtFixed instance will sometimes
+	 * only be redrawing the scrollbars attached to it. GTK will send many
+	 * draw events to an SwtFixed instance if:
+	 *   1) that instance has overlay scrollbars attached to it, and
+	 *   2) the mouse has just left (leave-notify) that SwtFixed widget.
+	 *
+	 * Such extra draw events cause extra SWT.Paint events to be sent and
+	 * reduce performance. The fix is to check if the dirty region in need
+	 * of a redraw is the same region that the scroll bars occupy, and ignore
+	 * draw events that target such cases. See bug 546248.
+	 */
+	boolean overlayScrolling = !OS.GTK_OVERLAY_SCROLLING_DISABLED;
+	if (overlayScrolling && OS.G_OBJECT_TYPE(widget) == OS.swt_fixed_get_type()) {
+		if ((style & SWT.V_SCROLL) != 0 && verticalBar != null) {
+			GtkAllocation verticalBarAlloc = new GtkAllocation();
+			GTK.gtk_widget_get_allocation(verticalBar.handle, verticalBarAlloc);
+			GdkRectangle rect = new GdkRectangle();
+			GDK.gdk_cairo_get_clip_rectangle(cairo, rect);
+			if (rect.width == verticalBarAlloc.width && rect.height == verticalBarAlloc.height) {
+				return 0;
+			}
+		}
+		if ((style & SWT.H_SCROLL) != 0 && horizontalBar != null) {
+			GtkAllocation horizontalBarAlloc = new GtkAllocation();
+			GTK.gtk_widget_get_allocation(horizontalBar.handle, horizontalBarAlloc);
+			GdkRectangle rect = new GdkRectangle();
+			GDK.gdk_cairo_get_clip_rectangle(cairo, rect);
+			if (rect.width == horizontalBarAlloc.width && rect.height == horizontalBarAlloc.height) {
+				return 0;
+			}
+		}
+	}
+	return super.gtk_draw(widget, cairo);
+}
+
+@Override
+long gtk_scroll_event (long widget, long eventPtr) {
+	long result = super.gtk_scroll_event (widget, eventPtr);
 
 	/*
 	* Feature in GTK.  Scrolled windows do not scroll if the scrollbars
@@ -312,11 +371,27 @@ long /*int*/ gtk_scroll_event (long /*int*/ widget, long /*int*/ eventPtr) {
 	*/
 	if ((state & CANVAS) != 0) {
 		ScrollBar scrollBar;
-		GdkEventScroll gdkEvent = new GdkEventScroll ();
-		OS.memmove (gdkEvent, eventPtr, GdkEventScroll.sizeof);
-		if (gdkEvent.direction == GDK.GDK_SCROLL_SMOOTH) {
+		int [] direction = new int[1];
+		boolean fetched;
+		if (GTK.GTK4) {
+			direction[0] = GDK.gdk_scroll_event_get_direction(eventPtr);
+			fetched = direction[0] != GDK.GDK_SCROLL_SMOOTH;
+		} else {
+			fetched = GDK.gdk_event_get_scroll_direction(eventPtr, direction);
+		}
+
+		if (!fetched) {
 			double[] delta_x = new double[1], delta_y = new double [1];
-			if (GDK.gdk_event_get_scroll_deltas (eventPtr, delta_x, delta_y)) {
+			boolean deltasAvailable;
+			if (GTK.GTK4) {
+				GDK.gdk_scroll_event_get_deltas(eventPtr, delta_x, delta_y);
+				// In GTK4, deltas is always available but zero when not GDK_SMOOTH_SCROLL
+				deltasAvailable = true;
+			} else {
+				deltasAvailable = GDK.gdk_event_get_scroll_deltas (eventPtr, delta_x, delta_y);
+			}
+
+			if (deltasAvailable) {
 				if (delta_x [0] != 0) {
 					scrollBar = horizontalBar;
 					if (scrollBar != null && !GTK.gtk_widget_get_visible (scrollBar.handle) && scrollBar.getEnabled()) {
@@ -343,7 +418,7 @@ long /*int*/ gtk_scroll_event (long /*int*/ widget, long /*int*/ eventPtr) {
 				}
 			}
 		} else {
-			if (gdkEvent.direction == GDK.GDK_SCROLL_UP || gdkEvent.direction == GDK.GDK_SCROLL_DOWN) {
+			if (direction[0] == GDK.GDK_SCROLL_UP || direction[0] == GDK.GDK_SCROLL_DOWN) {
 				scrollBar = verticalBar;
 			} else {
 				scrollBar = horizontalBar;
@@ -353,7 +428,7 @@ long /*int*/ gtk_scroll_event (long /*int*/ widget, long /*int*/ eventPtr) {
 				gtk_adjustment_get (scrollBar.adjustmentHandle, adjustment);
 				/* Calculate wheel delta to match GTK+ 2.4 and higher */
 				int wheel_delta = (int) Math.pow(adjustment.page_size, 2.0 / 3.0);
-				if (gdkEvent.direction == GDK.GDK_SCROLL_UP || gdkEvent.direction == GDK.GDK_SCROLL_LEFT)
+				if (direction[0] == GDK.GDK_SCROLL_UP || direction[0] == GDK.GDK_SCROLL_LEFT)
 					wheel_delta = -wheel_delta;
 				int value = (int) Math.max(adjustment.lower,
 						Math.min(adjustment.upper - adjustment.page_size, adjustment.value + wheel_delta));
@@ -400,7 +475,7 @@ boolean setScrollBarVisible (ScrollBar bar, boolean visible) {
 	int [] hsp = new int [1], vsp = new int [1];
 	GTK.gtk_scrolled_window_get_policy (scrolledHandle, hsp, vsp);
 	int policy = visible ? GTK.GTK_POLICY_ALWAYS : GTK.GTK_POLICY_NEVER;
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0) && !visible) {
+	if (!visible) {
 		policy = GTK.GTK_POLICY_EXTERNAL;
 	}
 	if ((bar.style & SWT.HORIZONTAL) != 0) {
@@ -422,9 +497,8 @@ void redrawWidget (int x, int y, int width, int height, boolean redrawAll, boole
 	super.redrawWidget (x, y, width, height, redrawAll, all, trim);
 	if (!GTK.gtk_widget_get_realized (handle)) return;
 	if (!trim) return;
-	long /*int*/ topHandle = topHandle (), paintHandle = paintHandle ();
+	long topHandle = topHandle (), paintHandle = paintHandle ();
 	if (topHandle == paintHandle) return;
-	long /*int*/ window = gtk_widget_get_window (topHandle);
 	GdkRectangle rect = new GdkRectangle ();
 	if (redrawAll) {
 		GtkAllocation allocation = new GtkAllocation ();
@@ -439,7 +513,14 @@ void redrawWidget (int x, int y, int width, int height, boolean redrawAll, boole
 		rect.width = Math.max (0, width);
 		rect.height = Math.max (0, height);
 	}
-	GDK.gdk_window_invalidate_rect (window, rect, all);
+	if (GTK.GTK4) {
+		/* TODO: GTK4 no ability to invalidate surfaces, may need to keep track of
+		 * invalid regions ourselves and do gdk_surface_queue_expose. Will need a different way to force redraws.
+		 * New "render" signal? */
+	} else {
+		long window = gtk_widget_get_window (topHandle);
+		GDK.gdk_window_invalidate_rect (window, rect, all);
+	}
 }
 
 @Override
@@ -469,19 +550,14 @@ void releaseChildren (boolean destroy) {
 
 @Override
 void resizeHandle (int width, int height) {
-	if (GTK.GTK3) {
-		if (fixedHandle != 0) {
-			OS.swt_fixed_resize (GTK.gtk_widget_get_parent(fixedHandle), fixedHandle, width, height);
-		}
-		long /*int*/ child = scrolledHandle != 0 ? scrolledHandle : handle;
-		Point sizes = resizeCalculationsGTK3 (child, width, height);
-		width = sizes.x;
-		height = sizes.y;
-		OS.swt_fixed_resize (GTK.gtk_widget_get_parent(child), child, width, height);
-	} else {
-		if (fixedHandle != 0) GTK.gtk_widget_set_size_request (fixedHandle, width, height);
-		GTK.gtk_widget_set_size_request (scrolledHandle != 0 ? scrolledHandle : handle, width, height);
+	if (fixedHandle != 0) {
+		OS.swt_fixed_resize (GTK.gtk_widget_get_parent(fixedHandle), fixedHandle, width, height);
 	}
+	long child = scrolledHandle != 0 ? scrolledHandle : handle;
+	Point sizes = resizeCalculationsGTK3 (child, width, height);
+	width = sizes.x;
+	height = sizes.y;
+	OS.swt_fixed_resize (GTK.gtk_widget_get_parent(child), child, width, height);
 }
 
 @Override
@@ -491,7 +567,7 @@ void showWidget () {
 }
 
 @Override
-long /*int*/ topHandle () {
+long topHandle () {
 	if (fixedHandle != 0) return fixedHandle;
 	if (scrolledHandle != 0) return scrolledHandle;
 	return super.topHandle ();
@@ -508,17 +584,17 @@ int vScrollBarWidth() {
 
 private Point hScrollbarSize() {
 	if (horizontalBar == null) return new Point(0, 0);
-	long /*int*/ vBarHandle = GTK.gtk_scrolled_window_get_hscrollbar (scrolledHandle);
+	long vBarHandle = GTK.gtk_scrolled_window_get_hscrollbar (scrolledHandle);
 	return scrollBarSize(vBarHandle);
 }
 
 private Point vScrollBarSize() {
 	if (verticalBar == null) return new Point(0, 0);
-	long /*int*/ vBarHandle = GTK.gtk_scrolled_window_get_vscrollbar (scrolledHandle);
+	long vBarHandle = GTK.gtk_scrolled_window_get_vscrollbar (scrolledHandle);
 	return scrollBarSize(vBarHandle);
 }
 
-private Point scrollBarSize(long /*int*/ scrollBarHandle) {
+private Point scrollBarSize(long scrollBarHandle) {
 	if (scrollBarHandle == 0) return new Point(0, 0);
 	GtkRequisition requisition = new GtkRequisition();
 	/*
@@ -526,12 +602,11 @@ private Point scrollBarSize(long /*int*/ scrollBarHandle) {
 	 * Calling gtk_widget_queue_resize() before querying the size
 	 * fixes this issue.
 	 */
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
-		GTK.gtk_widget_queue_resize (scrollBarHandle);
-	}
+	GTK.gtk_widget_queue_resize (scrollBarHandle);
 	gtk_widget_get_preferred_size (scrollBarHandle, requisition);
 	int [] padding = new int [1];
-	GTK.gtk_widget_style_get(scrolledHandle, OS.scrollbar_spacing, padding, 0);
+	// Only GTK3 needs this, GTK4 has the size built-in via gtk_widget_get_preferred_size()
+	if (!GTK.GTK4) GTK.gtk_widget_style_get(scrolledHandle, OS.scrollbar_spacing, padding, 0);
 	int spacing = padding[0];
 	return new Point(requisition.width + spacing, requisition.height + spacing);
 }
