@@ -255,10 +255,10 @@ Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 	Rectangle trim = super.computeTrimInPixels (x, y, width, height);
 	GtkBorder tmp = new GtkBorder();
 	long context = GTK.gtk_widget_get_style_context (handle);
-	int state_flag = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(handle);
+	int state_flag = GTK.gtk_widget_get_state_flags(handle);
 	gtk_style_context_get_padding(context, state_flag, tmp);
 	if ((style & SWT.BORDER) != 0) {
-		int state = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(handle);
+		int state = GTK.gtk_widget_get_state_flags(handle);
 		gtk_style_context_get_border(context, state, tmp);
 		trim.x -= tmp.left;
 		trim.y -= tmp.top;
@@ -318,9 +318,6 @@ void createHandle (int index) {
 		entryHandle = textHandle;
 	}
 	GTK.gtk_editable_set_editable (GTK.GTK4 ? entryHandle : handle, (style & SWT.READ_ONLY) == 0);
-	if (GTK.GTK_VERSION <= OS.VERSION(3, 20, 0)) {
-		GTK.gtk_entry_set_has_frame (GTK.GTK4 ? entryHandle : handle, (style & SWT.BORDER) != 0);
-	}
 	GTK.gtk_spin_button_set_wrap (handle, (style & SWT.WRAP) != 0);
 	imContext = OS.imContextLast();
 	// In GTK 3 font description is inherited from parent widget which is not how SWT has always worked,
@@ -810,9 +807,7 @@ long paintWindow () {
 @Override
 long paintSurface () {
 	long surface = super.paintSurface ();
-	long children = GDK.gdk_surface_get_children (surface);
-	if (children != 0) surface = OS.g_list_data (children);
-	OS.g_list_free (children);
+	/* TODO: GTK4 no access to children of the surface. Need to find alternative, note that class hierarchy can change from GTK3 */
 	return surface;
 }
 
@@ -938,9 +933,7 @@ void setBackgroundGdkRGBA (long context, long handle, GdkRGBA rgba) {
 		super.setBackgroundGdkRGBA(context, handle, rgba);
 	} else {
 		String color = display.gtk_rgba_to_css_string (background);
-		String properties = " {background-image: -gtk-gradient (linear, 0 0, 0 1, color-stop(0, " + color + "), color-stop(1, " + color + "));}";
-		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "spinbutton" : "GtkSpinButton";
-		String css = name + properties;
+		String css = "spinbutton {background-image: -gtk-gradient (linear, 0 0, 0 1, color-stop(0, " + color + "), color-stop(1, " + color + "));}";
 
 		cssBackground = css;
 
@@ -954,10 +947,9 @@ void setCursor (long cursor) {
 	long defaultCursor = 0;
 	if (cursor == 0)  {
 		if (GTK.GTK4) {
-			byte [] name = Converter.wcsToMbcs("text", true);
-			defaultCursor = GDK.gdk_cursor_new_from_name(name, 0);
+			defaultCursor = GDK.gdk_cursor_new_from_name ("xterm", 0);
 		} else {
-			defaultCursor = GDK.gdk_cursor_new_for_display (GDK.gdk_display_get_default(), GDK.GDK_XTERM);
+			defaultCursor = GDK.gdk_cursor_new_from_name (GDK.gdk_display_get_default(), "xterm");
 		}
 	}
 	super.setCursor (cursor != 0 ? cursor : defaultCursor);
@@ -1226,8 +1218,13 @@ boolean checkSubwindow () {
 
 @Override
 boolean translateTraversal (long event) {
-	int [] key = new int[1];
-	GDK.gdk_event_get_keyval(event, key);
+	int [] key = new int [1];
+	if (GTK.GTK4) {
+		key[0] = GDK.gdk_key_event_get_keyval(event);
+	} else {
+		GDK.gdk_event_get_keyval(event, key);
+	}
+
 	switch (key[0]) {
 		case GDK.GDK_KP_Enter:
 		case GDK.GDK_Return: {
