@@ -32,7 +32,7 @@ import org.eclipse.swt.internal.gtk.*;
  * </p><p>
  * Note that although this class is a subclass of <code>Composite</code>,
  * it does not make sense to set a layout on it.
- * </p><p>
+ * </p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>TOP, BOTTOM</dd>
@@ -142,14 +142,6 @@ protected void checkSubclass () {
 	if (!isValidSubclass ()) error (SWT.ERROR_INVALID_SUBCLASS);
 }
 
-@Override
-long /*int*/ childStyle () {
-	long /*int*/ rcStyle = GTK.gtk_widget_get_modifier_style (handle);
-	if ((GTK.gtk_rc_style_get_color_flags (rcStyle, 0) & GTK.GTK_RC_BG) != 0) return 0;
-	GTK.gtk_widget_realize (handle);
-	return GTK.gtk_widget_get_style (handle);
-}
-
 /**
  * Adds the listener to the collection of listeners who will
  * be notified when the user changes the receiver's selection, by sending
@@ -183,7 +175,7 @@ public void addSelectionListener(SelectionListener listener) {
 }
 
 @Override
-long /*int*/ clientHandle () {
+long clientHandle () {
 	int index = GTK.gtk_notebook_get_current_page (handle);
 	if (index != -1 && items [index] != null) {
 		return items [index].pageHandle;
@@ -201,11 +193,8 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	GTK.gtk_notebook_set_scrollable (handle, false);
 	Point notebookSize = computeNativeSize (handle, wHint, hHint, changed);
 	GTK.gtk_notebook_set_scrollable (handle, scrollable);
-	if (GTK.GTK_VERSION >= OS.VERSION (3, 2, 0)) {
-		int[] initialGap = new int[1];
-		GTK.gtk_widget_style_get (handle, OS.initial_gap, initialGap, 0);
-		notebookSize.x += initialGap[0]*2;
-	}
+	int[] initialGap = new int[1];
+	notebookSize.x += initialGap[0]*2;
 	size.x = Math.max (notebookSize.x, size.x);
 	size.y = Math.max (notebookSize.y, size.y);
 	return size;
@@ -215,7 +204,7 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 	checkWidget();
 	forceResize ();
-	long /*int*/ clientHandle = clientHandle ();
+	long clientHandle = clientHandle ();
 	GtkAllocation allocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation (clientHandle, allocation);
 	int clientX = allocation.x;
@@ -238,25 +227,23 @@ Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 Rectangle getClientAreaInPixels () {
 	Rectangle clientRectangle = super.getClientAreaInPixels ();
 
-	if (GTK.GTK3) {
-		/*
-		* Bug 454936 (see also other 454936 references)
-		* SWT's calls to gtk_widget_size_allocate and gtk_widget_set_allocation
-		* causes GTK+ to move the clientHandle's SwtFixed down by the size of the labels.
-		* These calls can come up from 'shell' and TabFolder has no control over these calls.
-		*
-		* This is an undesired side-effect. Client handle's x & y positions should never
-		* be incremented as this is an internal sub-container.
-		*
-		* Note: 0 by 0 was chosen as 1 by 1 shifts controls beyond their original pos.
-		* The long term fix would be to not use widget_*_allocation from higher containers,
-		* but this would require removal of swtFixed.
-		*
-		* This is Gtk3-specific for Tabfolder as the architecture is changed in gtk3 only.
-		*/
-		clientRectangle.x = 0;
-		clientRectangle.y = 0;
-	}
+	/*
+	* Bug 454936 (see also other 454936 references)
+	* SWT's calls to gtk_widget_size_allocate and gtk_widget_set_allocation
+	* causes GTK+ to move the clientHandle's SwtFixed down by the size of the labels.
+	* These calls can come up from 'shell' and TabFolder has no control over these calls.
+	*
+	* This is an undesired side-effect. Client handle's x & y positions should never
+	* be incremented as this is an internal sub-container.
+	*
+	* Note: 0 by 0 was chosen as 1 by 1 shifts controls beyond their original pos.
+	* The long term fix would be to not use widget_*_allocation from higher containers,
+	* but this would require removal of swtFixed.
+	*
+	* This is Gtk3-specific for Tabfolder as the architecture is changed in gtk3 only.
+	*/
+	clientRectangle.x = 0;
+	clientRectangle.y = 0;
 	return clientRectangle;
 }
 
@@ -266,7 +253,7 @@ void createHandle (int index) {
 	state |= HANDLE;
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (fixedHandle, true);
+	gtk_widget_set_has_surface_or_window (fixedHandle, true);
 	handle = GTK.gtk_notebook_new ();
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 	GTK.gtk_container_add (fixedHandle, handle);
@@ -284,7 +271,7 @@ void createWidget (int index) {
 }
 
 void createItem (TabItem item, int index) {
-	long /*int*/ list = GTK.gtk_container_get_children (handle);
+	long list = GTK.gtk_container_get_children (handle);
 	int itemCount = 0;
 	if (list != 0) {
 		itemCount = OS.g_list_length (list);
@@ -296,15 +283,15 @@ void createItem (TabItem item, int index) {
 		System.arraycopy (items, 0, newItems, 0, items.length);
 		items = newItems;
 	}
-	long /*int*/ boxHandle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 0);
+	long boxHandle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 0);
 	if (boxHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	long /*int*/ labelHandle = GTK.gtk_label_new_with_mnemonic (null);
+	long labelHandle = GTK.gtk_label_new_with_mnemonic (null);
 	if (labelHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	long /*int*/ imageHandle = GTK.gtk_image_new ();
+	long imageHandle = GTK.gtk_image_new ();
 	if (imageHandle == 0) error (SWT.ERROR_NO_HANDLES);
 	GTK.gtk_container_add (boxHandle, imageHandle);
 	GTK.gtk_container_add (boxHandle, labelHandle);
-	long /*int*/ pageHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
+	long pageHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (pageHandle == 0) error (SWT.ERROR_NO_HANDLES);
 	OS.g_signal_handlers_block_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, SWITCH_PAGE);
 	GTK.gtk_notebook_insert_page (handle, pageHandle, boxHandle, index);
@@ -320,7 +307,7 @@ void createItem (TabItem item, int index) {
 	System.arraycopy (items, index, items, index + 1, itemCount++ - index);
 	items [index] = item;
 	if ((state & FOREGROUND) != 0) {
-		item.setForegroundGdkColor (getForegroundGdkColor());
+		item.setForegroundGdkRGBA (item.handle, getForegroundGdkRGBA());
 	}
 	if ((state & FONT) != 0) {
 		item.setFontDescription (getFontDescription());
@@ -367,51 +354,46 @@ void destroyItem (TabItem item) {
 }
 
 @Override
-long /*int*/ eventHandle () {
+long eventHandle () {
 	return handle;
 }
 
 @Override
 Control[] _getChildren() {
 	Control [] directChildren = super._getChildren ();
-	if (GTK.GTK3) {
-		int directCount = directChildren.length;
-		int count = items == null ? 0 : items.length;
-		Control [] children = new Control [count + directCount];
-		int i = 0;
-		for (int j = 0; j < count; j++) {
-			TabItem tabItem = items[j];
-			if (tabItem != null && !tabItem.isDisposed()) {
-				long /*int*/ parentHandle = tabItem.pageHandle;
-				long /*int*/ list = GTK.gtk_container_get_children (parentHandle);
-				if (list != 0) {
-					long /*int*/ handle = OS.g_list_data (list);
-					if (handle != 0) {
-						Widget widget = display.getWidget (handle);
-						if (widget != null && widget != this) {
-							if (widget instanceof Control) {
-								children [i++] = (Control) widget;
-							}
+	int directCount = directChildren.length;
+	int count = items == null ? 0 : items.length;
+	Control [] children = new Control [count + directCount];
+	int i = 0;
+	for (int j = 0; j < count; j++) {
+		TabItem tabItem = items[j];
+		if (tabItem != null && !tabItem.isDisposed()) {
+			long parentHandle = tabItem.pageHandle;
+			long list = GTK.gtk_container_get_children (parentHandle);
+			if (list != 0) {
+				long handle = OS.g_list_data (list);
+				if (handle != 0) {
+					Widget widget = display.getWidget (handle);
+					if (widget != null && widget != this) {
+						if (widget instanceof Control) {
+							children [i++] = (Control) widget;
 						}
 					}
-					OS.g_list_free (list);
 				}
+				OS.g_list_free (list);
 			}
 		}
-		if (i == count + directCount) return children;
-		Control [] newChildren;
-		if (i == count) {
-			newChildren = children;
-		} else {
-			newChildren = new Control [i + directCount];
-			System.arraycopy (children, 0, newChildren, 0, i);
-		}
-		System.arraycopy (directChildren, 0, newChildren, i, directCount);
-		return newChildren;
-
-	} else {
-		return directChildren;
 	}
+	if (i == count + directCount) return children;
+	Control [] newChildren;
+	if (i == count) {
+		newChildren = children;
+	} else {
+		newChildren = new Control [i + directCount];
+		System.arraycopy (children, 0, newChildren, 0, i);
+	}
+	System.arraycopy (directChildren, 0, newChildren, i, directCount);
+	return newChildren;
 }
 
 /**
@@ -432,7 +414,7 @@ Control[] _getChildren() {
 public TabItem getItem (int index) {
 	checkWidget();
 	if (!(0 <= index && index < getItemCount())) error (SWT.ERROR_INVALID_RANGE);
-	long /*int*/ list = GTK.gtk_container_get_children (handle);
+	long list = GTK.gtk_container_get_children (handle);
 	if (list == 0) error (SWT.ERROR_CANNOT_GET_ITEM);
 	int itemCount = OS.g_list_length (list);
 	OS.g_list_free (list);
@@ -461,7 +443,7 @@ public TabItem getItem (int index) {
 public TabItem getItem(Point point) {
 	checkWidget();
 	if (point == null) error (SWT.ERROR_NULL_ARGUMENT);
-	long /*int*/ list = GTK.gtk_container_get_children (handle);
+	long list = GTK.gtk_container_get_children (handle);
 	if (list == 0) return null;
 	int itemCount = OS.g_list_length (list);
 	OS.g_list_free (list);
@@ -485,7 +467,7 @@ public TabItem getItem(Point point) {
  */
 public int getItemCount () {
 	checkWidget();
-	long /*int*/ list = GTK.gtk_container_get_children (handle);
+	long list = GTK.gtk_container_get_children (handle);
 	if (list == 0) return 0;
 	int itemCount = OS.g_list_length (list);
 	OS.g_list_free (list);
@@ -556,12 +538,12 @@ public int getSelectionIndex () {
 }
 
 @Override
-long /*int*/ gtk_focus (long /*int*/ widget, long /*int*/ directionType) {
+long gtk_focus (long widget, long directionType) {
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_switch_page (long /*int*/ widget, long /*int*/ page, long /*int*/ page_num) {
+long gtk_switch_page (long widget, long page, long page_num) {
 	int index = GTK.gtk_notebook_get_current_page (handle);
 	if (index != -1) {
 		Control control = items [index].getControl ();
@@ -571,7 +553,7 @@ long /*int*/ gtk_switch_page (long /*int*/ widget, long /*int*/ page, long /*int
 	} else {
 		return 0;
 	}
-	TabItem item = items [(int)/*64*/page_num];
+	TabItem item = items [(int)page_num];
 	Control control = item.getControl ();
 	if (control != null && !control.isDisposed ()) {
 		control.setBoundsInPixels(getClientAreaInPixels());
@@ -609,7 +591,7 @@ void hookEvents () {
 public int indexOf (TabItem item) {
 	checkWidget();
 	if (item == null) error (SWT.ERROR_NULL_ARGUMENT);
-	long /*int*/ list = GTK.gtk_container_get_children (handle);
+	long list = GTK.gtk_container_get_children (handle);
 	if (list == 0) return -1;
 	int count = OS.g_list_length (list);
 	OS.g_list_free (list);
@@ -627,7 +609,7 @@ Point minimumSize (int wHint, int hHint, boolean flushCache) {
 		Control child = children [i];
 		int index = 0;
 		int count = 0;
-		long /*int*/ list = GTK.gtk_container_get_children (handle);
+		long list = GTK.gtk_container_get_children (handle);
 		if (list != 0) {
 			count = OS.g_list_length (list);
 			OS.g_list_free (list);
@@ -657,7 +639,7 @@ Point minimumSize (int wHint, int hHint, boolean flushCache) {
 boolean mnemonicHit (char key) {
 	int itemCount = getItemCount ();
 	for (int i=0; i<itemCount; i++) {
-		long /*int*/ labelHandle = items [i].labelHandle;
+		long labelHandle = items [i].labelHandle;
 		if (labelHandle != 0 && mnemonicHit (labelHandle, key)) return true;
 	}
 	return false;
@@ -667,7 +649,7 @@ boolean mnemonicHit (char key) {
 boolean mnemonicMatch (char key) {
 	int itemCount = getItemCount ();
 	for (int i=0; i<itemCount; i++) {
-		long /*int*/ labelHandle = items [i].labelHandle;
+		long labelHandle = items [i].labelHandle;
 		if (labelHandle != 0 && mnemonicHit (labelHandle, key)) return true;
 	}
 	return false;
@@ -732,7 +714,7 @@ public void removeSelectionListener (SelectionListener listener) {
 @Override
 void reskinChildren (int flags) {
 	if (items != null) {
-		long /*int*/ list = GTK.gtk_container_get_children (handle);
+		long list = GTK.gtk_container_get_children (handle);
 		if (list != 0){
 			int count = OS.g_list_length (list);
 			OS.g_list_free (list);
@@ -746,22 +728,16 @@ void reskinChildren (int flags) {
 }
 
 @Override
-void setBackgroundGdkRGBA (long /*int*/ context, long /*int*/ handle, GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
-    if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-    	// Form background string
-    	String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "notebook header" : "GtkNotebook.header";
-        String css = name + " {background-color: " + display.gtk_rgba_to_css_string (rgba) + ";}";
+void setBackgroundGdkRGBA (long context, long handle, GdkRGBA rgba) {
+	// Form background string
+	String css = "notebook header {background-color: " + display.gtk_rgba_to_css_string (rgba) + ";}";
 
-        // Cache background
-        cssBackground = css;
+		// Cache background
+		cssBackground = css;
 
-        // Apply background color and any cached foreground color
-        String finalCss = display.gtk_css_create_css_color_string (cssBackground, cssForeground, SWT.BACKGROUND);
-        gtk_css_provider_load_from_css (context, finalCss);
-    } else {
-            GTK.gtk_widget_override_background_color (handle, GTK.GTK_STATE_FLAG_NORMAL, rgba);
-    }
+		// Apply background color and any cached foreground color
+	String finalCss = display.gtk_css_create_css_color_string (cssBackground, cssForeground, SWT.BACKGROUND);
+	gtk_css_provider_load_from_css (context, finalCss);
 }
 
 @Override
@@ -781,7 +757,7 @@ int setBounds (int x, int y, int width, int height, boolean move, boolean resize
 }
 
 @Override
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	super.setFontDescription (font);
 	TabItem [] items = getItems ();
 	for (int i = 0; i < items.length; i++) {
@@ -793,7 +769,6 @@ void setFontDescription (long /*int*/ font) {
 
 @Override
 void setForegroundGdkRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	super.setForegroundGdkRGBA(rgba);
 	TabItem [] items = getItems ();
 	for (int i = 0; i < items.length; i++) {
@@ -803,18 +778,6 @@ void setForegroundGdkRGBA (GdkRGBA rgba) {
 	}
 }
 
-@Override
-void setForegroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	super.setForegroundGdkColor (color);
-	TabItem [] items = getItems ();
-	for (int i = 0; i < items.length; i++) {
-		if (items[i] != null) {
-			items[i].setForegroundGdkColor (color);
-		}
-	}
-}
-
 @Override
 void setOrientation (boolean create) {
 	super.setOrientation (create);
