@@ -22,13 +22,13 @@ import org.eclipse.swt.internal.gtk.*;
 
 /**
  * Instances of this class represent a column in a table widget.
- * <p><dl>
+ * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>LEFT, RIGHT, CENTER</dd>
  * <dt><b>Events:</b></dt>
  * <dd> Move, Resize, Selection</dd>
  * </dl>
- * </p><p>
+ * <p>
  * Note: Only one of the styles LEFT, RIGHT and CENTER may be specified.
  * </p><p>
  * IMPORTANT: This class is <em>not</em> intended to be subclassed.
@@ -39,7 +39,7 @@ import org.eclipse.swt.internal.gtk.*;
  * @noextend This class is not intended to be subclassed by clients.
  */
 public class TableColumn extends Item {
-	long /*int*/ labelHandle, imageHandle, buttonHandle;
+	long labelHandle, imageHandle, buttonHandle;
 	Table parent;
 	int modelIndex, lastButton, lastTime, lastX, lastWidth;
 	boolean customDraw, useFixedWidth;
@@ -337,7 +337,7 @@ int getWidthInPixels () {
 }
 
 @Override
-long /*int*/ gtk_clicked (long /*int*/ widget) {
+long gtk_clicked (long widget) {
 	/*
 	* There is no API to get a double click on a table column.  Normally, when
 	* the mouse is double clicked, this is indicated by GDK_2BUTTON_PRESS
@@ -347,38 +347,53 @@ long /*int*/ gtk_clicked (long /*int*/ widget) {
 	*/
 	boolean doubleClick = false;
 	boolean postEvent = true;
-	long /*int*/ eventPtr = GTK.gtk_get_current_event ();
+	long eventPtr = GTK.gtk_get_current_event ();
 	if (eventPtr != 0) {
-		GdkEventButton gdkEvent = new GdkEventButton ();
-		OS.memmove (gdkEvent, eventPtr, GdkEventButton.sizeof);
-		GDK.gdk_event_free (eventPtr);
-		switch (gdkEvent.type) {
+		int [] eventButton = new int [1];
+		if (GTK.GTK4) {
+			eventButton[0] = GDK.gdk_button_event_get_button(eventPtr);
+		} else {
+			GDK.gdk_event_get_button(eventPtr, eventButton);
+		}
+
+		int eventType = GDK.gdk_event_get_event_type(eventPtr);
+		eventType = Control.fixGdkEventTypeValues(eventType);
+		int eventTime = GDK.gdk_event_get_time(eventPtr);
+		switch (eventType) {
 			case GDK.GDK_BUTTON_RELEASE: {
 				int clickTime = display.getDoubleClickTime ();
-				int eventTime = gdkEvent.time, eventButton = gdkEvent.button;
-				if (lastButton == eventButton && lastTime != 0 && Math.abs (lastTime - eventTime) <= clickTime) {
+				if (lastButton == eventButton[0] && lastTime != 0 && Math.abs (lastTime - eventTime) <= clickTime) {
 					doubleClick = true;
 				}
 				lastTime = eventTime == 0 ? 1: eventTime;
-				lastButton = eventButton;
+				lastButton = eventButton[0];
 				break;
 			}
 		}
+		gdk_event_free (eventPtr);
 	}
 	if (postEvent) sendSelectionEvent (doubleClick ? SWT.DefaultSelection : SWT.Selection);
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
-	GdkEvent event = new GdkEvent ();
-	OS.memmove (event, gdkEvent, GdkEvent.sizeof);
-	switch (event.type) {
+long gtk_event_after (long widget, long gdkEvent) {
+	int eventType = GDK.gdk_event_get_event_type(gdkEvent);
+	eventType = Control.fixGdkEventTypeValues(eventType);
+	switch (eventType) {
 		case GDK.GDK_BUTTON_PRESS: {
-			GdkEventButton gdkEventButton = new GdkEventButton ();
-			OS.memmove (gdkEventButton, gdkEvent, GdkEventButton.sizeof);
-			if (gdkEventButton.button == 3) {
-				parent.showMenu ((int) gdkEventButton.x_root, (int) gdkEventButton.y_root);
+			int [] eventButton = new int [1];
+			if (GTK.GTK4) {
+				eventButton[0] = GDK.gdk_button_event_get_button(gdkEvent);
+			} else {
+				GDK.gdk_event_get_button(gdkEvent, eventButton);
+			}
+
+			if (eventButton[0] == 3) {
+				double [] eventRX = new double [1];
+				double [] eventRY = new double [1];
+				GDK.gdk_event_get_root_coords(gdkEvent, eventRX, eventRY);
+				parent.showMenu ((int) eventRX[0], (int) eventRY[0]);
 			}
 			break;
 		}
@@ -387,12 +402,12 @@ long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
 }
 
 @Override
-long /*int*/ gtk_mnemonic_activate (long /*int*/ widget, long /*int*/ arg1) {
+long gtk_mnemonic_activate (long widget, long arg1) {
 	return parent.gtk_mnemonic_activate (widget, arg1);
 }
 
 @Override
-long /*int*/ gtk_size_allocate (long /*int*/ widget, long /*int*/ allocation) {
+long gtk_size_allocate (long widget, long allocation) {
 	useFixedWidth = false;
 	GtkAllocation widgetAllocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation (widget, widgetAllocation);
@@ -414,6 +429,11 @@ long /*int*/ gtk_size_allocate (long /*int*/ widget, long /*int*/ allocation) {
 		lastWidth = width;
 		sendEvent (SWT.Resize);
 	}
+	/*
+	 * Bug 545645: Updating SWT.VIRTUAL table sets header button can_focus to true,
+	 * set it back to false to avoid header being focused on click.
+	 */
+	GTK.gtk_widget_set_can_focus(buttonHandle, false);
 	return 0;
 }
 
@@ -423,7 +443,11 @@ void hookEvents () {
 	OS.g_signal_connect_closure (handle, OS.clicked, display.getClosure (CLICKED), false);
 	if (buttonHandle != 0) {
 		OS.g_signal_connect_closure_by_id (buttonHandle, display.signalIds [SIZE_ALLOCATE], 0, display.getClosure (SIZE_ALLOCATE), false);
-		OS.g_signal_connect_closure_by_id (buttonHandle, display.signalIds [EVENT_AFTER], 0, display.getClosure (EVENT_AFTER), false);
+		if (GTK.GTK4) {
+			OS.g_signal_connect_closure_by_id (buttonHandle, display.signalIds [EVENT], 0, display.getClosure (EVENT), false);
+		} else {
+			OS.g_signal_connect_closure_by_id (buttonHandle, display.signalIds [EVENT_AFTER], 0, display.getClosure (EVENT_AFTER), false);
+		}
 	}
 	if (labelHandle != 0) OS.g_signal_connect_closure_by_id (labelHandle, display.signalIds [MNEMONIC_ACTIVATE], 0, display.getClosure (MNEMONIC_ACTIVATE), false);
 }
@@ -476,7 +500,7 @@ public void pack () {
 			}
 		}
 	} else {
-		long /*int*/ iter = OS.g_malloc (GTK.GtkTreeIter_sizeof ());
+		long iter = OS.g_malloc (GTK.GtkTreeIter_sizeof ());
 		if (GTK.gtk_tree_model_get_iter_first (parent.modelHandle, iter)) {
 			do {
 				width = Math.max (width, parent.calculateWidth (handle, iter));
@@ -586,7 +610,7 @@ public void setAlignment (int alignment) {
 	parent.createRenderers (handle, modelIndex, index == 0, style);
 }
 
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	setFontDescription (labelHandle, font);
 	setFontDescription (imageHandle, font);
 }
@@ -602,11 +626,10 @@ public void setImage (Image image) {
 		}
 		int imageIndex = headerImageList.indexOf (image);
 		if (imageIndex == -1) imageIndex = headerImageList.add (image);
-		long /*int*/ pixbuf = headerImageList.getPixbuf (imageIndex);
-		gtk_image_set_from_gicon (imageHandle, pixbuf);
+		GTK.gtk_image_set_from_surface(imageHandle, image.surface);
 		GTK.gtk_widget_show (imageHandle);
 	} else {
-		gtk_image_set_from_gicon (imageHandle, 0);
+		GTK.gtk_image_set_from_surface(imageHandle, 0);
 		GTK.gtk_widget_hide (imageHandle);
 	}
 }
@@ -696,7 +719,7 @@ public void setText (String string) {
  * </p>
  * <p>
  * NOTE: This operation is a hint and behavior is platform specific, on Windows
- * for CJK-style mnemonics of the form " (&C)" at the end of the tooltip text
+ * for CJK-style mnemonics of the form " (&amp;C)" at the end of the tooltip text
  * are not shown in tooltip.
  * </p>
  *
@@ -760,22 +783,27 @@ void setWidthInPixels (int width) {
 	 */
 	if (width != 0) {
 		if (buttonHandle != 0) {
-			long /*int*/ window = GTK.gtk_widget_get_parent_window (buttonHandle);
-			if (window != 0) {
-				long /*int*/ windowList = GDK.gdk_window_get_children (window);
-				if (windowList != 0) {
-					long /*int*/ windows = windowList;
-					long /*int*/ [] userData = new long /*int*/ [1];
-					while (windows != 0) {
-						long /*int*/ child = OS.g_list_data (windows);
-						GDK.gdk_window_get_user_data (child, userData);
-						if (userData[0] == buttonHandle) {
-							GDK.gdk_window_lower (child);
-							break;
+			if (GTK.GTK4) {
+				/* TODO: GTK4 Removed this for time being, as not confirm if this bug still exists. Has to be
+				 * removed since the fix requires functions that no longer exist in GTK4. */
+			} else {
+				long window = GTK.gtk_widget_get_parent_window (buttonHandle);
+				if (window != 0) {
+					long windowList = GDK.gdk_window_get_children (window);
+					if (windowList != 0) {
+						long windows = windowList;
+						long [] userData = new long [1];
+						while (windows != 0) {
+							long child = OS.g_list_data (windows);
+							GDK.gdk_window_get_user_data (child, userData);
+							if (userData[0] == buttonHandle) {
+								GDK.gdk_window_lower (child);
+								break;
+							}
+							windows = OS.g_list_next (windows);
 						}
-						windows = OS.g_list_next (windows);
+						OS.g_list_free (windowList);
 					}
-					OS.g_list_free (windowList);
 				}
 			}
 		}
@@ -783,4 +811,15 @@ void setWidthInPixels (int width) {
 	sendEvent (SWT.Resize);
 }
 
+@Override
+long dpiChanged(long object, long arg0) {
+	super.dpiChanged(object, arg0);
+
+	if (image != null) {
+		image.internal_gtk_refreshImageForZoom();
+		setImage(image);
+	}
+
+	return 0;
+}
 }
