@@ -52,11 +52,7 @@ public class ToolBar extends Composite {
 	ToolItem [] tabItemList;
 	ImageList imageList;
 	boolean hasChildFocus;
-	static Callback menuItemSelectedFunc;
-	static {
-		menuItemSelectedFunc = new Callback(ToolBar.class, "MenuItemSelectedProc", 2);
-		if (menuItemSelectedFunc.getAddress() == 0) SWT.error(SWT.ERROR_NO_MORE_CALLBACKS);
-	}
+	static Callback menuItemSelectedFunc = new Callback(ToolBar.class, "MenuItemSelectedProc", 2);
 	String cssBackground, cssForeground = " ";
 
 /**
@@ -133,7 +129,13 @@ void createHandle (int index) {
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
 	gtk_widget_set_has_surface_or_window (fixedHandle, true);
-	handle = GTK.gtk_toolbar_new ();
+
+	if (GTK.GTK4) {
+		handle = GTK.gtk_box_new(GTK.GTK_ORIENTATION_HORIZONTAL, 0);
+	} else {
+		handle = GTK.gtk_toolbar_new ();
+	}
+
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 	GTK.gtk_container_add (fixedHandle, handle);
 
@@ -147,7 +149,7 @@ void createHandle (int index) {
 	* tool bar preferred size is too big with GTK_ICON_SIZE_LARGE_TOOLBAR
 	* when the tool bar item has no image or text.
 	*/
-	GTK.gtk_toolbar_set_icon_size (handle, GTK.GTK_ICON_SIZE_SMALL_TOOLBAR);
+	if (!GTK.GTK4) GTK.gtk_toolbar_set_icon_size (handle, GTK.GTK_ICON_SIZE_SMALL_TOOLBAR);
 
 	// In GTK 3 font description is inherited from parent widget which is not how SWT has always worked,
 	// reset to default font to get the usual behavior
@@ -164,15 +166,25 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	checkWidget ();
 	if (wHint != SWT.DEFAULT && wHint < 0) wHint = 0;
 	if (hHint != SWT.DEFAULT && hHint < 0) hHint = 0;
-	/*
-	 * Feature in GTK. Size of toolbar is calculated incorrectly
-	 * and appears as just the overflow arrow, if the arrow is enabled
-	 * to display. The fix is to disable it before the computation of
-	 * size and enable it if WRAP style is set.
-	 */
-	GTK.gtk_toolbar_set_show_arrow (handle, false);
-	Point size = computeNativeSize (handle, wHint, hHint, changed);
-	if ((style & SWT.WRAP) != 0) GTK.gtk_toolbar_set_show_arrow (handle, true);
+
+	Point size = null;
+
+	if (GTK.GTK4) {
+		/* TODO: GTK4 will require us to implement our own
+		 * overflow menu. May require the use of the "toolbar" style class
+		 * applied to the widget.  */
+	} else {
+		/*
+		 * Feature in GTK. Size of toolbar is calculated incorrectly
+		 * and appears as just the overflow arrow, if the arrow is enabled
+		 * to display. The fix is to disable it before the computation of
+		 * size and enable it if WRAP style is set.
+		 */
+		GTK.gtk_toolbar_set_show_arrow (handle, false);
+		size = computeNativeSize (handle, wHint, hHint, changed);
+		if ((style & SWT.WRAP) != 0) GTK.gtk_toolbar_set_show_arrow (handle, true);
+	}
+
 	return size;
 }
 
@@ -524,19 +536,25 @@ void relayout () {
 			hasImage |= item.image != null;
 		}
 	}
-	int type = GTK.GTK_TOOLBAR_ICONS;
-	if (hasText && hasImage) {
-		if ((style & SWT.RIGHT) != 0) {
-			type = GTK.GTK_TOOLBAR_BOTH_HORIZ;
-		} else {
-			type = GTK.GTK_TOOLBAR_BOTH;
+
+	if (GTK.GTK4) {
+		/* TODO: GTK4 no more GtkToolbar, we have to use a generic GtkBox
+		 * therefore we will need to implement these style ourselves. */
+	} else {
+		int type = GTK.GTK_TOOLBAR_ICONS;
+		if (hasText && hasImage) {
+			if ((style & SWT.RIGHT) != 0) {
+				type = GTK.GTK_TOOLBAR_BOTH_HORIZ;
+			} else {
+				type = GTK.GTK_TOOLBAR_BOTH;
+			}
+		} else if (hasText) {
+			type = GTK.GTK_TOOLBAR_TEXT;
+		} else if (hasImage) {
+			type = GTK.GTK_TOOLBAR_ICONS;
 		}
-	} else if (hasText) {
-		type = GTK.GTK_TOOLBAR_TEXT;
-	} else if (hasImage) {
-		type = GTK.GTK_TOOLBAR_ICONS;
+		GTK.gtk_toolbar_set_style (handle, type);
 	}
-	GTK.gtk_toolbar_set_style (handle, type);
 }
 
 @Override
@@ -585,26 +603,30 @@ int setBounds (int x, int y, int width, int height, boolean move, boolean resize
 	GTK.gtk_toolbar_set_show_arrow (handle, false);
 	int result = super.setBounds (x, y, width, height, move, resize);
 	if ((result & RESIZED) != 0) relayout ();
-	if ((style & SWT.WRAP) != 0) GTK.gtk_toolbar_set_show_arrow (handle, true);
+	if ((style & SWT.WRAP) != 0) {
+		if (GTK.GTK4) {
+			/* TODO: GTK4 will require us to implement our own
+			 * overflow menu. May require the use of the "toolbar" style class
+			 * applied to the widget.  */
+		} else {
+			GTK.gtk_toolbar_set_show_arrow (handle, true);
+		}
+	}
+
 	return result;
 }
 
 @Override
 void setBackgroundGdkRGBA (long context, long handle, GdkRGBA rgba) {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		// Form background string
-		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "toolbar" : "GtkToolbar";
-		String css = name + " {background-color: " + display.gtk_rgba_to_css_string(rgba) + "}";
+	// Form background string
+	String css = "toolbar {background-color: " + display.gtk_rgba_to_css_string(rgba) + "}";
 
-		// Cache background color
-		this.cssBackground = css;
+	// Cache background color
+	this.cssBackground = css;
 
-		// Apply background color and any foreground color
-		String finalCss = display.gtk_css_create_css_color_string (this.cssBackground, this.cssForeground, SWT.BACKGROUND);
-		gtk_css_provider_load_from_css(context, finalCss);
-	} else {
-		super.setBackgroundGdkRGBA(context, handle, rgba);
-	}
+	// Apply background color and any foreground color
+	String finalCss = display.gtk_css_create_css_color_string (this.cssBackground, this.cssForeground, SWT.BACKGROUND);
+	gtk_css_provider_load_from_css(context, finalCss);
 }
 
 @Override
@@ -615,32 +637,26 @@ void setParentBackground () {
 
 @Override
 void setForegroundGdkRGBA (long handle, GdkRGBA rgba) {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		GdkRGBA toSet = new GdkRGBA();
-		if (rgba != null) {
-			toSet = rgba;
-		} else {
-			toSet = display.COLOR_WIDGET_FOREGROUND_RGBA;
-		}
-		long context = GTK.gtk_widget_get_style_context (handle);
-		// Form foreground string
-		String color = display.gtk_rgba_to_css_string(toSet);
-		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? display.gtk_widget_class_get_css_name(handle)
-				: display.gtk_widget_get_name(handle);
-		GdkRGBA selectedForeground = display.COLOR_LIST_SELECTION_TEXT_RGBA;
-		String selection = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? " selection" : ":selected";
-		String css = "* {color: " + color + ";}\n"
-				+ name + selection + " {color: " + display.gtk_rgba_to_css_string(selectedForeground) + ";}";
-
-		// Cache foreground color
-		this.cssForeground = css;
-
-		// Apply foreground color and any cached background color
-		String finalCss = display.gtk_css_create_css_color_string (this.cssBackground, this.cssForeground, SWT.FOREGROUND);
-		gtk_css_provider_load_from_css(context, finalCss);
+	GdkRGBA toSet = new GdkRGBA();
+	if (rgba != null) {
+		toSet = rgba;
 	} else {
-		super.setForegroundGdkRGBA(handle, rgba);
+		toSet = display.COLOR_WIDGET_FOREGROUND_RGBA;
 	}
+	long context = GTK.gtk_widget_get_style_context (handle);
+	// Form foreground string
+	String color = display.gtk_rgba_to_css_string(toSet);
+	String name = display.gtk_widget_class_get_css_name(handle);
+	GdkRGBA selectedForeground = display.COLOR_LIST_SELECTION_TEXT_RGBA;
+	String css = "* {color: " + color + ";}\n"
+			+ name + " selection {color: " + display.gtk_rgba_to_css_string(selectedForeground) + ";}";
+
+	// Cache foreground color
+	this.cssForeground = css;
+
+	// Apply foreground color and any cached background color
+	String finalCss = display.gtk_css_create_css_color_string (this.cssBackground, this.cssForeground, SWT.FOREGROUND);
+	gtk_css_provider_load_from_css(context, finalCss);
 }
 
 @Override
