@@ -50,6 +50,7 @@ public class ToolItem extends Item {
 	boolean drawHotImage;
 	/** True iff map has been hooked for this ToolItem. See bug 546914. */
 	boolean mapHooked;
+	boolean enabled = true;
 
 /**
  * Constructs a new instance of this class given its parent
@@ -197,12 +198,22 @@ void createHandle (int index) {
 	}
 	switch (style & bits) {
 		case SWT.SEPARATOR:
-			handle = GTK.gtk_separator_tool_item_new ();
-			if (handle == 0) error (SWT.ERROR_NO_HANDLES);
-			GTK.gtk_separator_tool_item_set_draw (handle, true);
+			if (GTK.GTK4) {
+				handle = GTK.gtk_separator_new(GTK.GTK_ORIENTATION_VERTICAL);
+				if (handle == 0) error (SWT.ERROR_NO_HANDLES);
+			} else {
+				handle = GTK.gtk_separator_tool_item_new ();
+				if (handle == 0) error (SWT.ERROR_NO_HANDLES);
+				GTK.gtk_separator_tool_item_set_draw (handle, true);
+			}
 			break;
 		case SWT.DROP_DOWN:
-			handle = GTK.gtk_menu_tool_button_new (0, null);
+			if (GTK.GTK4) {
+				handle = GTK.gtk_menu_button_new();
+			} else {
+				handle = GTK.gtk_menu_tool_button_new (0, null);
+			}
+
 			if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 			/*
 			 * Feature in GTK. The arrow button of DropDown tool-item is
@@ -224,36 +235,61 @@ void createHandle (int index) {
 			* The fix is to use toggle buttons instead.
 			*/
 		case SWT.CHECK:
-			handle = GTK.gtk_toggle_tool_button_new ();
+			if (GTK.GTK4) {
+				handle = GTK.gtk_toggle_button_new();
+			} else {
+				handle = GTK.gtk_toggle_tool_button_new ();
+			}
+
 			if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 			break;
 		case SWT.PUSH:
 		default:
-			handle = GTK.gtk_tool_button_new (0, null);
+			if (GTK.GTK4) {
+				handle = GTK.gtk_button_new();
+			} else {
+				handle = GTK.gtk_tool_button_new (0, null);
+			}
+
 			if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 			break;
 	}
 	if (labelHandle != 0) {
-		GTK.gtk_tool_button_set_label_widget(handle, labelHandle);
+		if (GTK.GTK4) {
+			/* TODO: GTK4 button has no way of explicitly setting the
+			 * label widget. The solution is probably to create buttons with
+			 * labels and get the labelHandle by traversing the children of the
+			 * button widget. */
+		} else {
+			GTK.gtk_tool_button_set_label_widget(handle, labelHandle);
+		}
 	}
 	if (imageHandle != 0) {
-		GTK.gtk_tool_button_set_icon_widget(handle, imageHandle);
+		if (GTK.GTK4) {
+			GTK.gtk_button_set_child(handle, imageHandle);
+		} else {
+			GTK.gtk_tool_button_set_icon_widget(handle, imageHandle);
+		}
 	}
 	if ((parent.state & FONT) != 0) {
 		setFontDescription (parent.getFontDescription());
 	}
-	/*
-	 * Feature in GTK. GtkToolButton class uses this property to
-	 * determine whether to show or hide its label when the toolbar
-	 * style is GTK_TOOLBAR_BOTH_HORIZ (or SWT.RIGHT).
-	 */
-	if ((parent.style & SWT.RIGHT) != 0) GTK.gtk_tool_item_set_is_important (handle, true);
-	if ((style & SWT.SEPARATOR) == 0) GTK.gtk_tool_button_set_use_underline (handle, true);
+	if ((style & SWT.SEPARATOR) == 0) {
+		if (GTK.GTK4) {
+			GTK.gtk_button_set_use_underline (handle, true);
+		} else {
+			GTK.gtk_tool_button_set_use_underline (handle, true);
+		}
+	}
 	/*
 	 * Set the "homogeneous" property to false, otherwise all ToolItems will be as large as
 	 * the largest one in the ToolBar. See bug 548331, 395296 for more information.
 	 */
-	GTK.gtk_tool_item_set_homogeneous(handle, false);
+	if (GTK.GTK4) {
+		GTK.gtk_box_set_homogeneous(handle, false);
+	} else {
+		GTK.gtk_tool_item_set_homogeneous(handle, false);
+	}
 }
 
 @Override
@@ -397,6 +433,22 @@ public Image getHotImage () {
 	return hotImage;
 }
 
+/**
+ * Returns the receiver's enabled image if it has one, or null
+ * if it does not.
+ *
+ * @return the receiver's enabled image
+ *
+ * @exception SWTException <ul>
+ *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
+ *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
+ * </ul>
+ */
+@Override
+public Image getImage () {
+	return this.image;
+}
+
 /**
  * Returns the receiver's parent, which must be a <code>ToolBar</code>.
  *
@@ -433,7 +485,15 @@ public ToolBar getParent () {
 public boolean getSelection () {
 	checkWidget();
 	if ((style & (SWT.CHECK | SWT.RADIO)) == 0) return false;
-	return GTK.gtk_toggle_tool_button_get_active (handle);
+
+	boolean selection;
+	if (GTK.GTK4) {
+		selection = GTK.gtk_toggle_button_get_active(handle);
+	} else {
+		selection = GTK.gtk_toggle_tool_button_get_active(handle);
+	}
+
+	return selection;
 }
 
 /**
@@ -551,6 +611,11 @@ long gtk_clicked (long widget) {
 
 @Override
 long gtk_create_menu_proxy (long widget) {
+	if (GTK.GTK4) {
+		/* TODO: GTK4 have to implement our own overflow menu */
+		return 0;
+	}
+
 	/*
 	 * Feature in GTK. If the item is a radio/check button
 	 * with only image, then that image does not appear in
@@ -603,12 +668,8 @@ long gtk_create_menu_proxy (long widget) {
 
 				long menuLabel = GTK.gtk_accel_label_new (label);
 				if (menuLabel == 0) error (SWT.ERROR_NO_HANDLES);
-				if (GTK.GTK_VERSION >= OS.VERSION (3, 16, 0)) {
-					GTK.gtk_label_set_xalign (labelHandle, 0);
-					GTK.gtk_widget_set_halign (labelHandle, GTK.GTK_ALIGN_FILL);
-				} else {
-					GTK.gtk_misc_set_alignment(labelHandle, 0, 0);
-				}
+				GTK.gtk_label_set_xalign (labelHandle, 0);
+				GTK.gtk_widget_set_halign (labelHandle, GTK.GTK_ALIGN_FILL);
 
 				long menuImage = GTK.gtk_image_new_from_pixbuf (pixbuf);
 				if (menuImage == 0) error (SWT.ERROR_NO_HANDLES);
@@ -656,8 +717,7 @@ long gtk_enter_notify_event (long widget, long event) {
 		if (imageList != null) {
 			int index = imageList.indexOf (hotImage);
 			if (index != -1 && imageHandle != 0) {
-				long pixbuf = imageList.getPixbuf (index);
-				gtk_image_set_from_gicon(imageHandle, pixbuf);
+				GTK.gtk_image_set_from_surface(imageHandle, hotImage.surface);
 			}
 		}
 	}
@@ -671,7 +731,12 @@ long gtk_event_after (long widget, long gdkEvent) {
 	switch (eventType) {
 		case GDK.GDK_BUTTON_PRESS: {
 			int [] eventButton = new int [1];
-			GDK.gdk_event_get_button(gdkEvent, eventButton);
+			if (GTK.GTK4) {
+				eventButton[0] = GDK.gdk_button_event_get_button(gdkEvent);
+			} else {
+				GDK.gdk_event_get_button(gdkEvent, eventButton);
+			}
+
 			if (eventButton[0] == 3) {
 				double [] eventRX = new double [1];
 				double [] eventRY = new double [1];
@@ -688,12 +753,14 @@ long gtk_event_after (long widget, long gdkEvent) {
 long gtk_focus_in_event (long widget, long event) {
 	parent.hasChildFocus = true;
 	parent.currentFocusItem = this;
+	parent.sendFocusEvent(SWT.FocusIn);
 	return 0;
 }
 
 @Override
 long gtk_focus_out_event (long widget, long event) {
 	parent.hasChildFocus = false;
+	parent.sendFocusEvent(SWT.FocusOut);
 	return 0;
 }
 
@@ -707,8 +774,7 @@ long gtk_leave_notify_event (long widget, long event) {
 			if (imageList != null) {
 				int index = imageList.indexOf (image);
 				if (index != -1 && imageHandle != 0) {
-					long pixbuf = imageList.getPixbuf (index);
-					gtk_image_set_from_gicon(imageHandle, pixbuf);
+					GTK.gtk_image_set_from_surface(imageHandle, image.surface);
 				}
 			}
 		}
@@ -732,6 +798,7 @@ void hookEvents () {
 	super.hookEvents ();
 	if ((style & SWT.SEPARATOR) != 0) return;
 	OS.g_signal_connect_closure (handle, OS.clicked, display.getClosure (CLICKED), false);
+
 	/*
 	 * Feature in GTK. GtkToolItem does not respond to basic listeners
 	 * such as button-press, enter-notify to it. The fix is to assign
@@ -986,6 +1053,11 @@ public void setDisabledImage (Image image) {
 	checkWidget();
 	if ((style & SWT.SEPARATOR) != 0) return;
 	disabledImage = image;
+	if (image != null) {
+		if (!enabled) {
+			_setImage(image);
+		}
+	}
 }
 
 /**
@@ -1007,7 +1079,10 @@ public void setDisabledImage (Image image) {
 public void setEnabled (boolean enabled) {
 	checkWidget();
 	long topHandle = topHandle ();
-	if (GTK.gtk_widget_get_sensitive (topHandle) == enabled) return;
+	if (this.enabled == enabled) return;
+	this.enabled = enabled;
+	if (!enabled && disabledImage != null) _setImage (disabledImage);
+	if (enabled && this.image != null) _setImage (this.image);
 	GTK.gtk_widget_set_sensitive (topHandle, enabled);
 }
 
@@ -1028,28 +1103,16 @@ void setBackgroundRGBA (GdkRGBA rgba) {
 }
 
 void setBackgroundRGBA (long handle, GdkRGBA rgba) {
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		// Form background string
-		long context = GTK.gtk_widget_get_style_context(handle);
-		String name = GTK.GTK_VERSION >= OS.VERSION(3,	 20, 0) ? display.gtk_widget_class_get_css_name(handle)
-				: display.gtk_widget_get_name(handle);
-		String css = name + " {background-color: " + display.gtk_rgba_to_css_string(rgba) + "}";
+	// Form background string
+	long context = GTK.gtk_widget_get_style_context(handle);
+	String name = display.gtk_widget_class_get_css_name(handle);
+	String css = name + " {background-color: " + display.gtk_rgba_to_css_string(rgba) + "}";
 
-
-		// Apply background color and any foreground color
-		gtk_css_provider_load_from_css(context, css);
-	}
+	// Apply background color and any foreground color
+	gtk_css_provider_load_from_css(context, css);
 }
 
 void setForegroundRGBA (long handle, GdkRGBA rgba) {
-	if (GTK.GTK_VERSION < OS.VERSION(3, 14, 0)) {
-		GdkRGBA selectedForeground = display.COLOR_LIST_SELECTION_TEXT_RGBA;
-		GTK.gtk_widget_override_color (handle, GTK.GTK_STATE_FLAG_NORMAL, rgba);
-		GTK.gtk_widget_override_color (handle, GTK.GTK_STATE_FLAG_SELECTED, selectedForeground);
-		long context = GTK.gtk_widget_get_style_context (handle);
-		GTK.gtk_style_context_invalidate (context);
-		return;
-	}
 	GdkRGBA toSet = new GdkRGBA();
 	if (rgba != null) {
 		toSet = rgba;
@@ -1108,6 +1171,14 @@ public void setImage (Image image) {
 	checkWidget();
 	if ((style & SWT.SEPARATOR) != 0) return;
 	super.setImage (image);
+	if (!enabled && disabledImage != image && disabledImage != null) {
+		return;
+	}
+	_setImage(image);
+}
+
+void _setImage (Image image) {
+	if ((style & SWT.SEPARATOR) != 0) return;
 	if (image != null) {
 		ImageList imageList = parent.imageList;
 		if (imageList == null) imageList = parent.imageList = new ImageList ();
@@ -1117,10 +1188,10 @@ public void setImage (Image image) {
 		} else {
 			imageList.put (imageIndex, image);
 		}
-		long pixbuf = imageList.getPixbuf (imageIndex);
-		gtk_image_set_from_gicon(imageHandle, pixbuf);
+
+		GTK.gtk_image_set_from_surface(imageHandle, image.surface);
 	} else {
-		gtk_image_set_from_gicon(imageHandle, 0);
+		GTK.gtk_image_set_from_surface(imageHandle, 0);
 	}
 	/*
 	* If Text/Image of a tool-item changes, then it is
@@ -1128,9 +1199,13 @@ public void setImage (Image image) {
 	* old menuItem appears in the overflow menu.
 	*/
 	if ((style & SWT.DROP_DOWN) != 0) {
-		proxyMenuItem = 0;
-		proxyMenuItem = GTK.gtk_tool_item_retrieve_proxy_menu_item (handle);
-		OS.g_signal_connect(proxyMenuItem, OS.activate, ToolBar.menuItemSelectedFunc.getAddress(), handle);
+		if (GTK.GTK4) {
+			/* TODO: GTK4 have to implement our own overflow menu */
+		} else {
+			proxyMenuItem = 0;
+			proxyMenuItem = GTK.gtk_tool_item_retrieve_proxy_menu_item (handle);
+			OS.g_signal_connect(proxyMenuItem, OS.activate, ToolBar.menuItemSelectedFunc.getAddress(), handle);
+		}
 	}
 	parent.relayout ();
 }
@@ -1171,7 +1246,11 @@ public void setSelection (boolean selected) {
 	checkWidget ();
 	if ((style & (SWT.CHECK | SWT.RADIO)) == 0) return;
 	OS.g_signal_handlers_block_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, CLICKED);
-	GTK.gtk_toggle_tool_button_set_active (handle, selected);
+	if (GTK.GTK4) {
+		GTK.gtk_toggle_button_set_active (handle, selected);
+	} else {
+		GTK.gtk_toggle_tool_button_set_active (handle, selected);
+	}
 	OS.g_signal_handlers_unblock_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, CLICKED);
 }
 
@@ -1218,15 +1297,26 @@ public void setText (String string) {
 	char [] chars = fixMnemonic (string);
 	byte [] buffer = Converter.wcsToMbcs (chars, true);
 	GTK.gtk_label_set_text_with_mnemonic (labelHandle, buffer);
+	/*
+	 * Only set important if this ToolItem actually has text.
+	 * See bug 543895.
+	 */
+	if ((parent.style & SWT.RIGHT) != 0) {
+		if (!GTK.GTK4) GTK.gtk_tool_item_set_is_important (handle, !string.isEmpty());
+	}
 	/*
 	* If Text/Image of a tool-item changes, then it is
 	* required to reset the proxy menu. Otherwise, the
 	* old menuItem appears in the overflow menu.
 	*/
 	if ((style & SWT.DROP_DOWN) != 0) {
-		proxyMenuItem = 0;
-		proxyMenuItem = GTK.gtk_tool_item_retrieve_proxy_menu_item (handle);
-		OS.g_signal_connect(proxyMenuItem, OS.activate, ToolBar.menuItemSelectedFunc.getAddress(), handle);
+		if (GTK.GTK4) {
+			/* TODO: GTK4 have to implement our own overflow menu */
+		} else {
+			proxyMenuItem = 0;
+			proxyMenuItem = GTK.gtk_tool_item_retrieve_proxy_menu_item (handle);
+			OS.g_signal_connect(proxyMenuItem, OS.activate, ToolBar.menuItemSelectedFunc.getAddress(), handle);
+		}
 	}
 	parent.relayout ();
 }
@@ -1272,9 +1362,13 @@ public void setToolTipText (String string) {
 	* menu as a blank item.
 	*/
 	if ((style & SWT.DROP_DOWN) != 0) {
-		proxyMenuItem = 0;
-		proxyMenuItem = GTK.gtk_tool_item_retrieve_proxy_menu_item (handle);
-		OS.g_signal_connect(proxyMenuItem, OS.activate, ToolBar.menuItemSelectedFunc.getAddress(), handle);
+		if (GTK.GTK4) {
+			/* TODO: GTK4 have to implement our own overflow menu */
+		} else {
+			proxyMenuItem = 0;
+			proxyMenuItem = GTK.gtk_tool_item_retrieve_proxy_menu_item (handle);
+			OS.g_signal_connect(proxyMenuItem, OS.activate, ToolBar.menuItemSelectedFunc.getAddress(), handle);
+		}
 	}
 }
 
@@ -1322,6 +1416,59 @@ void showWidget (int index) {
 	if (handle != 0) GTK.gtk_widget_show (handle);
 	if (labelHandle != 0) GTK.gtk_widget_show (labelHandle);
 	if (imageHandle != 0) GTK.gtk_widget_show (imageHandle);
-	GTK.gtk_toolbar_insert(parent.handle, handle, index);
+
+	if (GTK.GTK4) {
+		if (index == 0) {
+			GTK.gtk_box_prepend(parent.handle, handle);
+		} else if (index < 0) {
+			GTK.gtk_box_append(parent.handle, handle);
+		} else {
+			/* TODO: This implementation of inserting the widget at a position
+			 * index in the GtkBox may not work if gtk_widget_get_next_sibling/_first_child
+			 * does not work as assumed */
+			long sibling = GTK.gtk_widget_get_first_child(parent.handle);
+
+			while (index > 0) {
+				sibling = GTK.gtk_widget_get_next_sibling(sibling);
+				index--;
+			}
+
+			GTK.gtk_box_insert_child_after(parent.handle, handle, sibling);
+		}
+	} else {
+		GTK.gtk_toolbar_insert(parent.handle, handle, index);
+	}
+}
+
+@Override
+String getNameText() {
+	String nameText = super.getNameText();
+	Object data = getData();
+	if(data != null) {
+		return "text: '" + nameText + "', data: " + data;
+	}
+	return nameText;
+}
+
+@Override
+long dpiChanged(long object, long arg0) {
+	super.dpiChanged(object, arg0);
+
+	if (image != null) {
+		image.internal_gtk_refreshImageForZoom();
+		setImage(image);
+	}
+
+	if (hotImage != null) {
+		hotImage.internal_gtk_refreshImageForZoom();
+		setHotImage(hotImage);
+	}
+
+	if (disabledImage != null) {
+		disabledImage.internal_gtk_refreshImageForZoom();
+		setDisabledImage(disabledImage);
+	}
+
+	return 0;
 }
 }
