@@ -285,8 +285,7 @@ void createHandle (int index) {
 		Color background = display.getSystemColor (SWT.COLOR_INFO_BACKGROUND);
 		long context = GTK.gtk_widget_get_style_context (handle);
 		GdkRGBA bgRGBA = background.handle;
-		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "window" : "GtkWindow";
-		String css = name + " {background-color: " + display.gtk_rgba_to_css_string(bgRGBA) + ";}";
+		String css = "window {background-color: " + display.gtk_rgba_to_css_string(bgRGBA) + ";}";
 		gtk_css_provider_load_from_css (context, css);
 		GTK.gtk_style_context_invalidate (context);
 		GTK.gtk_window_set_type_hint (handle, GDK.GDK_WINDOW_TYPE_HINT_TOOLTIP);
@@ -529,7 +528,14 @@ void drawTooltip (long cairo) {
 			case SWT.ICON_WARNING: buffer = Converter.wcsToMbcs ("dialog-warning", true); break;
 		}
 		if (buffer != null) {
-			long pixbuf = GTK.gtk_icon_theme_load_icon(GTK.gtk_icon_theme_get_default(), buffer, GTK.GTK_ICON_SIZE_MENU, 0, 0);
+			long iconTheme;
+			if (GTK.GTK4) {
+				iconTheme = GTK.gtk_icon_theme_get_for_display(GDK.gdk_display_get_default());
+			} else {
+				iconTheme = GTK.gtk_icon_theme_get_default();
+			}
+
+			long pixbuf = GTK.gtk_icon_theme_load_icon(iconTheme, buffer, GTK.GTK_ICON_SIZE_MENU, 0, 0);
 			GDK.gdk_cairo_set_source_pixbuf(cairo, pixbuf, x, y);
 			Cairo.cairo_paint (cairo);
 			OS.g_object_unref (pixbuf);
