@@ -54,7 +54,7 @@ public class Tracker extends Widget {
 	Rectangle bounds;
 	int cursorOrientation = SWT.NONE;
 	int oldX, oldY;
-	long provider; // Gtk3.14
+	long provider;
 
 	// Re-use/cache some items for performance reasons as draw-events must be efficient to prevent jitter.
 	Rectangle cachedCombinedDisplayResolution = Display.getDefault().getBounds(); // Cached for performance reasons.
@@ -211,7 +211,10 @@ Point adjustMoveCursor () {
 
 	int [] actualX = new int [1], actualY = new int [1], state = new int [1];
 	if (GTK.GTK4) {
-		display.gdk_surface_get_device_position (surface, actualX, actualY, state);
+		double [] actualXDouble = new double [1], actualYDouble = new double [1];
+		display.gdk_surface_get_device_position (surface, actualXDouble, actualYDouble, state);
+		actualX[0] = (int) actualXDouble[0];
+		actualY[0] = (int) actualYDouble[0];
 	} else {
 		display.gdk_window_get_device_position (window, actualX, actualY, state);
 	}
@@ -248,7 +251,10 @@ Point adjustResizeCursor () {
 	 */
 	int [] actualX = new int [1], actualY = new int [1], state = new int [1];
 	if (GTK.GTK4) {
-		display.gdk_surface_get_device_position (surface, actualX, actualY, state);
+		double [] actualXDouble = new double [1], actualYDouble = new double [1];
+		display.gdk_surface_get_device_position (surface, actualXDouble, actualYDouble, state);
+		actualX[0] = (int) actualXDouble[0];
+		actualY[0] = (int) actualYDouble[0];
 	} else {
 		display.gdk_window_get_device_position (window, actualX, actualY, state);
 	}
@@ -411,9 +417,9 @@ void drawRectangles (Rectangle [] rects) {
 	GTK.gtk_widget_shape_combine_region (overlay, region);
 	Cairo.cairo_region_destroy (region);
 	if (GTK.GTK4) {
-		long overlaySurface = GTK.gtk_widget_get_surface (overlay);
+		long overlaySurface = GTK.gtk_native_get_surface(GTK.gtk_widget_get_native (overlay));
 		GDK.gdk_surface_hide (overlaySurface);
-		GDK.gdk_surface_show (overlaySurface);
+		/* TODO: GTK does not provide a gdk_surface_show, probably will require use of the present api */
 	} else {
 		long overlayWindow = GTK.gtk_widget_get_window (overlay);
 		GDK.gdk_window_hide (overlayWindow);
@@ -485,10 +491,17 @@ long gtk_button_release_event (long widget, long event) {
 long gtk_key_press_event (long widget, long eventPtr) {
 	long result = super.gtk_key_press_event (widget, eventPtr);
 	if (result != 0) return result;
-	int [] state = new int[1];
-	GDK.gdk_event_get_state(eventPtr, state);
-	int [] keyval = new int[1];
-	GDK.gdk_event_get_keyval(eventPtr, keyval);
+
+	int [] state = new int [1];
+	int [] keyval = new int [1];
+	if (GTK.GTK4) {
+		state[0] = GDK.gdk_event_get_modifier_state(eventPtr);
+		keyval[0] = GDK.gdk_key_event_get_keyval(eventPtr);
+	} else {
+		GDK.gdk_event_get_state(eventPtr, state);
+		GDK.gdk_event_get_keyval(eventPtr, keyval);
+	}
+
 	int stepSize = ((state[0] & GDK.GDK_CONTROL_MASK) != 0) ? STEPSIZE_SMALL : STEPSIZE_LARGE;
 	int xChange = 0, yChange = 0;
 	switch (keyval[0]) {
@@ -631,7 +644,10 @@ long gtk_motion_notify_event (long widget, long eventPtr) {
 long gtk_mouse (int eventType, long widget, long eventPtr) {
 	int [] newX = new int [1], newY = new int [1];
 	if (GTK.GTK4) {
-		display.gdk_surface_get_device_position (surface, newX, newY, null);
+		double [] newXDouble = new double [1], newYDouble = new double [1];
+		display.gdk_surface_get_device_position (surface, newXDouble, newYDouble, null);
+		newX[0] = (int) newXDouble[0];
+		newY[0] = (int) newYDouble[0];
 	} else {
 		display.gdk_window_get_device_position (window, newX, newY, null);
 	}
@@ -779,7 +795,10 @@ public boolean open () {
 	tracking = true;
 	int [] oldX = new int [1], oldY = new int [1], state = new int [1];
 	if (GTK.GTK4) {
-		display.gdk_surface_get_device_position (surface, oldX, oldY, state);
+		double [] oldXDouble = new double [1], oldYDouble = new double [1];
+		display.gdk_surface_get_device_position (surface, oldXDouble, oldYDouble, state);
+		oldX[0] = (int) oldXDouble[0];
+		oldY[0] = (int) oldYDouble[0];
 	} else {
 		display.gdk_window_get_device_position (window, oldX, oldY, state);
 	}
@@ -872,35 +891,30 @@ private void setTrackerBackground(boolean opaque) {
 	} else if (opaque == cachedBackgroundIsOpaque.booleanValue()) {
 		return;
 	}
-	if (GTK.GTK_VERSION < OS.VERSION (3, 14, 0)) {
-		GTK.gtk_widget_override_background_color (overlay, GTK.GTK_STATE_FLAG_NORMAL, new GdkRGBA());
+	String css;
+	if (opaque) {
+		GTK.gtk_widget_set_opacity (overlay, 1.0);
+		css = "window {background-color: rgb(0,0,0);}";
 	} else {
-		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "window" : "GtkWindow";
-		String css;
-		if (opaque) {
-			GTK.gtk_widget_set_opacity (overlay, 1.0);
-			css = name + " {background-color: rgb(0,0,0);}";
-		} else {
-			GTK.gtk_widget_set_opacity (overlay, 0.0);
-			css = name +  " {  "
-					+ "border-top-color: transparent;"
-					+ "border-left-color: transparent;"
-					+ "border-right-color: transparent;"
-					+ "border-bottom-color: transparent;}";
-		}
-		long context = GTK.gtk_widget_get_style_context (overlay);
-		if (provider == 0) {
-			provider = GTK.gtk_css_provider_new ();
-			GTK.gtk_style_context_add_provider (context, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-			OS.g_object_unref (provider);
-		}
-		if (GTK.GTK4) {
-			GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1);
-		} else {
-			GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
-		}
-		GTK.gtk_style_context_invalidate (context);
+		GTK.gtk_widget_set_opacity (overlay, 0.0);
+		css = "window {  "
+				+ "border-top-color: transparent;"
+				+ "border-left-color: transparent;"
+				+ "border-right-color: transparent;"
+				+ "border-bottom-color: transparent;}";
 	}
+	long context = GTK.gtk_widget_get_style_context (overlay);
+	if (provider == 0) {
+		provider = GTK.gtk_css_provider_new ();
+		GTK.gtk_style_context_add_provider (context, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		OS.g_object_unref (provider);
+	}
+	if (GTK.GTK4) {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1);
+	} else {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+	}
+	GTK.gtk_style_context_invalidate (context);
 	long region = Cairo.cairo_region_create ();
 	GTK.gtk_widget_shape_combine_region (overlay, region);
 	GTK.gtk_widget_input_shape_combine_region (overlay, region);
