@@ -236,7 +236,8 @@ public abstract class Widget {
 	static final int GESTURE_RELEASED = 101;
 	static final int NOTIFY_STATE = 102;
 	static final int SIZE_ALLOCATE_GTK4 = 103;
-	static final int LAST_SIGNAL = 104;
+	static final int DPI_CHANGED = 104;
+	static final int LAST_SIGNAL = 105;
 
 	static final String IS_ACTIVE = "org.eclipse.swt.internal.control.isactive"; //$NON-NLS-1$
 	static final String KEY_CHECK_SUBWINDOW = "org.eclipse.swt.internal.control.checksubwindow"; //$NON-NLS-1$
@@ -528,6 +529,24 @@ public void dispose () {
 	release (true);
 }
 
+long dpiChanged (long object, long arg0) {
+	int oldScaleFactor = DPIUtil.getDeviceZoom() / 100;
+	int newScaleFactor = GTK.gtk_widget_get_scale_factor(object);
+
+	if (oldScaleFactor != newScaleFactor) {
+		display.dpiChanged(newScaleFactor);
+
+		Event event = new Event();
+		event.type = SWT.ZoomChanged;
+		event.widget = this;
+		event.detail = newScaleFactor;
+		event.doit = true;
+		notifyListeners(SWT.ZoomChanged, event);
+	}
+
+	return 0;
+}
+
 void error (int code) {
 	SWT.error (code);
 }
@@ -719,8 +738,8 @@ long gtk_changed (long widget) {
 	return 0;
 }
 
-long gtk_change_value (long widget, long scroll, long value1, long value2) {
-	return 0;
+boolean gtk_change_value (long widget, int scroll, double value, long user_data) {
+	return false;
 }
 
 long gtk_clicked (long widget) {
@@ -1139,6 +1158,9 @@ boolean isValidSubclass() {
 }
 
 void hookEvents () {
+	if (handle != 0) {
+		OS.g_signal_connect (handle, OS.dpi_changed, display.notifyProc, Widget.DPI_CHANGED);
+	}
 }
 
 /*
@@ -1435,19 +1457,17 @@ void sendEvent (int eventType, Event event, boolean send) {
 }
 
 boolean sendKeyEvent (int type, long event) {
-	int length;
-	long string;
+	int length = 0;
+	long string = 0;
 	if (GTK.GTK4) {
-		long [] eventString = new long [1];
-		GDK.gdk_event_get_string(event, eventString);
-		string = eventString[0];
-		length = (int)OS.g_utf16_strlen (string, -1);
+		/* TODO: GTK4 no access to key event string */
 	} else {
 		GdkEventKey gdkEvent = new GdkEventKey ();
 		OS.memmove(gdkEvent, event, GdkEventKey.sizeof);
 		length = gdkEvent.length;
 		string = gdkEvent.string;
 	}
+
 	if (string == 0 || OS.g_utf16_strlen (string, length) <= 1) {
 		Event javaEvent = new Event ();
 		javaEvent.time = GDK.gdk_event_get_time(event);
@@ -1482,7 +1502,11 @@ char [] sendIMKeyEvent (int type, long event, char [] chars) {
 				case GDK.GDK_KEY_PRESS:
 				case GDK.GDK_KEY_RELEASE:
 					int [] eventState = new int[1];
-					GDK.gdk_event_get_state(ptr, eventState);
+					if (GTK.GTK4) {
+						eventState[0] = GDK.gdk_event_get_modifier_state(event);
+					} else {
+						GDK.gdk_event_get_state(event, eventState);
+					}
 					state = eventState[0];
 					break;
 				default:
@@ -1548,14 +1572,23 @@ void sendSelectionEvent (int eventType, Event event, boolean send) {
 			case GDK.GDK_2BUTTON_PRESS:
 			case GDK.GDK_BUTTON_RELEASE: {
 				int [] eventButton = new int [1];
-				GDK.gdk_event_get_button(ptr, eventButton);
+				if (GTK.GTK4) {
+					eventButton[0] = GDK.gdk_button_event_get_button(ptr);
+				} else {
+					GDK.gdk_event_get_button(ptr, eventButton);
+				}
+
 				setButtonState(event, eventButton [0]);
 			}
 			//$FALL-THROUGH$
 			case GDK.GDK_KEY_PRESS:
 			case GDK.GDK_KEY_RELEASE: {
-				int [] state = new int [1];
-				GDK.gdk_event_get_state (ptr, state);
+				int [] state = new int[1];
+				if (GTK.GTK4) {
+					state[0] = GDK.gdk_event_get_modifier_state(ptr);
+				} else {
+					GDK.gdk_event_get_state(ptr, state);
+				}
 				setInputState (event, state [0]);
 				break;
 			}
@@ -1676,7 +1709,7 @@ public void setData (String key, Object value) {
 		}
 	}
 	if (key.equals(SWT.SKIN_CLASS) || key.equals(SWT.SKIN_ID)) this.reskin(SWT.ALL);
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) && key.equals(KEY_GTK_CSS) && value instanceof String) {
+	if (key.equals(KEY_GTK_CSS) && value instanceof String) {
 		long context = GTK.gtk_widget_get_style_context (cssHandle());
 		long provider = GTK.gtk_css_provider_new();
 		if (context != 0 && provider != 0) {
@@ -1719,21 +1752,22 @@ boolean setInputState (Event event, int state) {
 }
 
 boolean setKeyState (Event javaEvent, long event) {
-	long string;
-	int length;
-	int [] eventKeyval = new int[1];
+	long string = 0;
+	int length = 0;
 	int group;
-	GDK.gdk_event_get_keyval(event, eventKeyval);
-	int [] eventState = new int[1];
-	GDK.gdk_event_get_state(event, eventState);
+
+	int [] eventKeyval = new int [1];
+	int [] eventState = new int [1];
 	if (GTK.GTK4) {
-		long [] eventString = new long [1];
-		GDK.gdk_event_get_string(event, eventString);
-		string = eventString[0];
-		length = (int)OS.g_utf16_strlen (string, -1);
-		int [] eventGroup = new int [1];
-		GDK.gdk_event_get_key_group(event, eventGroup);
-		group = eventGroup[0];
+		eventKeyval[0] = GDK.gdk_key_event_get_keyval(event);
+		eventState[0] = GDK.gdk_event_get_modifier_state(event);
+	} else {
+		GDK.gdk_event_get_keyval(event, eventKeyval);
+		GDK.gdk_event_get_state(event, eventState);
+	}
+
+	if (GTK.GTK4) {
+		group = GDK.gdk_key_event_get_layout(event);
 	} else {
 		GdkEventKey gdkEvent = new GdkEventKey ();
 		OS.memmove(gdkEvent, event, GdkEventKey.sizeof);
@@ -1741,6 +1775,7 @@ boolean setKeyState (Event javaEvent, long event) {
 		string = gdkEvent.string;
 		group = gdkEvent.group;
 	}
+
 	if (string != 0 && OS.g_utf16_strlen (string, length) > 1) return false;
 	boolean isNull = false;
 	javaEvent.keyCode = Display.translateKey (eventKeyval[0]);
@@ -1763,15 +1798,22 @@ boolean setKeyState (Event javaEvent, long event) {
 				if (!groupLatinKeysCount.containsKey(group)) {
 					group = display.getLatinKeyGroup();
 				}
+
 				long keymap = 0;
 				long display = GDK.gdk_display_get_default();
 				if (GTK.GTK4) {
-					keymap = GDK.gdk_display_get_keymap(display);
+					//TODO: GTK4 Get keymap or find alternative for gdk_keymap_translate_keyboard_state (no longer exist in GTK4)
 				} else {
 					keymap = GDK.gdk_keymap_get_for_display(display);
 				}
+
 				short [] keyCode = new short [1];
-				GDK.gdk_event_get_keycode(event, keyCode);
+				if (GTK.GTK4) {
+					keyCode[0] = (short) GDK.gdk_key_event_get_keycode(event);
+				} else {
+					GDK.gdk_event_get_keycode(event, keyCode);
+				}
+
 				if (GDK.gdk_keymap_translate_keyboard_state (keymap, keyCode[0],
 						0, group, keyval, effective_group, level, consumed_modifiers)) {
 					javaEvent.keyCode = (int) GDK.gdk_keyval_to_unicode (keyval [0]);
@@ -1797,7 +1839,12 @@ boolean setKeyState (Event javaEvent, long event) {
 
 void setLocationState (Event event, long eventPtr) {
 	int [] eventKeyval = new int[1];
-	GDK.gdk_event_get_keyval(eventPtr, eventKeyval);
+	if (GTK.GTK4) {
+		eventKeyval[0] = GDK.gdk_key_event_get_keyval(eventPtr);
+	} else {
+		GDK.gdk_event_get_keyval(eventPtr, eventKeyval);
+	}
+
 	switch (eventKeyval[0]) {
 		case GDK.GDK_Alt_L:
 		case GDK.GDK_Shift_L:
@@ -1890,7 +1937,7 @@ long gtk_widget_get_window (long widget){
 
 long gtk_widget_get_surface (long widget){
 	GTK.gtk_widget_realize(widget);
-	return GTK.gtk_widget_get_surface (widget);
+	return GTK.gtk_native_get_surface(GTK.gtk_widget_get_native (widget));
 }
 
 void gtk_widget_set_has_surface_or_window (long widget, boolean has) {
@@ -1935,7 +1982,7 @@ void gdk_surface_get_size (long surface, int[] width, int[] height) {
 void gdk_event_free (long event) {
 	if (event == 0) return;
 	if (GTK.GTK4) {
-		OS.g_object_unref(event);
+		GDK.gdk_event_unref(event);
 	} else {
 		GDK.gdk_event_free(event);
 	}
@@ -1979,8 +2026,13 @@ long gdk_event_peek() {
  *        OS.GDK_SHIFT_MASK / OS.GDK_CONTROL_MASK / OS.GDK_MOD1_MASK etc..
  */
 int gdk_event_get_state (long event) {
-	int [] state = new int [1];
-	GDK.gdk_event_get_state (event, state);
+	int [] state = new int[1];
+	if (GTK.GTK4) {
+		state[0] = GDK.gdk_event_get_modifier_state(event);
+	} else {
+		GDK.gdk_event_get_state(event, state);
+	}
+
 	return state[0];
 }
 
@@ -2015,7 +2067,7 @@ void gtk_box_pack_end (long box, long child, boolean expand, boolean fill, int p
 			GTK.gtk_widget_set_valign(child, GTK.GTK_ALIGN_FILL);
 		}
 		OS.g_object_set(box, OS.margin, padding, 0);
-		GTK.gtk_box_pack_end(box, child);
+		GTK.gtk_box_append(box, child);
 	} else {
 		GTK.gtk_box_pack_end(box, child, expand, fill, padding);
 	}
@@ -2035,35 +2087,23 @@ int gdk_pointer_grab (long gdkResource, int grab_ownership, boolean owner_events
 			display = GDK.gdk_window_get_display (gdkResource);
 		}
 	}
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
-		long seat = GDK.gdk_display_get_default_seat(display);
-		if (gdkSeatGrabPrepareFunc == null) {
-			gdkSeatGrabPrepareFunc = new Callback(Widget.class, "GdkSeatGrabPrepareFunc", 3); //$NON-NLS-1$
-		}
-		long gdkSeatGrabPrepareFuncAddress = gdkSeatGrabPrepareFunc.getAddress();
-		if (gdkSeatGrabPrepareFuncAddress == 0) SWT.error (SWT.ERROR_NO_MORE_CALLBACKS);
-		return GDK.gdk_seat_grab(seat, gdkResource, GDK.GDK_SEAT_CAPABILITY_ALL_POINTING, owner_events, cursor, 0, gdkSeatGrabPrepareFuncAddress, gdkResource);
-	} else {
-		long pointer = GDK.gdk_get_pointer(display);
-		return GDK.gdk_device_grab (pointer, gdkResource, grab_ownership, owner_events, event_mask, cursor, time_);
+	long seat = GDK.gdk_display_get_default_seat(display);
+	if (gdkSeatGrabPrepareFunc == null) {
+		gdkSeatGrabPrepareFunc = new Callback(Widget.class, "GdkSeatGrabPrepareFunc", 3); //$NON-NLS-1$
 	}
+	return GDK.gdk_seat_grab(seat, gdkResource, GDK.GDK_SEAT_CAPABILITY_ALL_POINTING, owner_events, cursor, 0, gdkSeatGrabPrepareFunc.getAddress(), gdkResource);
 }
 
 void gdk_pointer_ungrab (long gdkResource, int time_) {
 	long display = GTK.GTK4? GDK.gdk_surface_get_display(gdkResource) : GDK.gdk_window_get_display (gdkResource);
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
-		long seat = GDK.gdk_display_get_default_seat(display);
-		GDK.gdk_seat_ungrab(seat);
-	} else {
-		long pointer = GDK.gdk_get_pointer(display);
-		GDK.gdk_device_ungrab (pointer, time_);
-	}
+	long seat = GDK.gdk_display_get_default_seat(display);
+	GDK.gdk_seat_ungrab(seat);
 }
 
 static long GdkSeatGrabPrepareFunc (long gdkSeat, long gdkResource, long userData_gdkResource) {
 	if (userData_gdkResource != 0) {
 		if (GTK.GTK4) {
-			GDK.gdk_surface_show(userData_gdkResource);
+			/* TODO: GTK does not provide a gdk_surface_show, probably will require use of the present api */
 		} else {
 			GDK.gdk_window_show(userData_gdkResource);
 		}
@@ -2099,9 +2139,16 @@ boolean translateTraversal (int event) {
 	return false;
 }
 
-long enterMotionScrollProc (long handle, double x, double y, long user_data) {
-	long event = GTK.gtk_get_current_event();
+long enterMotionScrollProc (long controller, long handle, double x, double y, long user_data) {
+	long event;
 	long result = 0;
+
+	if (GTK.GTK4) {
+		event = GTK.gtk_event_controller_get_current_event(controller);
+	} else {
+		event = GTK.gtk_get_current_event();
+	}
+
 	switch ((int)user_data) {
 		case ENTER:
 			result = gtk_enter_notify_event(handle, event);
@@ -2120,9 +2167,16 @@ long enterMotionScrollProc (long handle, double x, double y, long user_data) {
 	return result;
 }
 
-long focusProc (long handle, long user_data) {
-	long event = GTK.gtk_get_current_event();
+long focusProc (long controller, long handle, long user_data) {
+	long event;
 	long result = 0;
+
+	if (GTK.GTK4) {
+		event = GTK.gtk_event_controller_get_current_event(controller);
+	} else {
+		event = GTK.gtk_get_current_event();
+	}
+
 	switch ((int)user_data) {
 		case FOCUS_IN:
 			result = gtk_focus_in_event(handle, event);
@@ -2135,9 +2189,16 @@ long focusProc (long handle, long user_data) {
 	return result;
 }
 
-long keyPressReleaseProc (long handle, int keyval, int keycode, int state, long user_data) {
-	long event = GTK.gtk_get_current_event();
+long keyPressReleaseProc (long controller, long handle, int keyval, int keycode, int state, long user_data) {
+	long event;
 	long result = 0;
+
+	if (GTK.GTK4) {
+		event = GTK.gtk_event_controller_get_current_event(controller);
+	} else {
+		event = GTK.gtk_get_current_event();
+	}
+
 	switch ((int)user_data) {
 		case KEY_PRESSED:
 			result = gtk_key_press_event(handle, event);
@@ -2150,9 +2211,16 @@ long keyPressReleaseProc (long handle, int keyval, int keycode, int state, long
 	return result;
 }
 
-long getsurePressReleaseProc (long gesture, int n_press, double x, double y, long user_data) {
-	long event = GTK.gtk_get_current_event();
+long gesturePressReleaseProc (long gesture, int n_press, double x, double y, long user_data) {
+	long event;
 	long result = 0;
+
+	if (GTK.GTK4) {
+		event = GTK.gtk_event_controller_get_current_event(gesture);
+	} else {
+		event = GTK.gtk_get_current_event();
+	}
+
 	switch ((int)user_data) {
 		case GESTURE_PRESSED:
 			result = gtk_gesture_press_event(gesture, n_press, x, y, event);
@@ -2165,9 +2233,16 @@ long getsurePressReleaseProc (long gesture, int n_press, double x, double y, lon
 	return result;
 }
 
-long leaveProc (long handle, long user_data) {
-	long event = GTK.gtk_get_current_event();
+long leaveProc (long controller, long handle, long user_data) {
+	long event;
 	long result = 0;
+
+	if (GTK.GTK4) {
+		event = GTK.gtk_event_controller_get_current_event(controller);
+	} else {
+		event = GTK.gtk_get_current_event();
+	}
+
 	switch ((int)user_data) {
 		case LEAVE:
 			result = gtk_leave_notify_event(handle, event);
@@ -2177,7 +2252,15 @@ long leaveProc (long handle, long user_data) {
 	return result;
 }
 
-long notifyStateProc (long gdk_handle, long handle) {
+long notifyProc (long object, long arg0, long user_data) {
+	switch ((int)user_data) {
+		case DPI_CHANGED: return dpiChanged(object, arg0);
+		case NOTIFY_STATE: return notifyState(object, arg0);
+	}
+	return 0;
+}
+
+long notifyState (long object, long argo0) {
 	return 0;
 }
 
@@ -2280,7 +2363,6 @@ long windowProc (long handle, long arg0, long arg1, long user_data) {
 
 long windowProc (long handle, long arg0, long arg1, long arg2, long user_data) {
 	switch ((int)user_data) {
-		case CHANGE_VALUE: return gtk_change_value (handle, arg0, arg1, arg2);
 		case EXPAND_COLLAPSE_CURSOR_ROW: return gtk_expand_collapse_cursor_row (handle, arg0, arg1, arg2);
 		case INSERT_TEXT: return gtk_insert_text (handle, arg0, arg1, arg2);
 		case TEXT_BUFFER_INSERT_TEXT: return gtk_text_buffer_insert_text (handle, arg0, arg1, arg2);
@@ -2306,9 +2388,6 @@ void gtk_widget_get_preferred_size (long widget, GtkRequisition requisition){
 	GTK.gtk_widget_get_preferred_size (widget, requisition, null);
 }
 
-void gtk_image_set_from_gicon (long imageHandle, long pixbuf){
-	GTK.gtk_image_set_from_gicon(imageHandle, pixbuf, GTK.GTK_ICON_SIZE_SMALL_TOOLBAR);
-}
 /**
  * Retrieves the amount of space around the outside of the container.
  * On GTK3: this is done using gtk_container_get_border_width.
