@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -15,17 +15,15 @@ package org.eclipse.swt.graphics;
 
 
 import org.eclipse.swt.*;
-import org.eclipse.swt.internal.win32.*;
 
 /**
- * Instances of this class manage the operating system resources that
- * implement SWT's RGB color model. To create a color you can either
+ * Instances of this store color information. To create a color you can either
  * specify the individual color components as integers in the range
  * 0 to 255 or provide an instance of an <code>RGB</code> or <code>RGBA</code>.
  * <p>
- * Application code must explicitly invoke the <code>Color.dispose()</code>
- * method to release the operating system resources managed by each instance
- * when those instances are no longer required.
+ * Colors do not need to be disposed, however to maintain compatibility
+ * with older code, disposing a Color is not an error. As Colors do not require
+ * disposal, the constructors which do not require a Device are recommended.
  * </p>
  *
  * @see RGB
@@ -52,6 +50,13 @@ public final class Color extends Resource {
 	public int handle;
 	int alpha = 255;
 
+/**
+ * Prevents uninitialized instances from being created outside the package.
+ */
+Color() {
+	super();
+}
+
 /**
  * Prevents uninitialized instances from being created outside the package.
  */
@@ -62,14 +67,7 @@ Color(Device device) {
 /**
  * Constructs a new instance of this class given a device and the
  * desired red, green and blue values expressed as ints in the range
- * 0 to 255 (where 0 is black and 255 is full brightness). On limited
- * color devices, the color instance created by this call may not have
- * the same RGB values as the ones specified by the arguments. The
- * RGB values on the returned instance will be the color values of
- * the operating system color.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
+ * 0 to 255 (where 0 is black and 255 is full brightness).
  *
  * @param device the device on which to allocate the color
  * @param red the amount of red in the color
@@ -81,7 +79,7 @@ Color(Device device) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green or blue argument is not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(int, int, int) The equivalent constructor not requiring a Device
  */
 public Color (Device device, int red, int green, int blue) {
 	super(device);
@@ -89,17 +87,29 @@ public Color (Device device, int red, int green, int blue) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given the
+ * desired red, green and blue values expressed as ints in the range
+ * 0 to 255 (where 0 is black and 255 is full brightness).
+ *
+ * @param red the amount of red in the color
+ * @param green the amount of green in the color
+ * @param blue the amount of blue in the color
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green or blue argument is not between 0 and 255</li>
+ * </ul>
+ * @since 3.115
+ */
+public Color(int red, int green, int blue) {
+	super();
+	init(red, green, blue, 255);
+}
+
 /**
  * Constructs a new instance of this class given a device and the
- * desired red, green, blue & alpha values expressed as ints in the range
- * 0 to 255 (where 0 is black and 255 is full brightness). On limited
- * color devices, the color instance created by this call may not have
- * the same RGB values as the ones specified by the arguments. The
- * RGB values on the returned instance will be the color values of
- * the operating system color.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
+ * desired red, green, blue &amp; alpha values expressed as ints in the range
+ * 0 to 255 (where 0 is black and 255 is full brightness).
  *
  * @param device the device on which to allocate the color
  * @param red the amount of red in the color
@@ -112,7 +122,8 @@ public Color (Device device, int red, int green, int blue) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha argument is not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(int, int, int, int) The equivalent constructor not requiring a Device
+ *
  * @since 3.104
  */
 public Color (Device device, int red, int green, int blue, int alpha) {
@@ -121,16 +132,30 @@ public Color (Device device, int red, int green, int blue, int alpha) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given the
+ * desired red, green, blue &amp; alpha values expressed as ints in the range
+ * 0 to 255 (where 0 is black and 255 is full brightness).
+ *
+ * @param red the amount of red in the color
+ * @param green the amount of green in the color
+ * @param blue the amount of blue in the color
+ * @param alpha the amount of alpha in the color. Currently, SWT only honors extreme values for alpha i.e. 0 (transparent) or 255 (opaque).
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha argument is not between 0 and 255</li>
+ * </ul>
+ *
+ * @since 3.115
+ */
+public Color(int red, int green, int blue, int alpha) {
+	super();
+	init(red, green, blue, alpha);
+}
+
 /**
  * Constructs a new instance of this class given a device and an
  * <code>RGB</code> describing the desired red, green and blue values.
- * On limited color devices, the color instance created by this call
- * may not have the same RGB values as the ones specified by the
- * argument. The RGB values on the returned instance will be the color
- * values of the operating system color.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
  *
  * @param device the device on which to allocate the color
  * @param rgb the RGB values of the desired color
@@ -141,7 +166,7 @@ public Color (Device device, int red, int green, int blue, int alpha) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green or blue components of the argument are not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(RGB) The equivalent constructor not requiring a Device
  */
 public Color (Device device, RGB rgb) {
 	super(device);
@@ -150,16 +175,27 @@ public Color (Device device, RGB rgb) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given an
+ * <code>RGB</code> describing the desired red, green and blue values.
+ *
+ * @param rgb the RGB values of the desired color
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_NULL_ARGUMENT - if the rgb argument is null</li>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green or blue components of the argument are not between 0 and 255</li>
+ * </ul>
+ * @since 3.115
+ */
+public Color(RGB rgb) {
+	super();
+	if (rgb == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
+	init(rgb.red, rgb.green, rgb.blue, 255);
+}
+
 /**
  * Constructs a new instance of this class given a device and an
- * <code>RGBA</code> describing the desired red, green, blue & alpha values.
- * On limited color devices, the color instance created by this call
- * may not have the same RGBA values as the ones specified by the
- * argument. The RGBA values on the returned instance will be the color
- * values of the operating system color + alpha.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
+ * <code>RGBA</code> describing the desired red, green, blue &amp; alpha values.
  *
  * @param device the device on which to allocate the color
  * @param rgba the RGBA values of the desired color. Currently, SWT only honors extreme values for alpha i.e. 0 (transparent) or 255 (opaque).
@@ -170,7 +206,8 @@ public Color (Device device, RGB rgb) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha components of the argument are not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(RGBA) The equivalent constructor not requiring a Device
+ *
  * @since 3.104
  */
 public Color(Device device, RGBA rgba) {
@@ -180,17 +217,29 @@ public Color(Device device, RGBA rgba) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given an
+ * <code>RGBA</code> describing the desired red, green, blue &amp; alpha values.
+ *
+ * @param rgba the RGBA values of the desired color. Currently, SWT only honors extreme values for alpha i.e. 0 (transparent) or 255 (opaque).
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_NULL_ARGUMENT - if the rgba argument is null</li>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha components of the argument are not between 0 and 255</li>
+ * </ul>
+ *
+ * @since 3.115
+ */
+public Color(RGBA rgba) {
+	super();
+	if (rgba == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
+	init(rgba.rgb.red, rgba.rgb.green, rgba.rgb.blue, rgba.alpha);
+}
+
 /**
  * Constructs a new instance of this class given a device, an
  * <code>RGB</code> describing the desired red, green and blue values,
  * alpha specifying the level of transparency.
- * On limited color devices, the color instance created by this call
- * may not have the same RGB values as the ones specified by the
- * argument. The RGB values on the returned instance will be the color
- * values of the operating system color.
- * <p>
- * You must dispose the color when it is no longer required.
- * </p>
  *
  * @param device the device on which to allocate the color
  * @param rgb the RGB values of the desired color
@@ -202,7 +251,8 @@ public Color(Device device, RGBA rgba) {
  *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha components of the argument are not between 0 and 255</li>
  * </ul>
  *
- * @see #dispose
+ * @see #Color(RGB, int) The equivalent constructor not requiring a Device
+ *
  * @since 3.104
  */
 public Color(Device device, RGB rgb, int alpha) {
@@ -212,25 +262,67 @@ public Color(Device device, RGB rgb, int alpha) {
 	init();
 }
 
+/**
+ * Constructs a new instance of this class given an
+ * <code>RGB</code> describing the desired red, green and blue values,
+ * alpha specifying the level of transparency.
+ *
+ * @param rgb the RGB values of the desired color
+ * @param alpha the alpha value of the desired color. Currently, SWT only honors extreme values for alpha i.e. 0 (transparent) or 255 (opaque).
+ *
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_NULL_ARGUMENT - if the rgb argument is null</li>
+ *    <li>ERROR_INVALID_ARGUMENT - if the red, green, blue or alpha components of the argument are not between 0 and 255</li>
+ * </ul>
+ *
+ * @since 3.115
+ */
+public Color(RGB rgb, int alpha) {
+	super();
+	if (rgb == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
+	init(rgb.red, rgb.green, rgb.blue, alpha);
+}
+
 @Override
 void destroy() {
-	/*
-	 * If this is a palette-based device,
-	 * Decrease the reference count for this color.
-	 * If the reference count reaches 0, the slot may
-	 * be reused when another color is allocated.
-	 */
-	long /*int*/ hPal = device.hPalette;
-	if (hPal != 0) {
-		int index = OS.GetNearestPaletteIndex(hPal, handle);
-		int[] colorRefCount = device.colorRefCount;
-		if (colorRefCount[index] > 0) {
-			colorRefCount[index]--;
-		}
-	}
 	handle = -1;
 }
 
+/**
+ * Colors do not need to be disposed, however to maintain compatibility
+ * with older code, disposing a Color is not an error.
+ */
+@Override
+public void dispose() {
+	// Does as below to maintain API contract with Resource. Does
+	// not use super.dispose() because that untracks the Color
+	// from the Device tracking, however init() is overridden
+	// to prevent the tracking in the first place.
+	destroy();
+	device = null;
+}
+
+/**
+ * Returns the <code>Device</code> where this resource was
+ * created. In cases where no <code>Device</code> was used
+ * at creation, returns the current or default Device.
+ *
+ * <p>
+ * As Color does not require a Device it is recommended to not
+ * use {@link Color#getDevice()}.
+ * </p>
+ *
+ * @return <code>Device</code> the device of the receiver
+ * @since 3.2
+ */
+@Override
+public Device getDevice() {
+	// Fall back on Device.getDevice only if we haven't been disposed
+	// already.
+	if (this.device == null && this.handle != -1) return Device.getDevice();
+	return super.getDevice();
+}
+
 /**
  * Compares the argument to the receiver, and returns true
  * if they represent the <em>same</em> object using a class
@@ -246,7 +338,7 @@ public boolean equals (Object object) {
 	if (object == this) return true;
 	if (!(object instanceof Color)) return false;
 	Color color = (Color) object;
-	return device == color.device && (handle & 0xFFFFFF) == (color.handle & 0xFFFFFF) && (alpha == color.alpha);
+	return (handle & 0xFFFFFF) == (color.handle & 0xFFFFFF) && (alpha == color.alpha);
 }
 
 /**
@@ -371,44 +463,14 @@ void init(int red, int green, int blue, int alpha) {
 	}
 	handle = (red & 0xFF) | ((green & 0xFF) << 8) | ((blue & 0xFF) << 16);
 	this.alpha = alpha;
+}
 
-	/* If this is not a palette-based device, return */
-	long /*int*/ hPal = device.hPalette;
-	if (hPal == 0) return;
-
-	int[] colorRefCount = device.colorRefCount;
-	/* Add this color to the default palette now */
-	/* First find out if the color already exists */
-	int index = OS.GetNearestPaletteIndex(hPal, handle);
-	/* See if the nearest color actually is the color */
-	byte[] entry = new byte[4];
-	OS.GetPaletteEntries(hPal, index, 1, entry);
-	if ((entry[0] == (byte)red) && (entry[1] == (byte)green) &&
-		(entry[2] == (byte)blue)) {
-			/* Found the color. Increment the ref count and return */
-			colorRefCount[index]++;
-			return;
-	}
-	/* Didn't find the color, allocate it now. Find the first free entry */
-	int i = 0;
-	while (i < colorRefCount.length) {
-		if (colorRefCount[i] == 0) {
-			index = i;
-			break;
-		}
-		i++;
-	}
-	if (i == colorRefCount.length) {
-		/* No free entries, use the closest one */
-		/* Remake the handle from the actual rgbs */
-		handle = (entry[0] & 0xFF) | ((entry[1] & 0xFF) << 8) |
-				 ((entry[2] & 0xFF) << 16);
-	} else {
-		/* Found a free entry */
-		entry = new byte[] { (byte)(red & 0xFF), (byte)(green & 0xFF), (byte)(blue & 0xFF), 0 };
-		OS.SetPaletteEntries(hPal, index, 1, entry);
-	}
-	colorRefCount[index]++;
+@Override
+void init() {
+	// Resource init simply tracks this resource in the Device
+	// if DEBUG is on. Since Colors don't require disposal,
+	// the tracking would be a memory leak and a misreport
+	// on what resources are in use.
 }
 
 /**
