@@ -140,6 +140,12 @@ Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 	return new Rectangle (rect.left, rect.top, nWidth, nHeight);
 }
 
+@Override
+void createHandle () {
+	super.createHandle();
+	maybeEnableDarkSystemTheme();
+}
+
 ScrollBar createScrollBar (int type) {
 	ScrollBar bar = new ScrollBar (this, type);
 	if ((state & CANVAS) != 0) {
@@ -152,14 +158,8 @@ ScrollBar createScrollBar (int type) {
 @Override
 void createWidget () {
 	super.createWidget ();
-	/*
-	 * NOTE: ICON_CANCEL and ICON_SEARCH have the same value as H_SCROLL and
-	 * V_SCROLL. The meaning is determined by whether SWT.SEARCH is set.
-	 */
-	if ((style & SWT.SEARCH) == 0) {
-		if ((style & SWT.H_SCROLL) != 0) horizontalBar = createScrollBar (SWT.H_SCROLL);
-		if ((style & SWT.V_SCROLL) != 0) verticalBar = createScrollBar (SWT.V_SCROLL);
-	}
+	if ((style & SWT.H_SCROLL) != 0) horizontalBar = createScrollBar (SWT.H_SCROLL);
+	if ((style & SWT.V_SCROLL) != 0) verticalBar = createScrollBar (SWT.V_SCROLL);
 }
 
 @Override
@@ -316,32 +316,11 @@ long scrolledHandle () {
 	return handle;
 }
 
-@Override
-int widgetExtStyle () {
-	return super.widgetExtStyle ();
-	/*
-	* This code is intentionally commented.  In future,
-	* we may wish to support different standard Windows
-	* edge styles.  The issue here is that not all of
-	* these styles are available on the other platforms
-	* this would need to be a hint.
-	*/
-//	if ((style & SWT.BORDER) != 0) return OS.WS_EX_CLIENTEDGE;
-//	if ((style & SWT.SHADOW_IN) != 0) return OS.WS_EX_STATICEDGE;
-//	return super.widgetExtStyle ();
-}
-
 @Override
 int widgetStyle () {
 	int bits = super.widgetStyle () | OS.WS_TABSTOP;
-	/*
-	 * NOTE: ICON_CANCEL and ICON_SEARCH have the same value as H_SCROLL and
-	 * V_SCROLL. The meaning is determined by whether SWT.SEARCH is set.
-	 */
-	if ((style & SWT.SEARCH) == 0) {
-		if ((style & SWT.H_SCROLL) != 0) bits |= OS.WS_HSCROLL;
-		if ((style & SWT.V_SCROLL) != 0) bits |= OS.WS_VSCROLL;
-	}
+	if ((style & SWT.H_SCROLL) != 0) bits |= OS.WS_HSCROLL;
+	if ((style & SWT.V_SCROLL) != 0) bits |= OS.WS_VSCROLL;
 	return bits;
 }
 
@@ -396,24 +375,30 @@ LRESULT wmScrollWheel (boolean update, long wParam, long lParam) {
 	* Translate WM_MOUSEWHEEL to WM_VSCROLL or WM_HSCROLL.
 	*/
 	if (update) {
-		if ((wParam & (OS.MK_SHIFT | OS.MK_CONTROL)) != 0) return result;
-		boolean vertical = verticalBar != null && verticalBar.getEnabled ();
-		boolean horizontal = horizontalBar != null && horizontalBar.getEnabled ();
-		int msg = vertical ? OS.WM_VSCROLL : horizontal ? OS.WM_HSCROLL : 0;
-		if (msg == 0) return result;
-		int [] linesToScroll = new int [1];
-		OS.SystemParametersInfo (OS.SPI_GETWHEELSCROLLLINES, 0, linesToScroll, 0);
-		int delta = OS.GET_WHEEL_DELTA_WPARAM (wParam);
-		boolean pageScroll = linesToScroll [0] == OS.WHEEL_PAGESCROLL;
+		if ((wParam & (OS.MK_SHIFT | OS.MK_CONTROL)) != 0)
+			return null;
+
+		boolean vertical;
+		if (verticalBar != null && verticalBar.getEnabled ())
+			vertical = true;
+		else if (horizontalBar != null && horizontalBar.getEnabled ())
+			vertical = false;
+		else
+			return null;
+
 		ScrollBar bar = vertical ? verticalBar : horizontalBar;
+		MouseWheelData wheelData = new MouseWheelData(vertical, bar, wParam, display.scrollRemainderBar);
+
+		if (wheelData.count == 0) return null;
+
 		SCROLLINFO info = new SCROLLINFO ();
 		info.cbSize = SCROLLINFO.sizeof;
 		info.fMask = OS.SIF_POS;
 		OS.GetScrollInfo (handle, bar.scrollBarType (), info);
-		if (vertical && !pageScroll) delta *= linesToScroll [0];
-		int increment = pageScroll ? bar.getPageIncrement () : bar.getIncrement ();
-		info.nPos -=  increment * delta / OS.WHEEL_DELTA;
+		info.nPos -= wheelData.count;
 		OS.SetScrollInfo (handle, bar.scrollBarType (), info, true);
+
+		int msg = vertical ? OS.WM_VSCROLL : OS.WM_HSCROLL;
 		OS.SendMessage (handle, msg, OS.SB_THUMBPOSITION, 0);
 		return LRESULT.ZERO;
 	}
