@@ -1028,16 +1028,29 @@ public void removeAll () {
 	TVITEM tvItem = new TVITEM ();
 	tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_PARAM;
 	tvItem.hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
-	while (tvItem.hItem != 0) {
-		OS.SendMessage (hwnd, OS.TVM_GETITEM, 0, tvItem);
-		TreeItem item = tvItem.lParam != -1 ? parent.items [(int)tvItem.lParam] : null;
-		if (item != null && !item.isDisposed ()) {
-			item.dispose ();
-		} else {
-			parent.releaseItem (tvItem.hItem, tvItem, false);
-			parent.destroyItem (null, tvItem.hItem);
+	/**
+	 * Performance optimization, switch off redraw for high amount of elements
+	 */
+	boolean disableRedraw = parent.itemCount > 30;
+	if (disableRedraw) {
+		parent.setRedraw(false);
+	}
+	try {
+		while (tvItem.hItem != 0) {
+			OS.SendMessage (hwnd, OS.TVM_GETITEM, 0, tvItem);
+			TreeItem item = tvItem.lParam != -1 ? parent.items [(int)tvItem.lParam] : null;
+			if (item != null && !item.isDisposed ()) {
+				item.dispose ();
+			} else {
+				parent.releaseItem (tvItem.hItem, tvItem, false);
+				parent.destroyItem (null, tvItem.hItem);
+			}
+			tvItem.hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
+		}
+	} finally {
+		if (disableRedraw) {
+			parent.setRedraw(true);
 		}
-		tvItem.hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	}
 }
 
@@ -1246,10 +1259,6 @@ public void setExpanded (boolean expanded) {
 					OS.UpdateWindow (hwnd);
 					OS.DefWindowProc (hwnd, OS.WM_SETREDRAW, 0, 0);
 				}
-				/*
-				* This code is intentionally commented.
-				*/
-//				OS.SendMessage (hwnd, OS.WM_SETREDRAW, 0, 0);
 			}
 		}
 	}
@@ -1325,10 +1334,6 @@ public void setExpanded (boolean expanded) {
 			if (hwnd != topHandle) {
 				OS.DefWindowProc (hwnd, OS.WM_SETREDRAW, 1, 0);
 			}
-			/*
-			* This code is intentionally commented.
-			*/
-//			OS.SendMessage (hwnd, OS.WM_SETREDRAW, 1, 0);
 			if (fixScroll) {
 				parent.updateScrollBar ();
 				SCROLLINFO info = new SCROLLINFO ();
@@ -1802,4 +1807,12 @@ public void setText (String string) {
 	parent.sort (handle, false);
 }
 
+@Override
+String getNameText () {
+	if ((parent.style & SWT.VIRTUAL) != 0) {
+		if (!cached) return "*virtual*"; //$NON-NLS-1$
+	}
+	return super.getNameText ();
+}
+
 }
