@@ -146,10 +146,8 @@ class TreeTab extends ScrollableTab {
 			colorDialog.setRGB(oldColor.getRGB());
 			RGB rgb = colorDialog.open();
 			if (rgb == null) return;
-			oldColor = itemForegroundColor;
-			itemForegroundColor = new Color (display, rgb);
+			itemForegroundColor = new Color (rgb);
 			setItemForeground ();
-			if (oldColor != null) oldColor.dispose ();
 		}
 		break;
 		case ITEM_BACKGROUND_COLOR: {
@@ -158,10 +156,8 @@ class TreeTab extends ScrollableTab {
 			colorDialog.setRGB(oldColor.getRGB());
 			RGB rgb = colorDialog.open();
 			if (rgb == null) return;
-			oldColor = itemBackgroundColor;
-			itemBackgroundColor = new Color (display, rgb);
+			itemBackgroundColor = new Color (rgb);
 			setItemBackground ();
-			if (oldColor != null) oldColor.dispose ();
 		}
 		break;
 		case ITEM_FONT: {
@@ -183,10 +179,8 @@ class TreeTab extends ScrollableTab {
 			colorDialog.setRGB(oldColor.getRGB());
 			RGB rgb = colorDialog.open();
 			if (rgb == null) return;
-			oldColor = cellForegroundColor;
-			cellForegroundColor = new Color (display, rgb);
+			cellForegroundColor = new Color (rgb);
 			setCellForeground ();
-			if (oldColor != null) oldColor.dispose ();
 		}
 		break;
 		case CELL_BACKGROUND_COLOR: {
@@ -195,10 +189,8 @@ class TreeTab extends ScrollableTab {
 			colorDialog.setRGB(oldColor.getRGB());
 			RGB rgb = colorDialog.open();
 			if (rgb == null) return;
-			oldColor = cellBackgroundColor;
-			cellBackgroundColor = new Color (display, rgb);
+			cellBackgroundColor = new Color (rgb);
 			setCellBackground ();
-			if (oldColor != null) oldColor.dispose ();
 		}
 		break;
 		case CELL_FONT: {
@@ -220,10 +212,8 @@ class TreeTab extends ScrollableTab {
 			colorDialog.setRGB(oldColor.getRGB());
 			RGB rgb = colorDialog.open();
 			if (rgb == null) return;
-			oldColor = headerForegroundColor;
-			headerForegroundColor = new Color (display, rgb);
+			headerForegroundColor = new Color (rgb);
 			setHeaderForeground ();
-			if (oldColor != null) oldColor.dispose ();
 		}
 		break;
 		case HEADER_BACKGROUND_COLOR: {
@@ -232,10 +222,8 @@ class TreeTab extends ScrollableTab {
 			colorDialog.setRGB(oldColor.getRGB());
 			RGB rgb = colorDialog.open();
 			if (rgb == null) return;
-			oldColor = headerBackgroundColor;
-			headerBackgroundColor = new Color (display, rgb);
+			headerBackgroundColor = new Color (rgb);
 			setHeaderBackground ();
-			if (oldColor != null) oldColor.dispose ();
 		}
 		default:
 			super.changeFontOrColor(index);
