@@ -14,19 +14,20 @@
  */
 package org.eclipse.swt.tests.win32;
 
+import org.junit.runner.JUnitCore;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
 
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
-		// Test.class be added here.
+	Test_org_eclipse_swt_dnd_DND.class,
 })
 
 public class AllWin32Tests {
 
 	public static void main(String[] args) {
-//		JUnitCore.main(AllWin32Tests.class.getName()); // Enable once a test is added.
+		JUnitCore.main(AllWin32Tests.class.getName());
 	}
 
 }
