@@ -47,10 +47,12 @@ import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
+import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
+import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Menu;
 import org.eclipse.swt.widgets.Monitor;
 import org.eclipse.swt.widgets.Shell;
@@ -606,19 +608,19 @@ public void test_requestLayoutL() {
 }
 @Test
 public void test_setBackgroundLorg_eclipse_swt_graphics_Color() {
-	Color color = new Color(control.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	control.setBackground(color);
 	assertEquals("getBackground not equal color after setBackground(color) for " + control, color, control.getBackground());
 	control.setBackground(null);
 	assertTrue("getBackground unchanged after setBackground(null) for " + control, !control.getBackground().equals(color));
 	color.dispose();
-	color = new Color(control.getDisplay(), 255, 0, 0, 0);
+	color = new Color(255, 0, 0, 0);
 	control.setBackground(color);
 	assertEquals("getBackground not equal color after setBackground(color) with 0 alpha for " + control + " " + control.getBackground(), color, control.getBackground());
 	control.setBackground(null);
 	assertTrue("getBackground unchanged after setBackground(null) alpha for " + control + " " + control.getBackground() + " " + control, !control.getBackground().equals(color));
 	if ("gtk".equals(SWT.getPlatform ())) {
-		Color fg = new Color(control.getDisplay(), 0, 255, 0);
+		Color fg = new Color(0, 255, 0);
 		control.setBackground(color);
 		control.setForeground(fg);
 		assertEquals("Setting a foreground disrupted the background color for " + control,
@@ -630,10 +632,10 @@ public void test_setBackgroundLorg_eclipse_swt_graphics_Color() {
 }
 @Test
 public void test_setBackgroundAlphaLorg_eclipse_swt_graphics_Color() {
-	Color color = new Color (control.getDisplay(), 255, 0, 0, 0);
+	Color color = new Color (255, 0, 0, 0);
 	control.setBackground(color);
 	assertEquals(color, control.getBackground());
-	Color fg = new Color(control.getDisplay(), 0, 255, 0, 0);
+	Color fg = new Color(0, 255, 0, 0);
 	control.setForeground(fg);
 	assertEquals(color, control.getBackground());
 	color.dispose();
@@ -641,7 +643,7 @@ public void test_setBackgroundAlphaLorg_eclipse_swt_graphics_Color() {
 }
 @Test
 public void test_setBackgroundDisposedColorLorg_eclipse_swt_graphics_Color() {
-	Color color = new Color(control.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	color.dispose();
 	try {
 		control.setBackground(color);
@@ -747,13 +749,13 @@ public void test_setFontLorg_eclipse_swt_graphics_Font() {
 }
 @Test
 public void test_setForegroundLorg_eclipse_swt_graphics_Color() {
-	Color color = new Color(control.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	control.setForeground(color);
 	assertEquals(color, control.getForeground());
 	control.setForeground(null);
 	assertFalse(control.getForeground().equals(color));
 	if ("gtk".equals(SWT.getPlatform ())) {
-		Color bg = new Color(control.getDisplay(), 0, 255, 0);
+		Color bg = new Color(0, 255, 0);
 		control.setForeground(color);
 		control.setBackground(bg);
 		assertEquals("Setting a background disrupted the foreground color for " + control,
@@ -767,10 +769,10 @@ public void test_setForegroundLorg_eclipse_swt_graphics_Color() {
 public void test_setForegroundAlphaLorg_eclipse_swt_graphics_Color() {
 	assumeTrue("Alpha support for foreground colors does not exist on GTK2 or Win32",
 			SwtTestUtil.isCocoa || SwtTestUtil.isGTK);
-	Color color = new Color (control.getDisplay(), 255, 0, 0, 0);
+	Color color = new Color (255, 0, 0, 0);
 	control.setForeground(color);
 	assertEquals(color, control.getForeground());
-	Color bg = new Color(control.getDisplay(), 0, 255, 0, 0);
+	Color bg = new Color(0, 255, 0, 0);
 	control.setBackground(bg);
 	assertEquals(color, control.getForeground());
 	color.dispose();
@@ -779,7 +781,7 @@ public void test_setForegroundAlphaLorg_eclipse_swt_graphics_Color() {
 
 @Test
 public void test_setForegroundDisposedColorLorg_eclipse_swt_graphics_Color() {
-	Color color = new Color(control.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	color.dispose();
 	try {
 		control.setForeground(color);
@@ -1183,4 +1185,16 @@ public void test_ExceptionsThrownInDisposeListenerDontPreventDisposal () {
 	}
 }
 
+@Test
+public void test_NoExceptionsThrownInFillLayout () {
+	shell.setLayout(new FillLayout());
+	Label label = new Label(shell, SWT.NONE);
+	Label label2 = new Label(shell, SWT.NONE);
+	String layoutData = new String("not a fill layout");
+	label.setLayoutData(layoutData);
+	shell.computeSize(SWT.DEFAULT, SWT.DEFAULT, true);
+	assertEquals(layoutData, label.getLayoutData());
+	assertNotNull(label2.getLayoutData());
+}
+
 }
