@@ -152,7 +152,7 @@ public void test_addSelectionListenerWidgetSelectedAdapterLorg_eclipse_swt_event
 @Test
 public void test_setBackgroundCalendarDateTime() {
 	DateTime calendar = new DateTime(shell, SWT.CALENDAR);
-	Color color = new Color(calendar.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	calendar.setBackground(color);
 	assertEquals("getBackground not equal after setBackground for SWT.CALENDAR DateTime",
 			color, calendar.getBackground());
@@ -160,7 +160,7 @@ public void test_setBackgroundCalendarDateTime() {
 	assertTrue("getBackground unchanged after setBackground(null) for SWT.CALENDAR DateTime",
 			!calendar.getBackground().equals(color));
 	color.dispose();
-	color = new Color(calendar.getDisplay(), 255, 0, 0, 0);
+	color = new Color(255, 0, 0, 0);
 	calendar.setBackground(color);
 	assertEquals("getBackground not equal after setBackground with 0 alpha for SWT.CALENDAR DateTime",
 			color, calendar.getBackground());
@@ -168,7 +168,7 @@ public void test_setBackgroundCalendarDateTime() {
 	assertTrue("getBackground unchanged after setBackground(null) with 0 alpha for SWT.CALENDAR DateTime",
 			!calendar.getBackground().equals(color));
 	if ("gtk".equals(SWT.getPlatform ())) {
-		Color fg = new Color(calendar.getDisplay(), 0, 255, 0);
+		Color fg = new Color(0, 255, 0);
 		calendar.setBackground(color);
 		calendar.setForeground(fg);
 		assertEquals("Setting a foreground disrupted the background color for SWT.CALENDAR DateTime",
@@ -184,10 +184,10 @@ public void test_setBackgroundCalendarDateTime() {
 @Test
 public void test_setBackgroundAlphaCalendarDateTime() {
 	DateTime calendar = new DateTime(shell, SWT.CALENDAR);
-	Color color = new Color (calendar.getDisplay(), 255, 0, 0, 0);
+	Color color = new Color (255, 0, 0, 0);
 	calendar.setBackground(color);
 	assertEquals(color, calendar.getBackground());
-	Color fg = new Color(calendar.getDisplay(), 0, 255, 0, 0);
+	Color fg = new Color(0, 255, 0, 0);
 	calendar.setForeground(fg);
 	assertEquals(color, calendar.getBackground());
 	color.dispose();
@@ -198,7 +198,7 @@ public void test_setBackgroundAlphaCalendarDateTime() {
 @Test
 public void test_setBackgroundTimeDateTime() {
 	DateTime time = new DateTime(shell, SWT.TIME);
-	Color color = new Color(time.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	time.setBackground(color);
 	assertEquals("getBackground not equal after setBackground for SWT.TIME DateTime",
 			color, time.getBackground());
@@ -206,7 +206,7 @@ public void test_setBackgroundTimeDateTime() {
 	assertTrue("getBackground unchanged after setBackground(null) for SWT.TIME DateTime",
 			!time.getBackground().equals(color));
 	color.dispose();
-	color = new Color(time.getDisplay(), 255, 0, 0, 0);
+	color = new Color(255, 0, 0, 0);
 	time.setBackground(color);
 	assertEquals("getBackground not equal after setBackground with 0 alpha for SWT.TIME DateTime",
 			color, time.getBackground());
@@ -214,7 +214,7 @@ public void test_setBackgroundTimeDateTime() {
 	assertTrue("getBackground unchanged after setBackground(null) with 0 alpha for SWT.TIME DateTime",
 			!time.getBackground().equals(color));
 	if ("gtk".equals(SWT.getPlatform ())) {
-		Color fg = new Color(time.getDisplay(), 0, 255, 0);
+		Color fg = new Color(0, 255, 0);
 		time.setBackground(color);
 		time.setForeground(fg);
 		assertEquals("Setting a foreground disrupted the background color for SWT.TIME DateTime",
@@ -230,10 +230,10 @@ public void test_setBackgroundTimeDateTime() {
 @Test
 public void test_setBackgroundAlphaTimeDateTime() {
 	DateTime time = new DateTime(shell, SWT.TIME);
-	Color color = new Color (time.getDisplay(), 255, 0, 0, 0);
+	Color color = new Color (255, 0, 0, 0);
 	time.setBackground(color);
 	assertEquals(color, time.getBackground());
-	Color fg = new Color(time.getDisplay(), 0, 255, 0, 0);
+	Color fg = new Color(0, 255, 0, 0);
 	time.setForeground(fg);
 	assertEquals(color, time.getBackground());
 	color.dispose();
@@ -244,7 +244,7 @@ public void test_setBackgroundAlphaTimeDateTime() {
 @Test
 public void test_setBackgroundDateDateTime() {
 	DateTime date = new DateTime(shell, SWT.DATE);
-	Color color = new Color(date.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	date.setBackground(color);
 	assertEquals("getBackground not equal after setBackground for SWT.DATE DateTime",
 			color, date.getBackground());
@@ -252,7 +252,7 @@ public void test_setBackgroundDateDateTime() {
 	assertTrue("getBackground unchanged after setBackground(null) for SWT.DATE DateTime",
 			!date.getBackground().equals(color));
 	color.dispose();
-	color = new Color(date.getDisplay(), 255, 0, 0, 0);
+	color = new Color(255, 0, 0, 0);
 	date.setBackground(color);
 	assertEquals("getBackground not equal after setBackground with 0 alpha for SWT.DATE DateTime",
 			color, date.getBackground());
@@ -260,7 +260,7 @@ public void test_setBackgroundDateDateTime() {
 	assertTrue("getBackground unchanged after setBackground(null) with 0 alpha for SWT.DATE DateTime",
 			!date.getBackground().equals(color));
 	if ("gtk".equals(SWT.getPlatform ())) {
-		Color fg = new Color(date.getDisplay(), 0, 255, 0);
+		Color fg = new Color(0, 255, 0);
 		date.setBackground(color);
 		date.setForeground(fg);
 		assertEquals("Setting a foreground disrupted the background color for SWT.DATE DateTime",
@@ -276,10 +276,10 @@ public void test_setBackgroundDateDateTime() {
 @Test
 public void test_setBackgroundAlphaDateDateTime() {
 	DateTime date = new DateTime(shell, SWT.DATE);
-	Color color = new Color (date.getDisplay(), 255, 0, 0, 0);
+	Color color = new Color (255, 0, 0, 0);
 	date.setBackground(color);
 	assertEquals(color, date.getBackground());
-	Color fg = new Color(date.getDisplay(), 0, 255, 0, 0);
+	Color fg = new Color(0, 255, 0, 0);
 	date.setForeground(fg);
 	assertEquals(color, date.getBackground());
 	color.dispose();
@@ -416,13 +416,13 @@ public void test_setDayI() {
 @Test
 public void test_setForegroundCalendarDateTime() {
 	DateTime calendar = new DateTime(shell, SWT.CALENDAR);
-	Color color = new Color(calendar.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	calendar.setForeground(color);
 	assertEquals(color, calendar.getForeground());
 	calendar.setForeground(null);
 	assertFalse(calendar.getForeground().equals(color));
 	if ("gtk".equals(SWT.getPlatform ())) {
-		Color bg = new Color(calendar.getDisplay(), 0, 255, 0);
+		Color bg = new Color(0, 255, 0);
 		calendar.setForeground(color);
 		calendar.setBackground(bg);
 		assertEquals("Setting a background disrupted the foreground color for SWT.CALENDAR DateTime",
@@ -440,10 +440,10 @@ public void test_setForegroundAlphaCalendarDateTime() {
 	DateTime calendar = new DateTime(shell, SWT.CALENDAR);
 	assumeTrue("Alpha support for foreground colors does not exist on GTK2 or Win32",
 			SwtTestUtil.isCocoa || SwtTestUtil.isGTK);
-	Color color = new Color (calendar.getDisplay(), 255, 0, 0, 0);
+	Color color = new Color (255, 0, 0, 0);
 	calendar.setForeground(color);
 	assertEquals(color, calendar.getForeground());
-	Color bg = new Color(calendar.getDisplay(), 0, 255, 0, 0);
+	Color bg = new Color(0, 255, 0, 0);
 	calendar.setBackground(bg);
 	assertEquals(color, calendar.getForeground());
 	color.dispose();
@@ -454,13 +454,13 @@ public void test_setForegroundAlphaCalendarDateTime() {
 @Test
 public void test_setForegroundTimeDateTime() {
 	DateTime time = new DateTime(shell, SWT.TIME);
-	Color color = new Color(time.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	time.setForeground(color);
 	assertEquals(color, time.getForeground());
 	time.setForeground(null);
 	assertFalse(time.getForeground().equals(color));
 	if ("gtk".equals(SWT.getPlatform ())) {
-		Color bg = new Color(time.getDisplay(), 0, 255, 0);
+		Color bg = new Color(0, 255, 0);
 		time.setForeground(color);
 		time.setBackground(bg);
 		assertEquals("Setting a background disrupted the foreground color for SWT.TIME DateTime",
@@ -478,10 +478,10 @@ public void test_setForegroundAlphaTimeDateTime() {
 	DateTime time = new DateTime(shell, SWT.TIME);
 	assumeTrue("Alpha support for foreground colors does not exist on GTK2 or Win32",
 			SwtTestUtil.isCocoa || SwtTestUtil.isGTK);
-	Color color = new Color (time.getDisplay(), 255, 0, 0, 0);
+	Color color = new Color (255, 0, 0, 0);
 	time.setForeground(color);
 	assertEquals(color, time.getForeground());
-	Color bg = new Color(time.getDisplay(), 0, 255, 0, 0);
+	Color bg = new Color(0, 255, 0, 0);
 	time.setBackground(bg);
 	assertEquals(color, time.getForeground());
 	color.dispose();
@@ -492,13 +492,13 @@ public void test_setForegroundAlphaTimeDateTime() {
 @Test
 public void test_setForegroundDateDateTime() {
 	DateTime date = new DateTime(shell, SWT.DATE);
-	Color color = new Color(date.getDisplay(), 255, 0, 0);
+	Color color = new Color(255, 0, 0);
 	date.setForeground(color);
 	assertEquals(color, date.getForeground());
 	date.setForeground(null);
 	assertFalse(date.getForeground().equals(color));
 	if ("gtk".equals(SWT.getPlatform ())) {
-		Color bg = new Color(date.getDisplay(), 0, 255, 0);
+		Color bg = new Color(0, 255, 0);
 		date.setForeground(color);
 		date.setBackground(bg);
 		assertEquals("Setting a background disrupted the foreground color for SWT.DATE DateTime",
@@ -516,10 +516,10 @@ public void test_setForegroundAlphaDateDateTime() {
 	DateTime date = new DateTime(shell, SWT.DATE);
 	assumeTrue("Alpha support for foreground colors does not exist on GTK2 or Win32",
 			SwtTestUtil.isCocoa || SwtTestUtil.isGTK);
-	Color color = new Color (date.getDisplay(), 255, 0, 0, 0);
+	Color color = new Color (255, 0, 0, 0);
 	date.setForeground(color);
 	assertEquals(color, date.getForeground());
-	Color bg = new Color(date.getDisplay(), 0, 255, 0, 0);
+	Color bg = new Color(0, 255, 0, 0);
 	date.setBackground(bg);
 	assertEquals(color, date.getForeground());
 	color.dispose();
