@@ -101,9 +101,9 @@ protected void setWidget(Widget widget) {
 }
 
 private void freeImages() {
-	for (int i=0; i<images.length; i++) {
-		if (images[i] != null)
-			images[i].dispose();
+	for (Image image : images) {
+		if (image != null)
+			image.dispose();
 	}
 }
 }
