@@ -502,8 +502,8 @@ public void test_open() {
 
 @Test
 public void test_setActive() {
-	if (SwtTestUtil.isGTK) {
-		//TODO Fix GTK failure.
+	if (SwtTestUtil.isGTK || SwtTestUtil.isCocoa) {
+		//TODO Fix GTK and Cocoa failure.
 		if (SwtTestUtil.verbose) {
 			System.out.println("Excluded test_setActive(org.eclipse.swt.tests.junit.Test_org_eclipse_swt_widgets_Shell))");
 		}
@@ -517,9 +517,6 @@ public void test_setActive() {
 	/* Test setActive for visible shell. */
 	shell.setVisible(true);
 	shell.setActive();
-	if (SwtTestUtil.isCocoa) { //workaround for Bug 536564
-		drainEventQueue(shell.getDisplay(), 5000);
-	}
 	assertTrue("visible shell was not made active", shell.getDisplay().getActiveShell() == shell);
 
 	/* Test setActive for visible dialog shell. */
@@ -527,9 +524,6 @@ public void test_setActive() {
 	testShell.setBounds(shell.getBounds());
 	testShell.setVisible(true);
 	testShell.setActive();
-	if (SwtTestUtil.isCocoa) { //workaround for Bug 536564
-		drainEventQueue(shell.getDisplay(), 2000);
-	}
 	assertTrue("visible dialog shell was not made active", testShell.getDisplay().getActiveShell() == testShell);
 
 	/* Test setActive for non-visible shell. */
@@ -537,9 +531,6 @@ public void test_setActive() {
 	shell.setVisible(false);
 	shell.setActive();
 	shell2.setText("Shell2: Not active");
-	if (SwtTestUtil.isCocoa) { //workaround for Bug 536564
-		drainEventQueue(shell.getDisplay(), 2000);
-	}
 	assertTrue("non-visible shell was made active", shell.getDisplay().getActiveShell() != shell);
 
 	/* Test setActive for non-visible dialog shell. */
@@ -547,32 +538,11 @@ public void test_setActive() {
 	testShell.setVisible(false);
 	testShell.setActive();
 	shell2.setText("Shell2: Not active");
-	if (SwtTestUtil.isCocoa) { //workaround for Bug 536564
-		drainEventQueue(shell.getDisplay(), 2000);
-	}
 	assertTrue("non-visible dialog shell was made active", testShell.getDisplay().getActiveShell() != testShell);
 
 	shell2.dispose();
 }
 
-private static void drainEventQueue(Display display, int millis) {
-	if (millis == 0) {
-		while (!display.isDisposed() && display.readAndDispatch()) {
-		}
-		return;
-	}
-	long end = System.currentTimeMillis() + millis;
-	while (!display.isDisposed() && System.currentTimeMillis() < end) {
-		if (!display.readAndDispatch ()) {
-			try {
-				Thread.sleep(10);
-			} catch (InterruptedException e) {
-				e.printStackTrace();
-			}
-		}
-	}
-}
-
 @Override
 @Test
 public void test_setEnabledZ() {
@@ -682,8 +652,8 @@ public void test_activateEventSend() {
 			});
 		testShell.open();
 		int[] styles = {SWT.ON_TOP, SWT.APPLICATION_MODAL, SWT.PRIMARY_MODAL, SWT.SYSTEM_MODAL, SWT.NO_TRIM, SWT.BORDER, SWT.SHELL_TRIM};
-		for (int i = 0; i < styles.length; i++) {
-			Shell childShell = new Shell(testShell, styles[i]);
+		for (int style : styles) {
+			Shell childShell = new Shell(testShell, style);
 			listenerCalled = false;
 			childShell.open();
 			childShell.dispose();
@@ -915,4 +885,38 @@ public void test_setAlpha() {
 	testShell.setAlpha(255);
 	assertEquals(255, testShell.getAlpha());
 }
+
+@Test // see bug#520488
+public void test_childDisposesParent () {
+	createShell();
+	Shell root = new Shell(testShell, SWT.SHELL_TRIM);
+	Shell child = new Shell(root, SWT.SHELL_TRIM);
+	child.addListener(SWT.Dispose, e -> root.dispose());
+	root.dispose();
+}
+
+@Test
+public void test_bug558652_scrollBarNPE() {
+	createShell();
+	int[] styles = new int[] { SWT.NONE, SWT.DIALOG_TRIM, SWT.SHELL_TRIM };
+	for (int style : styles) {
+		Shell shell = new Shell(testShell, style);
+		assertNull(shell.getVerticalBar());
+		assertNull(shell.getHorizontalBar());
+		shell.dispose();
+		shell = new Shell(testShell, style | SWT.V_SCROLL);
+		assertNotNull(shell.getVerticalBar());
+		assertNull(shell.getHorizontalBar());
+		shell.dispose();
+		shell = new Shell(testShell, style | SWT.H_SCROLL);
+		assertNull(shell.getVerticalBar());
+		assertNotNull(shell.getHorizontalBar());
+		shell.dispose();
+		shell = new Shell(testShell, style | SWT.V_SCROLL | SWT.H_SCROLL);
+		assertNotNull(shell.getVerticalBar());
+		assertNotNull(shell.getHorizontalBar());
+		shell.dispose();
+	}
+}
+
 }
