@@ -33,8 +33,11 @@ import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Tree;
 import org.eclipse.swt.widgets.TreeColumn;
 import org.eclipse.swt.widgets.TreeItem;
+import org.eclipse.test.Screenshots;
 import org.junit.Before;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.TestName;
 
 /**
  * Automated Test Suite for class org.eclipse.swt.widgets.Tree
@@ -43,6 +46,9 @@ import org.junit.Test;
  */
 public class Test_org_eclipse_swt_widgets_Tree extends Test_org_eclipse_swt_widgets_Composite {
 
+@Rule
+public TestName testName = new TestName();
+
 @Override
 @Before
 public void setUp() {
@@ -369,7 +375,7 @@ public void test_selectAll() {
 @Test
 public void test_setHeaderBackgroundLorg_eclipse_swt_graphics_Color() {
 	assertNotNull(tree.getHeaderBackground());
-	Color color = new Color(control.getDisplay(), 12, 34, 56);
+	Color color = new Color(12, 34, 56);
 	tree.setHeaderBackground(color);
 	assertEquals(color, tree.getHeaderBackground());
 	tree.setHeaderBackground(null);
@@ -380,7 +386,7 @@ public void test_setHeaderBackgroundLorg_eclipse_swt_graphics_Color() {
 @Test
 public void test_setHeaderForegroundLorg_eclipse_swt_graphics_Color() {
 	assertNotNull(tree.getHeaderForeground());
-	Color color = new Color(control.getDisplay(), 12, 34, 56);
+	Color color = new Color(12, 34, 56);
 	tree.setHeaderForeground(color);
 	assertEquals(color, tree.getHeaderForeground());
 	tree.setHeaderForeground(null);
@@ -929,8 +935,13 @@ public void test_Virtual() {
 			top[0] = item;
 			item.setText("top");
 		} else {
-			int index = top[0].indexOf(item);
-			item.setText("Item " + index);
+			if (top[0] == null) {
+				top[0] = tree.getItem(0);
+			}
+			if (top[0] != null) {
+				int index = top[0].indexOf(item);
+				item.setText("Item " + index);
+			}
 		}
 		dataCounter[0]++;
 	});
@@ -941,8 +952,10 @@ public void test_Virtual() {
 	TreeItem item0 = tree.getItem(0);
 	item0.setItemCount(count);
 	item0.setExpanded(true);
+
 	long end = System.currentTimeMillis() + 3000;
-	while (!shell.isDisposed() && System.currentTimeMillis() < end) {
+	Display display = shell.getDisplay();
+	while (!display.isDisposed() && System.currentTimeMillis() < end) {
 		if (!shell.getDisplay().readAndDispatch ()) {
 			try {
 				Thread.sleep(10);
@@ -951,8 +964,16 @@ public void test_Virtual() {
 			}
 		}
 	}
-	// the "* 2" allows some surplus for platforms that pre-fetch items to improve scrolling performance:
+	// temp code to capture screenshot
+	if (SwtTestUtil.isCocoa) {
+		Screenshots.takeScreenshot(getClass(), testName.getMethodName());
+		// check if setData is called for root item
+		assertTrue("SetData not called for top item", top[0] != null);
+	}
+
+
+	// the "* 3" allows some surplus for platforms that pre-fetch items to improve scrolling performance:
 	assertTrue("SetData callback count not in range: " + dataCounter[0],
-			dataCounter[0] > visibleCount / 2 && dataCounter[0] <= visibleCount * 2);
+			dataCounter[0] > visibleCount / 2 && dataCounter[0] <= visibleCount * 3);
 }
 }
